library(phangorn)
library(ape)
library(picante)
library(phytools)
library(smatr)
library(geiger)
library(car)
library(mvMORPH)
library(nortest)
library(geomorph)
library(foreach)
library(doMC)
library(doParallel)
library(phylolm)

#this funciton is modified from Schmitz L, Higham TE (2018) Data from: Non-uniform evolutionary response of gecko eye size to changes in diel activity patterns. Biology Letters https://doi.org/10.5061/dryad.96qr7n2   
#x = OUM,  y= BM1
power.error <- function (x, y){
  nsim=100
  OUM_data<-simulate(x, tree=painttree[[1]], nsim=nsim)
  BM1_data<-simulate(y, tree=painttree[[1]], nsim=nsim)
  
  result.BM1.other<-foreach(i=1:nsim)%dopar%{mvBM(painttree[[1]], OUM_data[,i], model="BM1")}
  result.BM1.self<-foreach(i=1:nsim)%dopar%{mvBM(painttree[[1]], BM1_data[,i], model="BM1")}
  
  result.OUM.self<-foreach(i=1:nsim)%dopar%{mvOU(painttree[[1]], OUM_data[,i], model="OUM")}
  result.OUM.other<-foreach(i=1:nsim)%dopar%{mvOU(painttree[[1]], BM1_data[,i], model="OUM")}
  
  OUM_simul<-sapply(1:nsim, function(x){
    c(result.OUM.self[[x]]$AICc,result.BM1.other[[x]]$AICc)
  })
  
  BM1_simul<-sapply(1:nsim, function(x){
    c(result.OUM.other[[x]]$AICc, result.BM1.self[[x]]$AICc)
  })
  
  tI<-(sum(BM1_simul[1,]<BM1_simul[2,])/nsim)
  tII<-(sum(OUM_simul[1,]<OUM_simul[2,])/nsim)
  return(c(tI, tII))
}

dat<-read.csv(file.choose())
row.names(dat) <- dat$species
sp_list_F<-row.names(dat)
  
# phylo -------------------------------------------------------------------
#mammaltrees, Kuhn TS, Mooers A0, Thomas, GH 2011. A simple polytomy resolver for dated phylogenies.  Methods in Ecology and Evoution. https://doi.org/10.1111/j.2041-210X.2011.00103.x  
#Pygathrix_nigripes substituted for Pygathrix_cinerea
#source file used uploaded to figshare
m.trees.1.F<-read.nexus("/Volumes/GoogleDrive/My Drive/Granatosky/Joint Angles/PHYLO/phylogenies/FritzTree.rs200k.100trees.tre") 
m.trees.F <- lapply(m.trees.1.F, drop.tip, tip=setdiff(m.trees.1.F[[1]]$tip.label, sp_list_F))
class(m.trees.F) <- 'multiPhylo'
prop.part(m.trees.F) -> pp
maxCladeCred(m.trees.F, tree=TRUE, part = pp) -> mcctree
prop.clades(mcctree, m.trees.F, rooted=T) -> boot
plot(mcctree, cex=0.4)
nodelabels(boot, cex=0.3)

#birdtrees, downloaded from https://vertlife.org/phylosubsets/ , Ericson All Species, a set of 10000 trees with 9993 OTUs each
#Jetz, W., G. H. Thomas, J. B. Joy, K. Hartmann, D. Redding, and A. O. Mooers. 2014. Distribution and conservation of global evolutionary distinctness in birds. Current Biology 24, 1-12 http://dx.doi.org/10.1016/j.cub.2014.03.011
#W. Jetz, G. H. Thomas, J. B. Joy, K. Hartmann, A. O. Mooers The global diversity of birds in space and time Nature, 491: 444-448.  doi:10.1038/nature11631
#source file used uploaded to figshare
read.nexus("/Volumes/GoogleDrive/My Drive/Granatosky/FORCE/R2/Phylos/bird.output.nex") -> b.trees.F
prop.part(b.trees.F) -> pp
maxCladeCred(b.trees.F, tree=TRUE, part = pp) -> mcctree
prop.clades(mcctree, b.trees.F, rooted=T) -> boot
plot(mcctree, cex=0.4)
nodelabels(boot, cex=0.3)

#lizardtrees, https://vertlife.org/phylosubsets/, Tonini JFR, Beard KH, Ferreira RB, Jetz W, Pyron RA (2016) Fully-sampled phylogenies of squamates reveal evolutionary patterns in threat status. Biological Conservation, online in advance of print. http://dx.doi.org/10.1016/j.biocon.2016.03.039  
#source file used uploaded to figshare
read.nexus("/Volumes/GoogleDrive/My Drive/Granatosky/FORCE/R2/Phylos/liz.output.nex") -> l.trees.F
prop.part(l.trees.F) -> pp
maxCladeCred(l.trees.F, tree=TRUE, part = pp) -> mcctree
prop.clades(mcctree, l.trees.F, rooted=T) -> boot
plot(mcctree, cex=0.4)
nodelabels(boot, cex=0.3)

#amphibtrees, https://vertlife.org/phylosubsets/, Jetz, W., and R. A. Pyron. 2018. The interplay of past diversification and evolutionary isolation with present imperilment across the amphibian tree of life. Nature Ecology & Evolution:1. https://www.nature.com/articles/s41559-018-0515-5
#source file used uploaded to figshare
read.nexus("/Volumes/GoogleDrive/My Drive/Granatosky/FORCE/R2/Phylos/amphib.output.nex") -> a.trees.F
prop.part(a.trees.F) -> pp
maxCladeCred(a.trees.F, tree=TRUE, part = pp) -> mcctree
prop.clades(mcctree, a.trees.F, rooted=T) -> boot
plot(mcctree, cex=0.4)
nodelabels(boot, cex=0.3)

# Branch lengths from http://www.timetree.org,  
#Kumar S, Stecher G, Suleski M, Hedges SB (2017) TimeTree: A Resource for Timelines, Timetrees, and Divergence Times. Mol Biol Evol 34 (7): 1812-1819
#Hedges SB, Marin J, Suleski M, Paymer M & Kumar S (2015) Tree of Life Reveals Clock-Like Speciation and Diversification. Mol Biol Evol 32: 835-845.
#Kumar S & Hedges SB (2011) TimeTree2: species divergence times on the iPhone. Bioinformatics 27:2023-2024.
#Hedges SB, Dudley J, & Kumar S (2006). TimeTree: A public knowledge-base of divergence times among organisms. Bioinformatics 22: 2971-2972.
tree.b <- "tetrapoda(amphibia:204,(mammalia:164,(lepidosauria:110,(testudines:174,(crocodylia:173, aves:126):17):26):32):40);"
cat(tree.b, file="ex.tre", sep="\n")
tree.am <- read.tree("ex.tre")
plot(tree.am)
edgelabels(tree.am$edge.length)
tiplabels()

#node depths for crown clades set from http://www.timetree.org
phylogeny.F<-ape::rcoal(3);
for (i in 1:100){
  t <- sample(1:100, 1)
  m.tree.F <- m.trees.F[[t]]
  m.tree.F <- rescale(m.tree.F,model="depth", depth=round(mean(unlist((lapply(lapply(m.trees.F, nodeHeights), max)))), 0))
  phylogeny.F[[i]] <- bind.tree(tree.am, m.tree.F, where=2)
}

phylogeny.1.F<-ape::rcoal(3);
for (i in 1:100){
  t <- sample(1:1000, 1)
  b.tree.F <- b.trees.F[[t]]
  b.tree.F <- rescale(b.tree.F,model="depth", depth=round(mean(unlist((lapply(lapply(b.trees.F, nodeHeights), max)))), 0))
  phylogeny.1.F[[i]] <- bind.tree(phylogeny.F[[i]], b.tree.F, where=5)
}

phylogeny.2.F<-ape::rcoal(3);
for (i in 1:100){
  t <- sample(1:1000, 1)
  l.tree.F <- l.trees.F[[t]]
  l.tree.F <- rescale(l.tree.F,model="depth", depth=round(mean(unlist((lapply(lapply(l.trees.F, nodeHeights), max)))), 0))
  phylogeny.2.F[[i]] <- bind.tree(phylogeny.1.F[[i]], l.tree.F, where=2)
}

phylogeny.3.F<-ape::rcoal(3);
for (i in 1:100){
  t <- sample(1:1000, 1)
  a.tree.F <- a.trees.F[[t]]
  a.tree.F <- rescale(a.tree.F,model="depth", depth=round(mean(unlist((lapply(lapply(a.trees.F, nodeHeights), max)))), 0))
  phylogeny.3.F[[i]] <- bind.tree(phylogeny.2.F[[i]], a.tree.F, where=1)
}

#node depth set using http://www.timetree.org,  Testudo species split set at 31 mya.
tree.1.F <- "turtle(Pseudemys_concinna:80, (Testudo_graeca:31, Testudo_hermanni:31):49);"
cat(tree.1.F, file="turtle.tre", sep="\n")
tree.t.F <- read.tree("turtle.tre")

tree.2.F <- "crocodylia(Caiman_crocodilus:64);"
cat(tree.2.F, file="croc.tre", sep="\n")
tree.c.F <- read.tree("croc.tre")

phylogeny.4.F<-ape::rcoal(3);
for (i in 1:100){
  phylogeny.4.F[[i]] <- bind.tree(phylogeny.3.F[[i]], tree.t.F, where=1)
}

phylogeny.5.F<-ape::rcoal(3);
for (i in 1:100){
  phylogeny.5.F[[i]] <- bind.tree(phylogeny.4.F[[i]], tree.c.F, where=1)
}

#make tree ultrametric by adding small amounts of BL to required edges
#note that this is mostly due to signifing error because of decimal precision from posterior samples (average deviation of bl from ultrametric  is ~ 10^-5 mya)
#from Liam Revell's Phytools Blog (http://blog.phytools.org/2017/03/forceultrametric-method-for-ultrametric.html)
phylogeny.final.F<-ape::rcoal(3);
for (i in 1:100){
  h<-diag(vcv(phylogeny.5.F[[i]]))
  d<-max(h)-h
  ii<-sapply(1:Ntip(phylogeny.5.F[[i]]),function(x,y) which(y==x), y=phylogeny.5.F[[i]]$edge[,2])
  phylogeny.5.F[[i]]$edge.length[ii]<-phylogeny.5.F[[i]]$edge.length[ii]+d
  phylogeny.final.F[[i]] <- phylogeny.5.F[[i]]
}

is.ultrametric(phylogeny.final.F[[1]])
class(phylogeny.final.F) <- 'multiPhylo'

####mCCtree for whole phylogeny
prop.part(phylogeny.final.F) -> pp
maxCladeCred(phylogeny.final.F, tree=TRUE, part = pp) -> mcctree.F
prop.clades(mcctree.F, phylogeny.final.F, rooted=T) -> boot.F
plot(mcctree.F, cex=0.2)
nodelabels(boot.F, cex=0.1)

# data formatting ---------------------------------------------------------
peakv <- log10(dat$peakv)
names(peakv)<-dat$species
se.pv<-log10(dat$pv.sd)/sqrt(dat$Number.of.individuals)
se.pv[is.na(se.pv)] <- mean(se.pv, na.rm ='T')
names(se.pv)<-dat$species

peakbrake <- log10(dat$peakbrake)
names(peakbrake)<-dat$species
se.pb<-log10(dat$pb.sd)/sqrt(dat$Number.of.individuals)
se.pb[is.na(se.pb)] <- mean(se.pb, na.rm ='T')
names(se.pb)<-dat$species

peakaccel <- log10(dat$peakaccel)
names(peakaccel)<-dat$species
se.pa<-log10(dat$pa.sd)/sqrt(dat$Number.of.individuals)
se.pa[is.na(se.pa)] <- mean(se.pa, na.rm ='T')
names(se.pa)<-dat$species

peakmed <- log10(dat$peakmed)
names(peakmed)<-dat$species
se.pm<-log10(dat$pm.sd)/sqrt(dat$Number.of.individuals)
se.pm[is.na(se.pm)] <- mean(se.pm, na.rm ='T')
names(se.pm)<-dat$species

peaklat <- log10(dat$peaklat)
names(peaklat)<-dat$species
se.pl<-log10(dat$pl.sd)/sqrt(dat$Number.of.individuals)
se.pl[is.na(se.pl)] <- mean(se.pl, na.rm ='T')
names(se.pl)<-dat$species

tv <- log10(dat$tv)
names(tv)<-dat$species
se.tv<-log10(dat$tv.sd)/sqrt(dat$Number.of.individuals)
se.tv[is.na(se.tv)] <- mean(se.tv, na.rm ='T')
names(se.tv)<-dat$species

tbrake <- log10(dat$tbrake) 
names(tbrake )<-dat$species
se.tb<-log10(dat$tb.sd)/sqrt(dat$Number.of.individuals)
se.tb[is.na(se.tb)] <- mean(se.tb, na.rm ='T')
names(se.tb)<-dat$species

taccel <- log10(dat$taccel)
names(taccel)<-dat$species
se.ta<-log10(dat$ta.sd)/sqrt(dat$Number.of.individuals)
se.ta[is.na(se.ta)] <- mean(se.ta, na.rm ='T')
names(se.ta)<-dat$species

tbp <- log10(dat$tbp)
names(tbp)<-dat$species
se.tbp<-log10(dat$tbp.sd)/sqrt(dat$Number.of.individuals)
se.tbp[is.na(se.tbp)] <- mean(se.tbp, na.rm ='T')
names(se.tbp)<-dat$species

tmed <- log10(dat$tmed)
names(tmed)<-dat$species
se.tm<-log10(dat$tm.sd)/sqrt(dat$Number.of.individuals)
se.tm[is.na(se.tm)] <- mean(se.tm, na.rm ='T')
names(se.tm)<-dat$species

tlat <- log10(dat$tlat)
names(tlat)<-dat$species
se.tl<-log10(dat$tl.sd)/sqrt(dat$Number.of.individuals)
se.tl[is.na(se.tl)] <- mean(se.tl, na.rm ='T')
names(se.tl)<-dat$species

cycle <- log10(dat$cycle)
names(cycle)<-dat$species
se.cycle<-log10(dat$cycle.sd)/sqrt(dat$Number.of.individuals)
se.cycle[is.na(se.cycle)] <- mean(se.cycle, na.rm ='T')
names(se.cycle)<-dat$species



# evolutionary models. size/speed/speedCV adjusted, no sampling variance --------------------------------
registerDoMC(8)
registerDoParallel()
painttree <- list()
for (i in 1:100){
  painttree[[i]] <- paintSubTree(phylogeny.final.F[[i]], node=95, 0)
  painttree[[i]] <- paintSubTree(painttree[[i]], node=60, 0)
}

mass <- log10(dat$mass)
names(mass) <- dat$species
speed<- log10(dat$speed)
names(speed) <- dat$species
speedCV<- log10(dat$speedCV)
names(speedCV) <- dat$species
massspeed<-cbind(mass,speed, speedCV)

#peakbrake
BM.1.pb <- list()
BM.M.pb <- list()
OU.1.pb <- list()
OU.M.pb <- list()
aicw.pb <- list()
aic.pb<-list()
pb.adjust <- list()
pb.adjust<-foreach(i=1:100)%dopar%{pb.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, peakbrake)}
BM.1.pb<-foreach(i=1:100)%dopar%{BM.1.pb[[i]]<-mvBM(painttree[[i]], pb.adjust[[i]]$resid, model='BM1')}
BM.M.pb<-foreach(i=1:100)%dopar%{BM.M.pb[[i]]<-mvBM(painttree[[i]], pb.adjust[[i]]$resid, model='BMM')}
OU.1.pb<-foreach(i=1:100)%dopar%{OU.1.pb[[i]]<-mvOU(painttree[[i]], pb.adjust[[i]]$resid, model='OU1')}
OU.M.pb<-foreach(i=1:100)%dopar%{OU.M.pb[[i]]<-mvOU(painttree[[i]], pb.adjust[[i]]$resid, model='OUM')}
aicw.pb<-foreach(i=1:100)%dopar%{aic.pb[[i]] <- aic.w(c(BM.1.pb[[i]]$AICc, BM.M.pb[[i]]$AICc, OU.1.pb[[i]]$AICc, OU.M.pb[[i]]$AICc))}
aicw.pb.vect<-(unlist(aicw.pb))
BM.1.pb.w<-mean(aicw.pb.vect[seq(1, length(aicw.pb.vect), 4)])
BM.M.pb.w<-mean(aicw.pb.vect[seq(2, length(aicw.pb.vect), 4)])
OU.1.pb.w<-mean(aicw.pb.vect[seq(3, length(aicw.pb.vect), 4)])
OU.M.pb.w<-mean(aicw.pb.vect[seq(4, length(aicw.pb.vect), 4)])
signif(c(BM.1.pb.w, BM.M.pb.w, OU.1.pb.w, OU.M.pb.w), 2)
BM.1.pb.w.sd<-sd(aicw.pb.vect[seq(1, length(aicw.pb.vect), 4)])
BM.M.pb.w.sd<-sd(aicw.pb.vect[seq(2, length(aicw.pb.vect), 4)])
OU.1.pb.w.sd<-sd(aicw.pb.vect[seq(3, length(aicw.pb.vect), 4)])
OU.M.pb.w.sd<-sd(aicw.pb.vect[seq(4, length(aicw.pb.vect), 4)])
signif(c(BM.1.pb.w.sd, BM.M.pb.w.sd, OU.1.pb.w.sd, OU.M.pb.w.sd), 2)
sigma.pb <- list()
sigma.pb<-foreach(i=1:100)%dopar%{sigma.pb[[i]] <- c(BM.1.pb[[i]]$sigma, BM.M.pb[[i]]$sigma, OU.1.pb[[i]]$sigma, OU.M.pb[[i]]$sigma)}
sigma.pb.vect<-(unlist(sigma.pb))
BM.1.pb.sigma<-mean(sigma.pb.vect[seq(1, length(sigma.pb.vect), 5)])
BM.1.pb.sigma.sd<-sd(sigma.pb.vect[seq(1, length(sigma.pb.vect), 5)])
BM.M.pb.sigma<-mean(sigma.pb.vect[seq(2, length(sigma.pb.vect), 5)])
BM.M.pb.sigma.sd<-sd(sigma.pb.vect[seq(2, length(sigma.pb.vect), 5)])
BM.M.2.pb.sigma<-mean(sigma.pb.vect[seq(3, length(sigma.pb.vect), 5)])
BM.M.2.pb.sigma.sd<-sd(sigma.pb.vect[seq(3, length(sigma.pb.vect), 5)])
OU.1.pb.sigma<-mean(sigma.pb.vect[seq(4, length(sigma.pb.vect), 5)])
OU.1.pb.sigma.sd<-sd(sigma.pb.vect[seq(4, length(sigma.pb.vect), 5)])
OU.M.pb.sigma<-mean(sigma.pb.vect[seq(5, length(sigma.pb.vect), 5)])
OU.M.pb.sigma.sd<-sd(sigma.pb.vect[seq(5, length(sigma.pb.vect), 5)])
signif(c(BM.1.pb.sigma, BM.M.pb.sigma, BM.M.2.pb.sigma, OU.1.pb.sigma, OU.M.pb.sigma), 2)
signif(c(BM.1.pb.sigma.sd, BM.M.pb.sigma.sd, BM.M.2.pb.sigma.sd, OU.1.pb.sigma.sd, OU.M.pb.sigma.sd), 2)
theta.pb <- list()
theta.pb<-foreach(i=1:100)%dopar%{theta.pb[[i]] <- c(BM.1.pb[[i]]$theta, BM.M.pb[[i]]$theta, OU.1.pb[[i]]$theta, OU.M.pb[[i]]$theta)}
theta.pb.vect<-(unlist(theta.pb))
BM.1.pb.theta<-mean(theta.pb.vect[seq(1, length(theta.pb.vect), 5)])
BM.1.pb.theta.sd<-sd(theta.pb.vect[seq(1, length(theta.pb.vect), 5)])
BM.M.pb.theta<-mean(theta.pb.vect[seq(2, length(theta.pb.vect), 5)])
BM.M.pb.theta.sd<-sd(theta.pb.vect[seq(2, length(theta.pb.vect), 5)])
OU.1.pb.theta<-mean(theta.pb.vect[seq(3, length(theta.pb.vect), 5)])
OU.1.pb.theta.sd<-sd(theta.pb.vect[seq(3, length(theta.pb.vect), 5)])
OU.M.pb.theta<-mean(theta.pb.vect[seq(4, length(theta.pb.vect), 5)])
OU.M.pb.theta.sd<-sd(theta.pb.vect[seq(4, length(theta.pb.vect), 5)])
OU.M.2.pb.theta<-mean(theta.pb.vect[seq(5, length(theta.pb.vect), 5)])
OU.M.2.pb.theta.sd<-sd(theta.pb.vect[seq(5, length(theta.pb.vect), 5)])
signif(c(BM.1.pb.theta, BM.M.pb.theta, OU.1.pb.theta, OU.M.pb.theta, OU.M.2.pb.theta), 2)
signif(c(BM.1.pb.theta.sd, BM.M.pb.theta.sd, OU.1.pb.theta.sd, OU.M.pb.theta.sd, OU.M.2.pb.theta.sd), 2)
alpha.pb<-list()
alpha.pb<-foreach(i=1:100)%dopar%{alpha.pb[[i]] <- c(OU.1.pb[[i]]$alpha, OU.M.pb[[i]]$alpha)}
alpha.pb.vect<-(unlist(alpha.pb))
OU.1.pb.alpha<-mean(alpha.pb.vect[seq(1, length(alpha.pb.vect), 2)])
OU.1.pb.alpha.sd<-sd(alpha.pb.vect[seq(1, length(alpha.pb.vect), 2)])
OU.M.pb.alpha<-mean(alpha.pb.vect[seq(2, length(alpha.pb.vect), 2)])
OU.M.pb.alpha.sd<-sd(alpha.pb.vect[seq(2, length(alpha.pb.vect), 2)])
signif(c(OU.1.pb.alpha, OU.M.pb.alpha), 2)
signif(c(OU.1.pb.alpha.sd, OU.M.pb.alpha.sd), 2)
aic.pb<-foreach(i=1:100)%dopar%{aic.pb[[i]] <- c(BM.1.pb[[i]]$AICc, BM.M.pb[[i]]$AICc, OU.1.pb[[i]]$AICc, OU.M.pb[[i]]$AICc)}
aic.pb.vect<-(unlist(aic.pb))
BM.1.pb.aic<-mean(aic.pb.vect[seq(1, length(aic.pb.vect), 4)])
BM.1.pb.aic.sd<-sd(aic.pb.vect[seq(1, length(aic.pb.vect), 4)])
BM.M.pb.aic<-mean(aic.pb.vect[seq(2, length(aic.pb.vect), 4)])
BM.M.pb.aic.sd<-sd(aic.pb.vect[seq(2, length(aic.pb.vect), 4)])
OU.1.pb.aic<-mean(aic.pb.vect[seq(3, length(aic.pb.vect), 4)])
OU.1.pb.aic.sd<-sd(aic.pb.vect[seq(3, length(aic.pb.vect), 4)])
OU.M.pb.aic<-mean(aic.pb.vect[seq(4, length(aic.pb.vect), 4)])
OU.M.pb.aic.sd<-sd(aic.pb.vect[seq(4, length(aic.pb.vect), 4)])
signif(c(BM.1.pb.aic, BM.M.pb.aic, OU.1.pb.aic, OU.M.pb.aic), 4)
signif(c(BM.1.pb.aic.sd, BM.M.pb.aic.sd, OU.1.pb.aic.sd, OU.M.pb.aic.sd), 4)
power.error(OU.M.pb[[1]], BM.1.pb[[1]])


#peakaccel
BM.1.pa <- list()
BM.M.pa <- list()
OU.1.pa <- list()
OU.M.pa <- list()
aicw.pa <- list()
aic.pa<-list()
pa.adjust <- list()
pa.adjust<-foreach(i=1:100)%dopar%{pa.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, peakaccel)}
BM.1.pa<-foreach(i=1:100)%dopar%{BM.1.pa[[i]]<-mvBM(painttree[[i]], pa.adjust[[i]]$resid, model='BM1')}
BM.M.pa<-foreach(i=1:100)%dopar%{BM.M.pa[[i]]<-mvBM(painttree[[i]], pa.adjust[[i]]$resid, model='BMM')}
OU.1.pa<-foreach(i=1:100)%dopar%{OU.1.pa[[i]]<-mvOU(painttree[[i]], pa.adjust[[i]]$resid, model='OU1')}
OU.M.pa<-foreach(i=1:100)%dopar%{OU.M.pa[[i]]<-mvOU(painttree[[i]], pa.adjust[[i]]$resid, model='OUM')}
aicw.pa<-foreach(i=1:100)%dopar%{aic.pa[[i]] <- aic.w(c(BM.1.pa[[i]]$AICc, BM.M.pa[[i]]$AICc, OU.1.pa[[i]]$AICc, OU.M.pa[[i]]$AICc))}
aicw.pa.vect<-(unlist(aicw.pa))
BM.1.pa.w<-mean(aicw.pa.vect[seq(1, length(aicw.pa.vect), 4)])
BM.M.pa.w<-mean(aicw.pa.vect[seq(2, length(aicw.pa.vect), 4)])
OU.1.pa.w<-mean(aicw.pa.vect[seq(3, length(aicw.pa.vect), 4)])
OU.M.pa.w<-mean(aicw.pa.vect[seq(4, length(aicw.pa.vect), 4)])
signif(c(BM.1.pa.w, BM.M.pa.w, OU.1.pa.w, OU.M.pa.w), 2)
BM.1.pa.w.sd<-sd(aicw.pa.vect[seq(1, length(aicw.pa.vect), 4)])
BM.M.pa.w.sd<-sd(aicw.pa.vect[seq(2, length(aicw.pa.vect), 4)])
OU.1.pa.w.sd<-sd(aicw.pa.vect[seq(3, length(aicw.pa.vect), 4)])
OU.M.pa.w.sd<-sd(aicw.pa.vect[seq(4, length(aicw.pa.vect), 4)])
signif(c(BM.1.pa.w.sd, BM.M.pa.w.sd, OU.1.pa.w.sd, OU.M.pa.w.sd), 2)
sigma.pa <- list()
sigma.pa<-foreach(i=1:100)%dopar%{sigma.pa[[i]] <- c(BM.1.pa[[i]]$sigma, BM.M.pa[[i]]$sigma, OU.1.pa[[i]]$sigma, OU.M.pa[[i]]$sigma)}
sigma.pa.vect<-(unlist(sigma.pa))
BM.1.pa.sigma<-mean(sigma.pa.vect[seq(1, length(sigma.pa.vect), 5)])
BM.1.pa.sigma.sd<-sd(sigma.pa.vect[seq(1, length(sigma.pa.vect), 5)])
BM.M.pa.sigma<-mean(sigma.pa.vect[seq(2, length(sigma.pa.vect), 5)])
BM.M.pa.sigma.sd<-sd(sigma.pa.vect[seq(2, length(sigma.pa.vect), 5)])
BM.M.2.pa.sigma<-mean(sigma.pa.vect[seq(3, length(sigma.pa.vect), 5)])
BM.M.2.pa.sigma.sd<-sd(sigma.pa.vect[seq(3, length(sigma.pa.vect), 5)])
OU.1.pa.sigma<-mean(sigma.pa.vect[seq(4, length(sigma.pa.vect), 5)])
OU.1.pa.sigma.sd<-sd(sigma.pa.vect[seq(4, length(sigma.pa.vect), 5)])
OU.M.pa.sigma<-mean(sigma.pa.vect[seq(5, length(sigma.pa.vect), 5)])
OU.M.pa.sigma.sd<-sd(sigma.pa.vect[seq(5, length(sigma.pa.vect), 5)])
signif(c(BM.1.pa.sigma, BM.M.pa.sigma, BM.M.2.pa.sigma, OU.1.pa.sigma, OU.M.pa.sigma), 2)
signif(c(BM.1.pa.sigma.sd, BM.M.pa.sigma.sd, BM.M.2.pa.sigma.sd, OU.1.pa.sigma.sd, OU.M.pa.sigma.sd), 2)
theta.pa <- list()
theta.pa<-foreach(i=1:100)%dopar%{theta.pa[[i]] <- c(BM.1.pa[[i]]$theta, BM.M.pa[[i]]$theta, OU.1.pa[[i]]$theta, OU.M.pa[[i]]$theta)}
theta.pa.vect<-(unlist(theta.pa))
BM.1.pa.theta<-mean(theta.pa.vect[seq(1, length(theta.pa.vect), 5)])
BM.1.pa.theta.sd<-sd(theta.pa.vect[seq(1, length(theta.pa.vect), 5)])
BM.M.pa.theta<-mean(theta.pa.vect[seq(2, length(theta.pa.vect), 5)])
BM.M.pa.theta.sd<-sd(theta.pa.vect[seq(2, length(theta.pa.vect), 5)])
OU.1.pa.theta<-mean(theta.pa.vect[seq(3, length(theta.pa.vect), 5)])
OU.1.pa.theta.sd<-sd(theta.pa.vect[seq(3, length(theta.pa.vect), 5)])
OU.M.pa.theta<-mean(theta.pa.vect[seq(4, length(theta.pa.vect), 5)])
OU.M.pa.theta.sd<-sd(theta.pa.vect[seq(4, length(theta.pa.vect), 5)])
OU.M.2.pa.theta<-mean(theta.pa.vect[seq(5, length(theta.pa.vect), 5)])
OU.M.2.pa.theta.sd<-sd(theta.pa.vect[seq(5, length(theta.pa.vect), 5)])
signif(c(BM.1.pa.theta, BM.M.pa.theta, OU.1.pa.theta, OU.M.pa.theta, OU.M.2.pa.theta), 2)
signif(c(BM.1.pa.theta.sd, BM.M.pa.theta.sd, OU.1.pa.theta.sd, OU.M.pa.theta.sd, OU.M.2.pa.theta.sd), 2)
alpha.pa<-list()
alpha.pa<-foreach(i=1:100)%dopar%{alpha.pa[[i]] <- c(OU.1.pa[[i]]$alpha, OU.M.pa[[i]]$alpha)}
alpha.pa.vect<-(unlist(alpha.pa))
OU.1.pa.alpha<-mean(alpha.pa.vect[seq(1, length(alpha.pa.vect), 2)])
OU.1.pa.alpha.sd<-sd(alpha.pa.vect[seq(1, length(alpha.pa.vect), 2)])
OU.M.pa.alpha<-mean(alpha.pa.vect[seq(2, length(alpha.pa.vect), 2)])
OU.M.pa.alpha.sd<-sd(alpha.pa.vect[seq(2, length(alpha.pa.vect), 2)])
signif(c(OU.1.pa.alpha, OU.M.pa.alpha), 2)
signif(c(OU.1.pa.alpha.sd, OU.M.pa.alpha.sd), 2)
aic.pa<-foreach(i=1:100)%dopar%{aic.pa[[i]] <- c(BM.1.pa[[i]]$AICc, BM.M.pa[[i]]$AICc, OU.1.pa[[i]]$AICc, OU.M.pa[[i]]$AICc)}
aic.pa.vect<-(unlist(aic.pa))
BM.1.pa.aic<-mean(aic.pa.vect[seq(1, length(aic.pa.vect), 4)])
BM.1.pa.aic.sd<-sd(aic.pa.vect[seq(1, length(aic.pa.vect), 4)])
BM.M.pa.aic<-mean(aic.pa.vect[seq(2, length(aic.pa.vect), 4)])
BM.M.pa.aic.sd<-sd(aic.pa.vect[seq(2, length(aic.pa.vect), 4)])
OU.1.pa.aic<-mean(aic.pa.vect[seq(3, length(aic.pa.vect), 4)])
OU.1.pa.aic.sd<-sd(aic.pa.vect[seq(3, length(aic.pa.vect), 4)])
OU.M.pa.aic<-mean(aic.pa.vect[seq(4, length(aic.pa.vect), 4)])
OU.M.pa.aic.sd<-sd(aic.pa.vect[seq(4, length(aic.pa.vect), 4)])
signif(c(BM.1.pa.aic, BM.M.pa.aic, OU.1.pa.aic, OU.M.pa.aic), 4)
signif(c(BM.1.pa.aic.sd, BM.M.pa.aic.sd, OU.1.pa.aic.sd, OU.M.pa.aic.sd), 4)
power.error(OU.M.pa[[1]], BM.1.pa[[1]])

#peakmed
BM.1.pm <- list()
BM.M.pm <- list()
OU.1.pm <- list()
OU.M.pm <- list()
aicw.pm <- list()
aic.pm<-list()
pm.adjust <- list()
pm.adjust<-foreach(i=1:100)%dopar%{pm.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, peakmed)}
BM.1.pm<-foreach(i=1:100)%dopar%{BM.1.pm[[i]]<-mvBM(painttree[[i]], pm.adjust[[i]]$resid, model='BM1')}
BM.M.pm<-foreach(i=1:100)%dopar%{BM.M.pm[[i]]<-mvBM(painttree[[i]], pm.adjust[[i]]$resid, model='BMM')}
OU.1.pm<-foreach(i=1:100)%dopar%{OU.1.pm[[i]]<-mvOU(painttree[[i]], pm.adjust[[i]]$resid, model='OU1')}
OU.M.pm<-foreach(i=1:100)%dopar%{OU.M.pm[[i]]<-mvOU(painttree[[i]], pm.adjust[[i]]$resid, model='OUM')}
aicw.pm<-foreach(i=1:100)%dopar%{aic.pm[[i]] <- aic.w(c(BM.1.pm[[i]]$AICc, BM.M.pm[[i]]$AICc, OU.1.pm[[i]]$AICc, OU.M.pm[[i]]$AICc))}
aicw.pm.vect<-(unlist(aicw.pm))
BM.1.pm.w<-mean(aicw.pm.vect[seq(1, length(aicw.pm.vect), 4)])
BM.M.pm.w<-mean(aicw.pm.vect[seq(2, length(aicw.pm.vect), 4)])
OU.1.pm.w<-mean(aicw.pm.vect[seq(3, length(aicw.pm.vect), 4)])
OU.M.pm.w<-mean(aicw.pm.vect[seq(4, length(aicw.pm.vect), 4)])
signif(c(BM.1.pm.w, BM.M.pm.w, OU.1.pm.w, OU.M.pm.w), 2)
BM.1.pm.w.sd<-sd(aicw.pm.vect[seq(1, length(aicw.pm.vect), 4)])
BM.M.pm.w.sd<-sd(aicw.pm.vect[seq(2, length(aicw.pm.vect), 4)])
OU.1.pm.w.sd<-sd(aicw.pm.vect[seq(3, length(aicw.pm.vect), 4)])
OU.M.pm.w.sd<-sd(aicw.pm.vect[seq(4, length(aicw.pm.vect), 4)])
signif(c(BM.1.pm.w.sd, BM.M.pm.w.sd, OU.1.pm.w.sd, OU.M.pm.w.sd), 2)
sigma.pm <- list()
sigma.pm<-foreach(i=1:100)%dopar%{sigma.pm[[i]] <- c(BM.1.pm[[i]]$sigma, BM.M.pm[[i]]$sigma, OU.1.pm[[i]]$sigma, OU.M.pm[[i]]$sigma)}
sigma.pm.vect<-(unlist(sigma.pm))
BM.1.pm.sigma<-mean(sigma.pm.vect[seq(1, length(sigma.pm.vect), 5)])
BM.1.pm.sigma.sd<-sd(sigma.pm.vect[seq(1, length(sigma.pm.vect), 5)])
BM.M.pm.sigma<-mean(sigma.pm.vect[seq(2, length(sigma.pm.vect), 5)])
BM.M.pm.sigma.sd<-sd(sigma.pm.vect[seq(2, length(sigma.pm.vect), 5)])
BM.M.2.pm.sigma<-mean(sigma.pm.vect[seq(3, length(sigma.pm.vect), 5)])
BM.M.2.pm.sigma.sd<-sd(sigma.pm.vect[seq(3, length(sigma.pm.vect), 5)])
OU.1.pm.sigma<-mean(sigma.pm.vect[seq(4, length(sigma.pm.vect), 5)])
OU.1.pm.sigma.sd<-sd(sigma.pm.vect[seq(4, length(sigma.pm.vect), 5)])
OU.M.pm.sigma<-mean(sigma.pm.vect[seq(5, length(sigma.pm.vect), 5)])
OU.M.pm.sigma.sd<-sd(sigma.pm.vect[seq(5, length(sigma.pm.vect), 5)])
signif(c(BM.1.pm.sigma, BM.M.pm.sigma, BM.M.2.pm.sigma, OU.1.pm.sigma, OU.M.pm.sigma), 2)
signif(c(BM.1.pm.sigma.sd, BM.M.pm.sigma.sd, BM.M.2.pm.sigma.sd, OU.1.pm.sigma.sd, OU.M.pm.sigma.sd), 2)
theta.pm <- list()
theta.pm<-foreach(i=1:100)%dopar%{theta.pm[[i]] <- c(BM.1.pm[[i]]$theta, BM.M.pm[[i]]$theta, OU.1.pm[[i]]$theta, OU.M.pm[[i]]$theta)}
theta.pm.vect<-(unlist(theta.pm))
BM.1.pm.theta<-mean(theta.pm.vect[seq(1, length(theta.pm.vect), 5)])
BM.1.pm.theta.sd<-sd(theta.pm.vect[seq(1, length(theta.pm.vect), 5)])
BM.M.pm.theta<-mean(theta.pm.vect[seq(2, length(theta.pm.vect), 5)])
BM.M.pm.theta.sd<-sd(theta.pm.vect[seq(2, length(theta.pm.vect), 5)])
OU.1.pm.theta<-mean(theta.pm.vect[seq(3, length(theta.pm.vect), 5)])
OU.1.pm.theta.sd<-sd(theta.pm.vect[seq(3, length(theta.pm.vect), 5)])
OU.M.pm.theta<-mean(theta.pm.vect[seq(4, length(theta.pm.vect), 5)])
OU.M.pm.theta.sd<-sd(theta.pm.vect[seq(4, length(theta.pm.vect), 5)])
OU.M.2.pm.theta<-mean(theta.pm.vect[seq(5, length(theta.pm.vect), 5)])
OU.M.2.pm.theta.sd<-sd(theta.pm.vect[seq(5, length(theta.pm.vect), 5)])
signif(c(BM.1.pm.theta, BM.M.pm.theta, OU.1.pm.theta, OU.M.pm.theta, OU.M.2.pm.theta), 2)
signif(c(BM.1.pm.theta.sd, BM.M.pm.theta.sd, OU.1.pm.theta.sd, OU.M.pm.theta.sd, OU.M.2.pm.theta.sd), 2)
alpha.pm<-list()
alpha.pm<-foreach(i=1:100)%dopar%{alpha.pm[[i]] <- c(OU.1.pm[[i]]$alpha, OU.M.pm[[i]]$alpha)}
alpha.pm.vect<-(unlist(alpha.pm))
OU.1.pm.alpha<-mean(alpha.pm.vect[seq(1, length(alpha.pm.vect), 2)])
OU.1.pm.alpha.sd<-sd(alpha.pm.vect[seq(1, length(alpha.pm.vect), 2)])
OU.M.pm.alpha<-mean(alpha.pm.vect[seq(2, length(alpha.pm.vect), 2)])
OU.M.pm.alpha.sd<-sd(alpha.pm.vect[seq(2, length(alpha.pm.vect), 2)])
signif(c(OU.1.pm.alpha, OU.M.pm.alpha), 2)
signif(c(OU.1.pm.alpha.sd, OU.M.pm.alpha.sd), 2)
aic.pm<-foreach(i=1:100)%dopar%{aic.pm[[i]] <- c(BM.1.pm[[i]]$AICc, BM.M.pm[[i]]$AICc, OU.1.pm[[i]]$AICc, OU.M.pm[[i]]$AICc)}
aic.pm.vect<-(unlist(aic.pm))
BM.1.pm.aic<-mean(aic.pm.vect[seq(1, length(aic.pm.vect), 4)])
BM.1.pm.aic.sd<-sd(aic.pm.vect[seq(1, length(aic.pm.vect), 4)])
BM.M.pm.aic<-mean(aic.pm.vect[seq(2, length(aic.pm.vect), 4)])
BM.M.pm.aic.sd<-sd(aic.pm.vect[seq(2, length(aic.pm.vect), 4)])
OU.1.pm.aic<-mean(aic.pm.vect[seq(3, length(aic.pm.vect), 4)])
OU.1.pm.aic.sd<-sd(aic.pm.vect[seq(3, length(aic.pm.vect), 4)])
OU.M.pm.aic<-mean(aic.pm.vect[seq(4, length(aic.pm.vect), 4)])
OU.M.pm.aic.sd<-sd(aic.pm.vect[seq(4, length(aic.pm.vect), 4)])
signif(c(BM.1.pm.aic, BM.M.pm.aic, OU.1.pm.aic, OU.M.pm.aic), 4)
signif(c(BM.1.pm.aic.sd, BM.M.pm.aic.sd, OU.1.pm.aic.sd, OU.M.pm.aic.sd), 4)
power.error(OU.M.pm[[1]], BM.1.pm[[1]])

#peaklat
BM.1.pl <- list()
BM.M.pl <- list()
OU.1.pl <- list()
OU.M.pl <- list()
aicw.pl <- list()
aic.pl<-list()
pl.adjust <- list()
pl.adjust<-foreach(i=1:100)%dopar%{pl.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, peaklat)}
BM.1.pl<-foreach(i=1:100)%dopar%{BM.1.pl[[i]]<-mvBM(painttree[[i]], pl.adjust[[i]]$resid, model='BM1')}
BM.M.pl<-foreach(i=1:100)%dopar%{BM.M.pl[[i]]<-mvBM(painttree[[i]], pl.adjust[[i]]$resid, model='BMM')}
OU.1.pl<-foreach(i=1:100)%dopar%{OU.1.pl[[i]]<-mvOU(painttree[[i]], pl.adjust[[i]]$resid, model='OU1')}
OU.M.pl<-foreach(i=1:100)%dopar%{OU.M.pl[[i]]<-mvOU(painttree[[i]], pl.adjust[[i]]$resid, model='OUM')}
aicw.pl<-foreach(i=1:100)%dopar%{aic.pl[[i]] <- aic.w(c(BM.1.pl[[i]]$AICc, BM.M.pl[[i]]$AICc, OU.1.pl[[i]]$AICc, OU.M.pl[[i]]$AICc))}
aicw.pl.vect<-(unlist(aicw.pl))
BM.1.pl.w<-mean(aicw.pl.vect[seq(1, length(aicw.pl.vect), 4)])
BM.M.pl.w<-mean(aicw.pl.vect[seq(2, length(aicw.pl.vect), 4)])
OU.1.pl.w<-mean(aicw.pl.vect[seq(3, length(aicw.pl.vect), 4)])
OU.M.pl.w<-mean(aicw.pl.vect[seq(4, length(aicw.pl.vect), 4)])
signif(c(BM.1.pl.w, BM.M.pl.w, OU.1.pl.w, OU.M.pl.w), 2)
BM.1.pl.w.sd<-sd(aicw.pl.vect[seq(1, length(aicw.pl.vect), 4)])
BM.M.pl.w.sd<-sd(aicw.pl.vect[seq(2, length(aicw.pl.vect), 4)])
OU.1.pl.w.sd<-sd(aicw.pl.vect[seq(3, length(aicw.pl.vect), 4)])
OU.M.pl.w.sd<-sd(aicw.pl.vect[seq(4, length(aicw.pl.vect), 4)])
signif(c(BM.1.pl.w.sd, BM.M.pl.w.sd, OU.1.pl.w.sd, OU.M.pl.w.sd), 2)
sigma.pl <- list()
sigma.pl<-foreach(i=1:100)%dopar%{sigma.pl[[i]] <- c(BM.1.pl[[i]]$sigma, BM.M.pl[[i]]$sigma, OU.1.pl[[i]]$sigma, OU.M.pl[[i]]$sigma)}
sigma.pl.vect<-(unlist(sigma.pl))
BM.1.pl.sigma<-mean(sigma.pl.vect[seq(1, length(sigma.pl.vect), 5)])
BM.1.pl.sigma.sd<-sd(sigma.pl.vect[seq(1, length(sigma.pl.vect), 5)])
BM.M.pl.sigma<-mean(sigma.pl.vect[seq(2, length(sigma.pl.vect), 5)])
BM.M.pl.sigma.sd<-sd(sigma.pl.vect[seq(2, length(sigma.pl.vect), 5)])
BM.M.2.pl.sigma<-mean(sigma.pl.vect[seq(3, length(sigma.pl.vect), 5)])
BM.M.2.pl.sigma.sd<-sd(sigma.pl.vect[seq(3, length(sigma.pl.vect), 5)])
OU.1.pl.sigma<-mean(sigma.pl.vect[seq(4, length(sigma.pl.vect), 5)])
OU.1.pl.sigma.sd<-sd(sigma.pl.vect[seq(4, length(sigma.pl.vect), 5)])
OU.M.pl.sigma<-mean(sigma.pl.vect[seq(5, length(sigma.pl.vect), 5)])
OU.M.pl.sigma.sd<-sd(sigma.pl.vect[seq(5, length(sigma.pl.vect), 5)])
signif(c(BM.1.pl.sigma, BM.M.pl.sigma, BM.M.2.pl.sigma, OU.1.pl.sigma, OU.M.pl.sigma), 2)
signif(c(BM.1.pl.sigma.sd, BM.M.pl.sigma.sd, BM.M.2.pl.sigma.sd, OU.1.pl.sigma.sd, OU.M.pl.sigma.sd), 2)
theta.pl <- list()
theta.pl<-foreach(i=1:100)%dopar%{theta.pl[[i]] <- c(BM.1.pl[[i]]$theta, BM.M.pl[[i]]$theta, OU.1.pl[[i]]$theta, OU.M.pl[[i]]$theta)}
theta.pl.vect<-(unlist(theta.pl))
BM.1.pl.theta<-mean(theta.pl.vect[seq(1, length(theta.pl.vect), 5)])
BM.1.pl.theta.sd<-sd(theta.pl.vect[seq(1, length(theta.pl.vect), 5)])
BM.M.pl.theta<-mean(theta.pl.vect[seq(2, length(theta.pl.vect), 5)])
BM.M.pl.theta.sd<-sd(theta.pl.vect[seq(2, length(theta.pl.vect), 5)])
OU.1.pl.theta<-mean(theta.pl.vect[seq(3, length(theta.pl.vect), 5)])
OU.1.pl.theta.sd<-sd(theta.pl.vect[seq(3, length(theta.pl.vect), 5)])
OU.M.pl.theta<-mean(theta.pl.vect[seq(4, length(theta.pl.vect), 5)])
OU.M.pl.theta.sd<-sd(theta.pl.vect[seq(4, length(theta.pl.vect), 5)])
OU.M.2.pl.theta<-mean(theta.pl.vect[seq(5, length(theta.pl.vect), 5)])
OU.M.2.pl.theta.sd<-sd(theta.pl.vect[seq(5, length(theta.pl.vect), 5)])
signif(c(BM.1.pl.theta, BM.M.pl.theta, OU.1.pl.theta, OU.M.pl.theta, OU.M.2.pl.theta), 2)
signif(c(BM.1.pl.theta.sd, BM.M.pl.theta.sd, OU.1.pl.theta.sd, OU.M.pl.theta.sd, OU.M.2.pl.theta.sd), 2)
alpha.pl<-list()
alpha.pl<-foreach(i=1:100)%dopar%{alpha.pl[[i]] <- c(OU.1.pl[[i]]$alpha, OU.M.pl[[i]]$alpha)}
alpha.pl.vect<-(unlist(alpha.pl))
OU.1.pl.alpha<-mean(alpha.pl.vect[seq(1, length(alpha.pl.vect), 2)])
OU.1.pl.alpha.sd<-sd(alpha.pl.vect[seq(1, length(alpha.pl.vect), 2)])
OU.M.pl.alpha<-mean(alpha.pl.vect[seq(2, length(alpha.pl.vect), 2)])
OU.M.pl.alpha.sd<-sd(alpha.pl.vect[seq(2, length(alpha.pl.vect), 2)])
signif(c(OU.1.pl.alpha, OU.M.pl.alpha), 2)
signif(c(OU.1.pl.alpha.sd, OU.M.pl.alpha.sd), 2)
aic.pl<-foreach(i=1:100)%dopar%{aic.pl[[i]] <- c(BM.1.pl[[i]]$AICc, BM.M.pl[[i]]$AICc, OU.1.pl[[i]]$AICc, OU.M.pl[[i]]$AICc)}
aic.pl.vect<-(unlist(aic.pl))
BM.1.pl.aic<-mean(aic.pl.vect[seq(1, length(aic.pl.vect), 4)])
BM.1.pl.aic.sd<-sd(aic.pl.vect[seq(1, length(aic.pl.vect), 4)])
BM.M.pl.aic<-mean(aic.pl.vect[seq(2, length(aic.pl.vect), 4)])
BM.M.pl.aic.sd<-sd(aic.pl.vect[seq(2, length(aic.pl.vect), 4)])
OU.1.pl.aic<-mean(aic.pl.vect[seq(3, length(aic.pl.vect), 4)])
OU.1.pl.aic.sd<-sd(aic.pl.vect[seq(3, length(aic.pl.vect), 4)])
OU.M.pl.aic<-mean(aic.pl.vect[seq(4, length(aic.pl.vect), 4)])
OU.M.pl.aic.sd<-sd(aic.pl.vect[seq(4, length(aic.pl.vect), 4)])
signif(c(BM.1.pl.aic, BM.M.pl.aic, OU.1.pl.aic, OU.M.pl.aic), 4)
signif(c(BM.1.pl.aic.sd, BM.M.pl.aic.sd, OU.1.pl.aic.sd, OU.M.pl.aic.sd), 4)
power.error(OU.M.pl[[1]], BM.1.pl[[1]])

#peakv
BM.1.pv <- list()
BM.M.pv <- list()
OU.1.pv <- list()
OU.M.pv <- list()
aicw.pv <- list()
aic.pv<-list()
pv.adjust <- list()
pv.adjust<-foreach(i=1:100)%dopar%{pv.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, peakv)}
BM.1.pv<-foreach(i=1:100)%dopar%{BM.1.pv[[i]]<-mvBM(painttree[[i]], pv.adjust[[i]]$resid, model='BM1')}
BM.M.pv<-foreach(i=1:100)%dopar%{BM.M.pv[[i]]<-mvBM(painttree[[i]], pv.adjust[[i]]$resid, model='BMM')}
OU.1.pv<-foreach(i=1:100)%dopar%{OU.1.pv[[i]]<-mvOU(painttree[[i]], pv.adjust[[i]]$resid, model='OU1')}
OU.M.pv<-foreach(i=1:100)%dopar%{OU.M.pv[[i]]<-mvOU(painttree[[i]], pv.adjust[[i]]$resid, model='OUM')}
aicw.pv<-foreach(i=1:100)%dopar%{aic.pv[[i]] <- aic.w(c(BM.1.pv[[i]]$AICc, BM.M.pv[[i]]$AICc, OU.1.pv[[i]]$AICc, OU.M.pv[[i]]$AICc))}
aicw.pv.vect<-(unlist(aicw.pv))
BM.1.pv.w<-mean(aicw.pv.vect[seq(1, length(aicw.pv.vect), 4)])
BM.M.pv.w<-mean(aicw.pv.vect[seq(2, length(aicw.pv.vect), 4)])
OU.1.pv.w<-mean(aicw.pv.vect[seq(3, length(aicw.pv.vect), 4)])
OU.M.pv.w<-mean(aicw.pv.vect[seq(4, length(aicw.pv.vect), 4)])
signif(c(BM.1.pv.w, BM.M.pv.w, OU.1.pv.w, OU.M.pv.w), 2)
BM.1.pv.w.sd<-sd(aicw.pv.vect[seq(1, length(aicw.pv.vect), 4)])
BM.M.pv.w.sd<-sd(aicw.pv.vect[seq(2, length(aicw.pv.vect), 4)])
OU.1.pv.w.sd<-sd(aicw.pv.vect[seq(3, length(aicw.pv.vect), 4)])
OU.M.pv.w.sd<-sd(aicw.pv.vect[seq(4, length(aicw.pv.vect), 4)])
signif(c(BM.1.pv.w.sd, BM.M.pv.w.sd, OU.1.pv.w.sd, OU.M.pv.w.sd), 2)
sigma.pv <- list()
sigma.pv<-foreach(i=1:100)%dopar%{sigma.pv[[i]] <- c(BM.1.pv[[i]]$sigma, BM.M.pv[[i]]$sigma, OU.1.pv[[i]]$sigma, OU.M.pv[[i]]$sigma)}
sigma.pv.vect<-(unlist(sigma.pv))
BM.1.pv.sigma<-mean(sigma.pv.vect[seq(1, length(sigma.pv.vect), 5)])
BM.1.pv.sigma.sd<-sd(sigma.pv.vect[seq(1, length(sigma.pv.vect), 5)])
BM.M.pv.sigma<-mean(sigma.pv.vect[seq(2, length(sigma.pv.vect), 5)])
BM.M.pv.sigma.sd<-sd(sigma.pv.vect[seq(2, length(sigma.pv.vect), 5)])
BM.M.2.pv.sigma<-mean(sigma.pv.vect[seq(3, length(sigma.pv.vect), 5)])
BM.M.2.pv.sigma.sd<-sd(sigma.pv.vect[seq(3, length(sigma.pv.vect), 5)])
OU.1.pv.sigma<-mean(sigma.pv.vect[seq(4, length(sigma.pv.vect), 5)])
OU.1.pv.sigma.sd<-sd(sigma.pv.vect[seq(4, length(sigma.pv.vect), 5)])
OU.M.pv.sigma<-mean(sigma.pv.vect[seq(5, length(sigma.pv.vect), 5)])
OU.M.pv.sigma.sd<-sd(sigma.pv.vect[seq(5, length(sigma.pv.vect), 5)])
signif(c(BM.1.pv.sigma, BM.M.pv.sigma, BM.M.2.pv.sigma, OU.1.pv.sigma, OU.M.pv.sigma), 2)
signif(c(BM.1.pv.sigma.sd, BM.M.pv.sigma.sd, BM.M.2.pv.sigma.sd, OU.1.pv.sigma.sd, OU.M.pv.sigma.sd), 2)
theta.pv <- list()
theta.pv<-foreach(i=1:100)%dopar%{theta.pv[[i]] <- c(BM.1.pv[[i]]$theta, BM.M.pv[[i]]$theta, OU.1.pv[[i]]$theta, OU.M.pv[[i]]$theta)}
theta.pv.vect<-(unlist(theta.pv))
BM.1.pv.theta<-mean(theta.pv.vect[seq(1, length(theta.pv.vect), 5)])
BM.1.pv.theta.sd<-sd(theta.pv.vect[seq(1, length(theta.pv.vect), 5)])
BM.M.pv.theta<-mean(theta.pv.vect[seq(2, length(theta.pv.vect), 5)])
BM.M.pv.theta.sd<-sd(theta.pv.vect[seq(2, length(theta.pv.vect), 5)])
OU.1.pv.theta<-mean(theta.pv.vect[seq(3, length(theta.pv.vect), 5)])
OU.1.pv.theta.sd<-sd(theta.pv.vect[seq(3, length(theta.pv.vect), 5)])
OU.M.pv.theta<-mean(theta.pv.vect[seq(4, length(theta.pv.vect), 5)])
OU.M.pv.theta.sd<-sd(theta.pv.vect[seq(4, length(theta.pv.vect), 5)])
OU.M.2.pv.theta<-mean(theta.pv.vect[seq(5, length(theta.pv.vect), 5)])
OU.M.2.pv.theta.sd<-sd(theta.pv.vect[seq(5, length(theta.pv.vect), 5)])
signif(c(BM.1.pv.theta, BM.M.pv.theta, OU.1.pv.theta, OU.M.pv.theta, OU.M.2.pv.theta), 2)
signif(c(BM.1.pv.theta.sd, BM.M.pv.theta.sd, OU.1.pv.theta.sd, OU.M.pv.theta.sd, OU.M.2.pv.theta.sd), 2)
alpha.pv<-list()
alpha.pv<-foreach(i=1:100)%dopar%{alpha.pv[[i]] <- c(OU.1.pv[[i]]$alpha, OU.M.pv[[i]]$alpha)}
alpha.pv.vect<-(unlist(alpha.pv))
OU.1.pv.alpha<-mean(alpha.pv.vect[seq(1, length(alpha.pv.vect), 2)])
OU.1.pv.alpha.sd<-sd(alpha.pv.vect[seq(1, length(alpha.pv.vect), 2)])
OU.M.pv.alpha<-mean(alpha.pv.vect[seq(2, length(alpha.pv.vect), 2)])
OU.M.pv.alpha.sd<-sd(alpha.pv.vect[seq(2, length(alpha.pv.vect), 2)])
signif(c(OU.1.pv.alpha, OU.M.pv.alpha), 2)
signif(c(OU.1.pv.alpha.sd, OU.M.pv.alpha.sd), 2)
aic.pv<-foreach(i=1:100)%dopar%{aic.pv[[i]] <- c(BM.1.pv[[i]]$AICc, BM.M.pv[[i]]$AICc, OU.1.pv[[i]]$AICc, OU.M.pv[[i]]$AICc)}
aic.pv.vect<-(unlist(aic.pv))
BM.1.pv.aic<-mean(aic.pv.vect[seq(1, length(aic.pv.vect), 4)])
BM.1.pv.aic.sd<-sd(aic.pv.vect[seq(1, length(aic.pv.vect), 4)])
BM.M.pv.aic<-mean(aic.pv.vect[seq(2, length(aic.pv.vect), 4)])
BM.M.pv.aic.sd<-sd(aic.pv.vect[seq(2, length(aic.pv.vect), 4)])
OU.1.pv.aic<-mean(aic.pv.vect[seq(3, length(aic.pv.vect), 4)])
OU.1.pv.aic.sd<-sd(aic.pv.vect[seq(3, length(aic.pv.vect), 4)])
OU.M.pv.aic<-mean(aic.pv.vect[seq(4, length(aic.pv.vect), 4)])
OU.M.pv.aic.sd<-sd(aic.pv.vect[seq(4, length(aic.pv.vect), 4)])
signif(c(BM.1.pv.aic, BM.M.pv.aic, OU.1.pv.aic, OU.M.pv.aic), 4)
signif(c(BM.1.pv.aic.sd, BM.M.pv.aic.sd, OU.1.pv.aic.sd, OU.M.pv.aic.sd), 4)
power.error(OU.M.pv[[1]], BM.1.pv[[1]])

#tbrake
BM.1.tb <- list()
BM.M.tb <- list()
OU.1.tb <- list()
OU.M.tb <- list()
aicw.tb <- list()
aic.tb<-list()
tb.adjust <- list()
tb.adjust<-foreach(i=1:100)%dopar%{tb.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, tbrake)}
BM.1.tb<-foreach(i=1:100)%dopar%{BM.1.tb[[i]]<-mvBM(painttree[[i]], tb.adjust[[i]]$resid, model='BM1')}
BM.M.tb<-foreach(i=1:100)%dopar%{BM.M.tb[[i]]<-mvBM(painttree[[i]], tb.adjust[[i]]$resid, model='BMM')}
OU.1.tb<-foreach(i=1:100)%dopar%{OU.1.tb[[i]]<-mvOU(painttree[[i]], tb.adjust[[i]]$resid, model='OU1')}
OU.M.tb<-foreach(i=1:100)%dopar%{OU.M.tb[[i]]<-mvOU(painttree[[i]], tb.adjust[[i]]$resid, model='OUM')}
aicw.tb<-foreach(i=1:100)%dopar%{aic.tb[[i]] <- aic.w(c(BM.1.tb[[i]]$AICc, BM.M.tb[[i]]$AICc, OU.1.tb[[i]]$AICc, OU.M.tb[[i]]$AICc))}
aicw.tb.vect<-(unlist(aicw.tb))
BM.1.tb.w<-mean(aicw.tb.vect[seq(1, length(aicw.tb.vect), 4)])
BM.M.tb.w<-mean(aicw.tb.vect[seq(2, length(aicw.tb.vect), 4)])
OU.1.tb.w<-mean(aicw.tb.vect[seq(3, length(aicw.tb.vect), 4)])
OU.M.tb.w<-mean(aicw.tb.vect[seq(4, length(aicw.tb.vect), 4)])
signif(c(BM.1.tb.w, BM.M.tb.w, OU.1.tb.w, OU.M.tb.w), 2)
BM.1.tb.w.sd<-sd(aicw.tb.vect[seq(1, length(aicw.tb.vect), 4)])
BM.M.tb.w.sd<-sd(aicw.tb.vect[seq(2, length(aicw.tb.vect), 4)])
OU.1.tb.w.sd<-sd(aicw.tb.vect[seq(3, length(aicw.tb.vect), 4)])
OU.M.tb.w.sd<-sd(aicw.tb.vect[seq(4, length(aicw.tb.vect), 4)])
signif(c(BM.1.tb.w.sd, BM.M.tb.w.sd, OU.1.tb.w.sd, OU.M.tb.w.sd), 2)
sigma.tb <- list()
sigma.tb<-foreach(i=1:100)%dopar%{sigma.tb[[i]] <- c(BM.1.tb[[i]]$sigma, BM.M.tb[[i]]$sigma, OU.1.tb[[i]]$sigma, OU.M.tb[[i]]$sigma)}
sigma.tb.vect<-(unlist(sigma.tb))
BM.1.tb.sigma<-mean(sigma.tb.vect[seq(1, length(sigma.tb.vect), 5)])
BM.1.tb.sigma.sd<-sd(sigma.tb.vect[seq(1, length(sigma.tb.vect), 5)])
BM.M.tb.sigma<-mean(sigma.tb.vect[seq(2, length(sigma.tb.vect), 5)])
BM.M.tb.sigma.sd<-sd(sigma.tb.vect[seq(2, length(sigma.tb.vect), 5)])
BM.M.2.tb.sigma<-mean(sigma.tb.vect[seq(3, length(sigma.tb.vect), 5)])
BM.M.2.tb.sigma.sd<-sd(sigma.tb.vect[seq(3, length(sigma.tb.vect), 5)])
OU.1.tb.sigma<-mean(sigma.tb.vect[seq(4, length(sigma.tb.vect), 5)])
OU.1.tb.sigma.sd<-sd(sigma.tb.vect[seq(4, length(sigma.tb.vect), 5)])
OU.M.tb.sigma<-mean(sigma.tb.vect[seq(5, length(sigma.tb.vect), 5)])
OU.M.tb.sigma.sd<-sd(sigma.tb.vect[seq(5, length(sigma.tb.vect), 5)])
signif(c(BM.1.tb.sigma, BM.M.tb.sigma, BM.M.2.tb.sigma, OU.1.tb.sigma, OU.M.tb.sigma), 2)
signif(c(BM.1.tb.sigma.sd, BM.M.tb.sigma.sd, BM.M.2.tb.sigma.sd, OU.1.tb.sigma.sd, OU.M.tb.sigma.sd), 2)
theta.tb <- list()
theta.tb<-foreach(i=1:100)%dopar%{theta.tb[[i]] <- c(BM.1.tb[[i]]$theta, BM.M.tb[[i]]$theta, OU.1.tb[[i]]$theta, OU.M.tb[[i]]$theta)}
theta.tb.vect<-(unlist(theta.tb))
BM.1.tb.theta<-mean(theta.tb.vect[seq(1, length(theta.tb.vect), 5)])
BM.1.tb.theta.sd<-sd(theta.tb.vect[seq(1, length(theta.tb.vect), 5)])
BM.M.tb.theta<-mean(theta.tb.vect[seq(2, length(theta.tb.vect), 5)])
BM.M.tb.theta.sd<-sd(theta.tb.vect[seq(2, length(theta.tb.vect), 5)])
OU.1.tb.theta<-mean(theta.tb.vect[seq(3, length(theta.tb.vect), 5)])
OU.1.tb.theta.sd<-sd(theta.tb.vect[seq(3, length(theta.tb.vect), 5)])
OU.M.tb.theta<-mean(theta.tb.vect[seq(4, length(theta.tb.vect), 5)])
OU.M.tb.theta.sd<-sd(theta.tb.vect[seq(4, length(theta.tb.vect), 5)])
OU.M.2.tb.theta<-mean(theta.tb.vect[seq(5, length(theta.tb.vect), 5)])
OU.M.2.tb.theta.sd<-sd(theta.tb.vect[seq(5, length(theta.tb.vect), 5)])
signif(c(BM.1.tb.theta, BM.M.tb.theta, OU.1.tb.theta, OU.M.tb.theta, OU.M.2.tb.theta), 2)
signif(c(BM.1.tb.theta.sd, BM.M.tb.theta.sd, OU.1.tb.theta.sd, OU.M.tb.theta.sd, OU.M.2.tb.theta.sd), 2)
alpha.tb<-list()
alpha.tb<-foreach(i=1:100)%dopar%{alpha.tb[[i]] <- c(OU.1.tb[[i]]$alpha, OU.M.tb[[i]]$alpha)}
alpha.tb.vect<-(unlist(alpha.tb))
OU.1.tb.alpha<-mean(alpha.tb.vect[seq(1, length(alpha.tb.vect), 2)])
OU.1.tb.alpha.sd<-sd(alpha.tb.vect[seq(1, length(alpha.tb.vect), 2)])
OU.M.tb.alpha<-mean(alpha.tb.vect[seq(2, length(alpha.tb.vect), 2)])
OU.M.tb.alpha.sd<-sd(alpha.tb.vect[seq(2, length(alpha.tb.vect), 2)])
signif(c(OU.1.tb.alpha, OU.M.tb.alpha), 2)
signif(c(OU.1.tb.alpha.sd, OU.M.tb.alpha.sd), 2)
aic.tb<-foreach(i=1:100)%dopar%{aic.tb[[i]] <- c(BM.1.tb[[i]]$AICc, BM.M.tb[[i]]$AICc, OU.1.tb[[i]]$AICc, OU.M.tb[[i]]$AICc)}
aic.tb.vect<-(unlist(aic.tb))
BM.1.tb.aic<-mean(aic.tb.vect[seq(1, length(aic.tb.vect), 4)])
BM.1.tb.aic.sd<-sd(aic.tb.vect[seq(1, length(aic.tb.vect), 4)])
BM.M.tb.aic<-mean(aic.tb.vect[seq(2, length(aic.tb.vect), 4)])
BM.M.tb.aic.sd<-sd(aic.tb.vect[seq(2, length(aic.tb.vect), 4)])
OU.1.tb.aic<-mean(aic.tb.vect[seq(3, length(aic.tb.vect), 4)])
OU.1.tb.aic.sd<-sd(aic.tb.vect[seq(3, length(aic.tb.vect), 4)])
OU.M.tb.aic<-mean(aic.tb.vect[seq(4, length(aic.tb.vect), 4)])
OU.M.tb.aic.sd<-sd(aic.tb.vect[seq(4, length(aic.tb.vect), 4)])
signif(c(BM.1.tb.aic, BM.M.tb.aic, OU.1.tb.aic, OU.M.tb.aic), 4)
signif(c(BM.1.tb.aic.sd, BM.M.tb.aic.sd, OU.1.tb.aic.sd, OU.M.tb.aic.sd), 4)
power.error(OU.M.tb[[1]], BM.1.tb[[1]])

#taccel
BM.1.ta <- list()
BM.M.ta <- list()
OU.1.ta <- list()
OU.M.ta <- list()
aicw.ta <- list()
aic.ta<-list()
ta.adjust <- list()
ta.adjust<-foreach(i=1:100)%dopar%{ta.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, taccel)}
BM.1.ta<-foreach(i=1:100)%dopar%{BM.1.ta[[i]]<-mvBM(painttree[[i]], ta.adjust[[i]]$resid, model='BM1')}
BM.M.ta<-foreach(i=1:100)%dopar%{BM.M.ta[[i]]<-mvBM(painttree[[i]], ta.adjust[[i]]$resid, model='BMM')}
OU.1.ta<-foreach(i=1:100)%dopar%{OU.1.ta[[i]]<-mvOU(painttree[[i]], ta.adjust[[i]]$resid, model='OU1')}
OU.M.ta<-foreach(i=1:100)%dopar%{OU.M.ta[[i]]<-mvOU(painttree[[i]], ta.adjust[[i]]$resid, model='OUM')}
aicw.ta<-foreach(i=1:100)%dopar%{aic.ta[[i]] <- aic.w(c(BM.1.ta[[i]]$AICc, BM.M.ta[[i]]$AICc, OU.1.ta[[i]]$AICc, OU.M.ta[[i]]$AICc))}
aicw.ta.vect<-(unlist(aicw.ta))
BM.1.ta.w<-mean(aicw.ta.vect[seq(1, length(aicw.ta.vect), 4)])
BM.M.ta.w<-mean(aicw.ta.vect[seq(2, length(aicw.ta.vect), 4)])
OU.1.ta.w<-mean(aicw.ta.vect[seq(3, length(aicw.ta.vect), 4)])
OU.M.ta.w<-mean(aicw.ta.vect[seq(4, length(aicw.ta.vect), 4)])
signif(c(BM.1.ta.w, BM.M.ta.w, OU.1.ta.w, OU.M.ta.w), 2)
BM.1.ta.w.sd<-sd(aicw.ta.vect[seq(1, length(aicw.ta.vect), 4)])
BM.M.ta.w.sd<-sd(aicw.ta.vect[seq(2, length(aicw.ta.vect), 4)])
OU.1.ta.w.sd<-sd(aicw.ta.vect[seq(3, length(aicw.ta.vect), 4)])
OU.M.ta.w.sd<-sd(aicw.ta.vect[seq(4, length(aicw.ta.vect), 4)])
signif(c(BM.1.ta.w.sd, BM.M.ta.w.sd, OU.1.ta.w.sd, OU.M.ta.w.sd), 2)
sigma.ta <- list()
sigma.ta<-foreach(i=1:100)%dopar%{sigma.ta[[i]] <- c(BM.1.ta[[i]]$sigma, BM.M.ta[[i]]$sigma, OU.1.ta[[i]]$sigma, OU.M.ta[[i]]$sigma)}
sigma.ta.vect<-(unlist(sigma.ta))
BM.1.ta.sigma<-mean(sigma.ta.vect[seq(1, length(sigma.ta.vect), 5)])
BM.1.ta.sigma.sd<-sd(sigma.ta.vect[seq(1, length(sigma.ta.vect), 5)])
BM.M.ta.sigma<-mean(sigma.ta.vect[seq(2, length(sigma.ta.vect), 5)])
BM.M.ta.sigma.sd<-sd(sigma.ta.vect[seq(2, length(sigma.ta.vect), 5)])
BM.M.2.ta.sigma<-mean(sigma.ta.vect[seq(3, length(sigma.ta.vect), 5)])
BM.M.2.ta.sigma.sd<-sd(sigma.ta.vect[seq(3, length(sigma.ta.vect), 5)])
OU.1.ta.sigma<-mean(sigma.ta.vect[seq(4, length(sigma.ta.vect), 5)])
OU.1.ta.sigma.sd<-sd(sigma.ta.vect[seq(4, length(sigma.ta.vect), 5)])
OU.M.ta.sigma<-mean(sigma.ta.vect[seq(5, length(sigma.ta.vect), 5)])
OU.M.ta.sigma.sd<-sd(sigma.ta.vect[seq(5, length(sigma.ta.vect), 5)])
signif(c(BM.1.ta.sigma, BM.M.ta.sigma, BM.M.2.ta.sigma, OU.1.ta.sigma, OU.M.ta.sigma), 2)
signif(c(BM.1.ta.sigma.sd, BM.M.ta.sigma.sd, BM.M.2.ta.sigma.sd, OU.1.ta.sigma.sd, OU.M.ta.sigma.sd), 2)
theta.ta <- list()
theta.ta<-foreach(i=1:100)%dopar%{theta.ta[[i]] <- c(BM.1.ta[[i]]$theta, BM.M.ta[[i]]$theta, OU.1.ta[[i]]$theta, OU.M.ta[[i]]$theta)}
theta.ta.vect<-(unlist(theta.ta))
BM.1.ta.theta<-mean(theta.ta.vect[seq(1, length(theta.ta.vect), 5)])
BM.1.ta.theta.sd<-sd(theta.ta.vect[seq(1, length(theta.ta.vect), 5)])
BM.M.ta.theta<-mean(theta.ta.vect[seq(2, length(theta.ta.vect), 5)])
BM.M.ta.theta.sd<-sd(theta.ta.vect[seq(2, length(theta.ta.vect), 5)])
OU.1.ta.theta<-mean(theta.ta.vect[seq(3, length(theta.ta.vect), 5)])
OU.1.ta.theta.sd<-sd(theta.ta.vect[seq(3, length(theta.ta.vect), 5)])
OU.M.ta.theta<-mean(theta.ta.vect[seq(4, length(theta.ta.vect), 5)])
OU.M.ta.theta.sd<-sd(theta.ta.vect[seq(4, length(theta.ta.vect), 5)])
OU.M.2.ta.theta<-mean(theta.ta.vect[seq(5, length(theta.ta.vect), 5)])
OU.M.2.ta.theta.sd<-sd(theta.ta.vect[seq(5, length(theta.ta.vect), 5)])
signif(c(BM.1.ta.theta, BM.M.ta.theta, OU.1.ta.theta, OU.M.ta.theta, OU.M.2.ta.theta), 2)
signif(c(BM.1.ta.theta.sd, BM.M.ta.theta.sd, OU.1.ta.theta.sd, OU.M.ta.theta.sd, OU.M.2.ta.theta.sd), 2)
alpha.ta<-list()
alpha.ta<-foreach(i=1:100)%dopar%{alpha.ta[[i]] <- c(OU.1.ta[[i]]$alpha, OU.M.ta[[i]]$alpha)}
alpha.ta.vect<-(unlist(alpha.ta))
OU.1.ta.alpha<-mean(alpha.ta.vect[seq(1, length(alpha.ta.vect), 2)])
OU.1.ta.alpha.sd<-sd(alpha.ta.vect[seq(1, length(alpha.ta.vect), 2)])
OU.M.ta.alpha<-mean(alpha.ta.vect[seq(2, length(alpha.ta.vect), 2)])
OU.M.ta.alpha.sd<-sd(alpha.ta.vect[seq(2, length(alpha.ta.vect), 2)])
signif(c(OU.1.ta.alpha, OU.M.ta.alpha), 2)
signif(c(OU.1.ta.alpha.sd, OU.M.ta.alpha.sd), 2)
aic.ta<-foreach(i=1:100)%dopar%{aic.ta[[i]] <- c(BM.1.ta[[i]]$AICc, BM.M.ta[[i]]$AICc, OU.1.ta[[i]]$AICc, OU.M.ta[[i]]$AICc)}
aic.ta.vect<-(unlist(aic.ta))
BM.1.ta.aic<-mean(aic.ta.vect[seq(1, length(aic.ta.vect), 4)])
BM.1.ta.aic.sd<-sd(aic.ta.vect[seq(1, length(aic.ta.vect), 4)])
BM.M.ta.aic<-mean(aic.ta.vect[seq(2, length(aic.ta.vect), 4)])
BM.M.ta.aic.sd<-sd(aic.ta.vect[seq(2, length(aic.ta.vect), 4)])
OU.1.ta.aic<-mean(aic.ta.vect[seq(3, length(aic.ta.vect), 4)])
OU.1.ta.aic.sd<-sd(aic.ta.vect[seq(3, length(aic.ta.vect), 4)])
OU.M.ta.aic<-mean(aic.ta.vect[seq(4, length(aic.ta.vect), 4)])
OU.M.ta.aic.sd<-sd(aic.ta.vect[seq(4, length(aic.ta.vect), 4)])
signif(c(BM.1.ta.aic, BM.M.ta.aic, OU.1.ta.aic, OU.M.ta.aic), 4)
signif(c(BM.1.ta.aic.sd, BM.M.ta.aic.sd, OU.1.ta.aic.sd, OU.M.ta.aic.sd), 4)
power.error(OU.M.ta[[1]], BM.1.ta[[1]])

#tmed
BM.1.tm <- list()
BM.M.tm <- list()
OU.1.tm <- list()
OU.M.tm <- list()
aicw.tm <- list()
aic.tm<-list()
tm.adjust <- list()
tm.adjust<-foreach(i=1:100)%dopar%{tm.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, tmed)}
BM.1.tm<-foreach(i=1:100)%dopar%{BM.1.tm[[i]]<-mvBM(painttree[[i]], tm.adjust[[i]]$resid, model='BM1')}
BM.M.tm<-foreach(i=1:100)%dopar%{BM.M.tm[[i]]<-mvBM(painttree[[i]], tm.adjust[[i]]$resid, model='BMM')}
OU.1.tm<-foreach(i=1:100)%dopar%{OU.1.tm[[i]]<-mvOU(painttree[[i]], tm.adjust[[i]]$resid, model='OU1')}
OU.M.tm<-foreach(i=1:100)%dopar%{OU.M.tm[[i]]<-mvOU(painttree[[i]], tm.adjust[[i]]$resid, model='OUM')}
aicw.tm<-foreach(i=1:100)%dopar%{aic.tm[[i]] <- aic.w(c(BM.1.tm[[i]]$AICc, BM.M.tm[[i]]$AICc, OU.1.tm[[i]]$AICc, OU.M.tm[[i]]$AICc))}
aicw.tm.vect<-(unlist(aicw.tm))
BM.1.tm.w<-mean(aicw.tm.vect[seq(1, length(aicw.tm.vect), 4)])
BM.M.tm.w<-mean(aicw.tm.vect[seq(2, length(aicw.tm.vect), 4)])
OU.1.tm.w<-mean(aicw.tm.vect[seq(3, length(aicw.tm.vect), 4)])
OU.M.tm.w<-mean(aicw.tm.vect[seq(4, length(aicw.tm.vect), 4)])
signif(c(BM.1.tm.w, BM.M.tm.w, OU.1.tm.w, OU.M.tm.w), 2)
BM.1.tm.w.sd<-sd(aicw.tm.vect[seq(1, length(aicw.tm.vect), 4)])
BM.M.tm.w.sd<-sd(aicw.tm.vect[seq(2, length(aicw.tm.vect), 4)])
OU.1.tm.w.sd<-sd(aicw.tm.vect[seq(3, length(aicw.tm.vect), 4)])
OU.M.tm.w.sd<-sd(aicw.tm.vect[seq(4, length(aicw.tm.vect), 4)])
signif(c(BM.1.tm.w.sd, BM.M.tm.w.sd, OU.1.tm.w.sd, OU.M.tm.w.sd), 2)
sigma.tm <- list()
sigma.tm<-foreach(i=1:100)%dopar%{sigma.tm[[i]] <- c(BM.1.tm[[i]]$sigma, BM.M.tm[[i]]$sigma, OU.1.tm[[i]]$sigma, OU.M.tm[[i]]$sigma)}
sigma.tm.vect<-(unlist(sigma.tm))
BM.1.tm.sigma<-mean(sigma.tm.vect[seq(1, length(sigma.tm.vect), 5)])
BM.1.tm.sigma.sd<-sd(sigma.tm.vect[seq(1, length(sigma.tm.vect), 5)])
BM.M.tm.sigma<-mean(sigma.tm.vect[seq(2, length(sigma.tm.vect), 5)])
BM.M.tm.sigma.sd<-sd(sigma.tm.vect[seq(2, length(sigma.tm.vect), 5)])
BM.M.2.tm.sigma<-mean(sigma.tm.vect[seq(3, length(sigma.tm.vect), 5)])
BM.M.2.tm.sigma.sd<-sd(sigma.tm.vect[seq(3, length(sigma.tm.vect), 5)])
OU.1.tm.sigma<-mean(sigma.tm.vect[seq(4, length(sigma.tm.vect), 5)])
OU.1.tm.sigma.sd<-sd(sigma.tm.vect[seq(4, length(sigma.tm.vect), 5)])
OU.M.tm.sigma<-mean(sigma.tm.vect[seq(5, length(sigma.tm.vect), 5)])
OU.M.tm.sigma.sd<-sd(sigma.tm.vect[seq(5, length(sigma.tm.vect), 5)])
signif(c(BM.1.tm.sigma, BM.M.tm.sigma, BM.M.2.tm.sigma, OU.1.tm.sigma, OU.M.tm.sigma), 2)
signif(c(BM.1.tm.sigma.sd, BM.M.tm.sigma.sd, BM.M.2.tm.sigma.sd, OU.1.tm.sigma.sd, OU.M.tm.sigma.sd), 2)
theta.tm <- list()
theta.tm<-foreach(i=1:100)%dopar%{theta.tm[[i]] <- c(BM.1.tm[[i]]$theta, BM.M.tm[[i]]$theta, OU.1.tm[[i]]$theta, OU.M.tm[[i]]$theta)}
theta.tm.vect<-(unlist(theta.tm))
BM.1.tm.theta<-mean(theta.tm.vect[seq(1, length(theta.tm.vect), 5)])
BM.1.tm.theta.sd<-sd(theta.tm.vect[seq(1, length(theta.tm.vect), 5)])
BM.M.tm.theta<-mean(theta.tm.vect[seq(2, length(theta.tm.vect), 5)])
BM.M.tm.theta.sd<-sd(theta.tm.vect[seq(2, length(theta.tm.vect), 5)])
OU.1.tm.theta<-mean(theta.tm.vect[seq(3, length(theta.tm.vect), 5)])
OU.1.tm.theta.sd<-sd(theta.tm.vect[seq(3, length(theta.tm.vect), 5)])
OU.M.tm.theta<-mean(theta.tm.vect[seq(4, length(theta.tm.vect), 5)])
OU.M.tm.theta.sd<-sd(theta.tm.vect[seq(4, length(theta.tm.vect), 5)])
OU.M.2.tm.theta<-mean(theta.tm.vect[seq(5, length(theta.tm.vect), 5)])
OU.M.2.tm.theta.sd<-sd(theta.tm.vect[seq(5, length(theta.tm.vect), 5)])
signif(c(BM.1.tm.theta, BM.M.tm.theta, OU.1.tm.theta, OU.M.tm.theta, OU.M.2.tm.theta), 2)
signif(c(BM.1.tm.theta.sd, BM.M.tm.theta.sd, OU.1.tm.theta.sd, OU.M.tm.theta.sd, OU.M.2.tm.theta.sd), 2)
alpha.tm<-list()
alpha.tm<-foreach(i=1:100)%dopar%{alpha.tm[[i]] <- c(OU.1.tm[[i]]$alpha, OU.M.tm[[i]]$alpha)}
alpha.tm.vect<-(unlist(alpha.tm))
OU.1.tm.alpha<-mean(alpha.tm.vect[seq(1, length(alpha.tm.vect), 2)])
OU.1.tm.alpha.sd<-sd(alpha.tm.vect[seq(1, length(alpha.tm.vect), 2)])
OU.M.tm.alpha<-mean(alpha.tm.vect[seq(2, length(alpha.tm.vect), 2)])
OU.M.tm.alpha.sd<-sd(alpha.tm.vect[seq(2, length(alpha.tm.vect), 2)])
signif(c(OU.1.tm.alpha, OU.M.tm.alpha), 2)
signif(c(OU.1.tm.alpha.sd, OU.M.tm.alpha.sd), 2)
aic.tm<-foreach(i=1:100)%dopar%{aic.tm[[i]] <- c(BM.1.tm[[i]]$AICc, BM.M.tm[[i]]$AICc, OU.1.tm[[i]]$AICc, OU.M.tm[[i]]$AICc)}
aic.tm.vect<-(unlist(aic.tm))
BM.1.tm.aic<-mean(aic.tm.vect[seq(1, length(aic.tm.vect), 4)])
BM.1.tm.aic.sd<-sd(aic.tm.vect[seq(1, length(aic.tm.vect), 4)])
BM.M.tm.aic<-mean(aic.tm.vect[seq(2, length(aic.tm.vect), 4)])
BM.M.tm.aic.sd<-sd(aic.tm.vect[seq(2, length(aic.tm.vect), 4)])
OU.1.tm.aic<-mean(aic.tm.vect[seq(3, length(aic.tm.vect), 4)])
OU.1.tm.aic.sd<-sd(aic.tm.vect[seq(3, length(aic.tm.vect), 4)])
OU.M.tm.aic<-mean(aic.tm.vect[seq(4, length(aic.tm.vect), 4)])
OU.M.tm.aic.sd<-sd(aic.tm.vect[seq(4, length(aic.tm.vect), 4)])
signif(c(BM.1.tm.aic, BM.M.tm.aic, OU.1.tm.aic, OU.M.tm.aic), 4)
signif(c(BM.1.tm.aic.sd, BM.M.tm.aic.sd, OU.1.tm.aic.sd, OU.M.tm.aic.sd), 4)
power.error(OU.M.tm[[1]], BM.1.tm[[1]])

#tlat
BM.1.tl <- list()
BM.M.tl <- list()
OU.1.tl <- list()
OU.M.tl <- list()
aicw.tl <- list()
aic.tl<-list()
tl.adjust <- list()
tl.adjust<-foreach(i=1:100)%dopar%{tl.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, tlat)}
BM.1.tl<-foreach(i=1:100)%dopar%{BM.1.tl[[i]]<-mvBM(painttree[[i]], tl.adjust[[i]]$resid, model='BM1')}
BM.M.tl<-foreach(i=1:100)%dopar%{BM.M.tl[[i]]<-mvBM(painttree[[i]], tl.adjust[[i]]$resid, model='BMM')}
OU.1.tl<-foreach(i=1:100)%dopar%{OU.1.tl[[i]]<-mvOU(painttree[[i]], tl.adjust[[i]]$resid, model='OU1')}
OU.M.tl<-foreach(i=1:100)%dopar%{OU.M.tl[[i]]<-mvOU(painttree[[i]], tl.adjust[[i]]$resid, model='OUM')}
aicw.tl<-foreach(i=1:100)%dopar%{aic.tl[[i]] <- aic.w(c(BM.1.tl[[i]]$AICc, BM.M.tl[[i]]$AICc, OU.1.tl[[i]]$AICc, OU.M.tl[[i]]$AICc))}
aicw.tl.vect<-(unlist(aicw.tl))
BM.1.tl.w<-mean(aicw.tl.vect[seq(1, length(aicw.tl.vect), 4)])
BM.M.tl.w<-mean(aicw.tl.vect[seq(2, length(aicw.tl.vect), 4)])
OU.1.tl.w<-mean(aicw.tl.vect[seq(3, length(aicw.tl.vect), 4)])
OU.M.tl.w<-mean(aicw.tl.vect[seq(4, length(aicw.tl.vect), 4)])
signif(c(BM.1.tl.w, BM.M.tl.w, OU.1.tl.w, OU.M.tl.w), 2)
BM.1.tl.w.sd<-sd(aicw.tl.vect[seq(1, length(aicw.tl.vect), 4)])
BM.M.tl.w.sd<-sd(aicw.tl.vect[seq(2, length(aicw.tl.vect), 4)])
OU.1.tl.w.sd<-sd(aicw.tl.vect[seq(3, length(aicw.tl.vect), 4)])
OU.M.tl.w.sd<-sd(aicw.tl.vect[seq(4, length(aicw.tl.vect), 4)])
signif(c(BM.1.tl.w.sd, BM.M.tl.w.sd, OU.1.tl.w.sd, OU.M.tl.w.sd), 2)
sigma.tl <- list()
sigma.tl<-foreach(i=1:100)%dopar%{sigma.tl[[i]] <- c(BM.1.tl[[i]]$sigma, BM.M.tl[[i]]$sigma, OU.1.tl[[i]]$sigma, OU.M.tl[[i]]$sigma)}
sigma.tl.vect<-(unlist(sigma.tl))
BM.1.tl.sigma<-mean(sigma.tl.vect[seq(1, length(sigma.tl.vect), 5)])
BM.1.tl.sigma.sd<-sd(sigma.tl.vect[seq(1, length(sigma.tl.vect), 5)])
BM.M.tl.sigma<-mean(sigma.tl.vect[seq(2, length(sigma.tl.vect), 5)])
BM.M.tl.sigma.sd<-sd(sigma.tl.vect[seq(2, length(sigma.tl.vect), 5)])
BM.M.2.tl.sigma<-mean(sigma.tl.vect[seq(3, length(sigma.tl.vect), 5)])
BM.M.2.tl.sigma.sd<-sd(sigma.tl.vect[seq(3, length(sigma.tl.vect), 5)])
OU.1.tl.sigma<-mean(sigma.tl.vect[seq(4, length(sigma.tl.vect), 5)])
OU.1.tl.sigma.sd<-sd(sigma.tl.vect[seq(4, length(sigma.tl.vect), 5)])
OU.M.tl.sigma<-mean(sigma.tl.vect[seq(5, length(sigma.tl.vect), 5)])
OU.M.tl.sigma.sd<-sd(sigma.tl.vect[seq(5, length(sigma.tl.vect), 5)])
signif(c(BM.1.tl.sigma, BM.M.tl.sigma, BM.M.2.tl.sigma, OU.1.tl.sigma, OU.M.tl.sigma), 2)
signif(c(BM.1.tl.sigma.sd, BM.M.tl.sigma.sd, BM.M.2.tl.sigma.sd, OU.1.tl.sigma.sd, OU.M.tl.sigma.sd), 2)
theta.tl <- list()
theta.tl<-foreach(i=1:100)%dopar%{theta.tl[[i]] <- c(BM.1.tl[[i]]$theta, BM.M.tl[[i]]$theta, OU.1.tl[[i]]$theta, OU.M.tl[[i]]$theta)}
theta.tl.vect<-(unlist(theta.tl))
BM.1.tl.theta<-mean(theta.tl.vect[seq(1, length(theta.tl.vect), 5)])
BM.1.tl.theta.sd<-sd(theta.tl.vect[seq(1, length(theta.tl.vect), 5)])
BM.M.tl.theta<-mean(theta.tl.vect[seq(2, length(theta.tl.vect), 5)])
BM.M.tl.theta.sd<-sd(theta.tl.vect[seq(2, length(theta.tl.vect), 5)])
OU.1.tl.theta<-mean(theta.tl.vect[seq(3, length(theta.tl.vect), 5)])
OU.1.tl.theta.sd<-sd(theta.tl.vect[seq(3, length(theta.tl.vect), 5)])
OU.M.tl.theta<-mean(theta.tl.vect[seq(4, length(theta.tl.vect), 5)])
OU.M.tl.theta.sd<-sd(theta.tl.vect[seq(4, length(theta.tl.vect), 5)])
OU.M.2.tl.theta<-mean(theta.tl.vect[seq(5, length(theta.tl.vect), 5)])
OU.M.2.tl.theta.sd<-sd(theta.tl.vect[seq(5, length(theta.tl.vect), 5)])
signif(c(BM.1.tl.theta, BM.M.tl.theta, OU.1.tl.theta, OU.M.tl.theta, OU.M.2.tl.theta), 2)
signif(c(BM.1.tl.theta.sd, BM.M.tl.theta.sd, OU.1.tl.theta.sd, OU.M.tl.theta.sd, OU.M.2.tl.theta.sd), 2)
alpha.tl<-list()
alpha.tl<-foreach(i=1:100)%dopar%{alpha.tl[[i]] <- c(OU.1.tl[[i]]$alpha, OU.M.tl[[i]]$alpha)}
alpha.tl.vect<-(unlist(alpha.tl))
OU.1.tl.alpha<-mean(alpha.tl.vect[seq(1, length(alpha.tl.vect), 2)])
OU.1.tl.alpha.sd<-sd(alpha.tl.vect[seq(1, length(alpha.tl.vect), 2)])
OU.M.tl.alpha<-mean(alpha.tl.vect[seq(2, length(alpha.tl.vect), 2)])
OU.M.tl.alpha.sd<-sd(alpha.tl.vect[seq(2, length(alpha.tl.vect), 2)])
signif(c(OU.1.tl.alpha, OU.M.tl.alpha), 2)
signif(c(OU.1.tl.alpha.sd, OU.M.tl.alpha.sd), 2)
aic.tl<-foreach(i=1:100)%dopar%{aic.tl[[i]] <- c(BM.1.tl[[i]]$AICc, BM.M.tl[[i]]$AICc, OU.1.tl[[i]]$AICc, OU.M.tl[[i]]$AICc)}
aic.tl.vect<-(unlist(aic.tl))
BM.1.tl.aic<-mean(aic.tl.vect[seq(1, length(aic.tl.vect), 4)])
BM.1.tl.aic.sd<-sd(aic.tl.vect[seq(1, length(aic.tl.vect), 4)])
BM.M.tl.aic<-mean(aic.tl.vect[seq(2, length(aic.tl.vect), 4)])
BM.M.tl.aic.sd<-sd(aic.tl.vect[seq(2, length(aic.tl.vect), 4)])
OU.1.tl.aic<-mean(aic.tl.vect[seq(3, length(aic.tl.vect), 4)])
OU.1.tl.aic.sd<-sd(aic.tl.vect[seq(3, length(aic.tl.vect), 4)])
OU.M.tl.aic<-mean(aic.tl.vect[seq(4, length(aic.tl.vect), 4)])
OU.M.tl.aic.sd<-sd(aic.tl.vect[seq(4, length(aic.tl.vect), 4)])
signif(c(BM.1.tl.aic, BM.M.tl.aic, OU.1.tl.aic, OU.M.tl.aic), 2)
signif(c(BM.1.tl.aic.sd, BM.M.tl.aic.sd, OU.1.tl.aic.sd, OU.M.tl.aic.sd), 2)
power.error(OU.M.tl[[1]], BM.1.tl[[1]])

#tv
BM.1.tv <- list()
BM.M.tv <- list()
OU.1.tv <- list()
OU.M.tv <- list()
aicw.tv <- list()
aic.tv<-list()
tv.adjust <- list()
tv.adjust<-foreach(i=1:100)%dopar%{tv.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, tv)}
BM.1.tv<-foreach(i=1:100)%dopar%{BM.1.tv[[i]]<-mvBM(painttree[[i]], tv.adjust[[i]]$resid, model='BM1')}
BM.M.tv<-foreach(i=1:100)%dopar%{BM.M.tv[[i]]<-mvBM(painttree[[i]], tv.adjust[[i]]$resid, model='BMM')}
OU.1.tv<-foreach(i=1:100)%dopar%{OU.1.tv[[i]]<-mvOU(painttree[[i]], tv.adjust[[i]]$resid, model='OU1')}
OU.M.tv<-foreach(i=1:100)%dopar%{OU.M.tv[[i]]<-mvOU(painttree[[i]], tv.adjust[[i]]$resid, model='OUM')}
aicw.tv<-foreach(i=1:100)%dopar%{aic.tv[[i]] <- aic.w(c(BM.1.tv[[i]]$AICc, BM.M.tv[[i]]$AICc, OU.1.tv[[i]]$AICc, OU.M.tv[[i]]$AICc))}
aicw.tv.vect<-(unlist(aicw.tv))
BM.1.tv.w<-mean(aicw.tv.vect[seq(1, length(aicw.tv.vect), 4)])
BM.M.tv.w<-mean(aicw.tv.vect[seq(2, length(aicw.tv.vect), 4)])
OU.1.tv.w<-mean(aicw.tv.vect[seq(3, length(aicw.tv.vect), 4)])
OU.M.tv.w<-mean(aicw.tv.vect[seq(4, length(aicw.tv.vect), 4)])
signif(c(BM.1.tv.w, BM.M.tv.w, OU.1.tv.w, OU.M.tv.w), 2)
BM.1.tv.w.sd<-sd(aicw.tv.vect[seq(1, length(aicw.tv.vect), 4)])
BM.M.tv.w.sd<-sd(aicw.tv.vect[seq(2, length(aicw.tv.vect), 4)])
OU.1.tv.w.sd<-sd(aicw.tv.vect[seq(3, length(aicw.tv.vect), 4)])
OU.M.tv.w.sd<-sd(aicw.tv.vect[seq(4, length(aicw.tv.vect), 4)])
signif(c(BM.1.tv.w.sd, BM.M.tv.w.sd, OU.1.tv.w.sd, OU.M.tv.w.sd), 2)
sigma.tv <- list()
sigma.tv<-foreach(i=1:100)%dopar%{sigma.tv[[i]] <- c(BM.1.tv[[i]]$sigma, BM.M.tv[[i]]$sigma, OU.1.tv[[i]]$sigma, OU.M.tv[[i]]$sigma)}
sigma.tv.vect<-(unlist(sigma.tv))
BM.1.tv.sigma<-mean(sigma.tv.vect[seq(1, length(sigma.tv.vect), 5)])
BM.1.tv.sigma.sd<-sd(sigma.tv.vect[seq(1, length(sigma.tv.vect), 5)])
BM.M.tv.sigma<-mean(sigma.tv.vect[seq(2, length(sigma.tv.vect), 5)])
BM.M.tv.sigma.sd<-sd(sigma.tv.vect[seq(2, length(sigma.tv.vect), 5)])
BM.M.2.tv.sigma<-mean(sigma.tv.vect[seq(3, length(sigma.tv.vect), 5)])
BM.M.2.tv.sigma.sd<-sd(sigma.tv.vect[seq(3, length(sigma.tv.vect), 5)])
OU.1.tv.sigma<-mean(sigma.tv.vect[seq(4, length(sigma.tv.vect), 5)])
OU.1.tv.sigma.sd<-sd(sigma.tv.vect[seq(4, length(sigma.tv.vect), 5)])
OU.M.tv.sigma<-mean(sigma.tv.vect[seq(5, length(sigma.tv.vect), 5)])
OU.M.tv.sigma.sd<-sd(sigma.tv.vect[seq(5, length(sigma.tv.vect), 5)])
signif(c(BM.1.tv.sigma, BM.M.tv.sigma, BM.M.2.tv.sigma, OU.1.tv.sigma, OU.M.tv.sigma), 2)
signif(c(BM.1.tv.sigma.sd, BM.M.tv.sigma.sd, BM.M.2.tv.sigma.sd, OU.1.tv.sigma.sd, OU.M.tv.sigma.sd), 2)
theta.tv <- list()
theta.tv<-foreach(i=1:100)%dopar%{theta.tv[[i]] <- c(BM.1.tv[[i]]$theta, BM.M.tv[[i]]$theta, OU.1.tv[[i]]$theta, OU.M.tv[[i]]$theta)}
theta.tv.vect<-(unlist(theta.tv))
BM.1.tv.theta<-mean(theta.tv.vect[seq(1, length(theta.tv.vect), 5)])
BM.1.tv.theta.sd<-sd(theta.tv.vect[seq(1, length(theta.tv.vect), 5)])
BM.M.tv.theta<-mean(theta.tv.vect[seq(2, length(theta.tv.vect), 5)])
BM.M.tv.theta.sd<-sd(theta.tv.vect[seq(2, length(theta.tv.vect), 5)])
OU.1.tv.theta<-mean(theta.tv.vect[seq(3, length(theta.tv.vect), 5)])
OU.1.tv.theta.sd<-sd(theta.tv.vect[seq(3, length(theta.tv.vect), 5)])
OU.M.tv.theta<-mean(theta.tv.vect[seq(4, length(theta.tv.vect), 5)])
OU.M.tv.theta.sd<-sd(theta.tv.vect[seq(4, length(theta.tv.vect), 5)])
OU.M.2.tv.theta<-mean(theta.tv.vect[seq(5, length(theta.tv.vect), 5)])
OU.M.2.tv.theta.sd<-sd(theta.tv.vect[seq(5, length(theta.tv.vect), 5)])
signif(c(BM.1.tv.theta, BM.M.tv.theta, OU.1.tv.theta, OU.M.tv.theta, OU.M.2.tv.theta), 2)
signif(c(BM.1.tv.theta.sd, BM.M.tv.theta.sd, OU.1.tv.theta.sd, OU.M.tv.theta.sd, OU.M.2.tv.theta.sd), 2)
alpha.tv<-list()
alpha.tv<-foreach(i=1:100)%dopar%{alpha.tv[[i]] <- c(OU.1.tv[[i]]$alpha, OU.M.tv[[i]]$alpha)}
alpha.tv.vect<-(unlist(alpha.tv))
OU.1.tv.alpha<-mean(alpha.tv.vect[seq(1, length(alpha.tv.vect), 2)])
OU.1.tv.alpha.sd<-sd(alpha.tv.vect[seq(1, length(alpha.tv.vect), 2)])
OU.M.tv.alpha<-mean(alpha.tv.vect[seq(2, length(alpha.tv.vect), 2)])
OU.M.tv.alpha.sd<-sd(alpha.tv.vect[seq(2, length(alpha.tv.vect), 2)])
signif(c(OU.1.tv.alpha, OU.M.tv.alpha), 2)
signif(c(OU.1.tv.alpha.sd, OU.M.tv.alpha.sd), 2)
aic.tv<-foreach(i=1:100)%dopar%{aic.tv[[i]] <- c(BM.1.tv[[i]]$AICc, BM.M.tv[[i]]$AICc, OU.1.tv[[i]]$AICc, OU.M.tv[[i]]$AICc)}
aic.tv.vect<-(unlist(aic.tv))
BM.1.tv.aic<-mean(aic.tv.vect[seq(1, length(aic.tv.vect), 4)])
BM.1.tv.aic.sd<-sd(aic.tv.vect[seq(1, length(aic.tv.vect), 4)])
BM.M.tv.aic<-mean(aic.tv.vect[seq(2, length(aic.tv.vect), 4)])
BM.M.tv.aic.sd<-sd(aic.tv.vect[seq(2, length(aic.tv.vect), 4)])
OU.1.tv.aic<-mean(aic.tv.vect[seq(3, length(aic.tv.vect), 4)])
OU.1.tv.aic.sd<-sd(aic.tv.vect[seq(3, length(aic.tv.vect), 4)])
OU.M.tv.aic<-mean(aic.tv.vect[seq(4, length(aic.tv.vect), 4)])
OU.M.tv.aic.sd<-sd(aic.tv.vect[seq(4, length(aic.tv.vect), 4)])
signif(c(BM.1.tv.aic, BM.M.tv.aic, OU.1.tv.aic, OU.M.tv.aic), 2)
signif(c(BM.1.tv.aic.sd, BM.M.tv.aic.sd, OU.1.tv.aic.sd, OU.M.tv.aic.sd), 2)
power.error(OU.M.tv[[1]], BM.1.tv[[1]])

#tbp
BM.1.tbp <- list()
BM.M.tbp <- list()
OU.1.tbp <- list()
OU.M.tbp <- list()
aicw.tbp <- list()
aic.tbp<-list()
tbp.adjust <- list()
tbp.adjust<-foreach(i=1:100)%dopar%{tbp.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, tbp)}
BM.1.tbp<-foreach(i=1:100)%dopar%{BM.1.tbp[[i]]<-mvBM(painttree[[i]], tbp.adjust[[i]]$resid, model='BM1')}
BM.M.tbp<-foreach(i=1:100)%dopar%{BM.M.tbp[[i]]<-mvBM(painttree[[i]], tbp.adjust[[i]]$resid,  model='BMM')}
OU.1.tbp<-foreach(i=1:100)%dopar%{OU.1.tbp[[i]]<-mvOU(painttree[[i]], tbp.adjust[[i]]$resid,  model='OU1')}
OU.M.tbp<-foreach(i=1:100)%dopar%{OU.M.tbp[[i]]<-mvOU(painttree[[i]], tbp.adjust[[i]]$resid, model='OUM')}
aicw.tbp<-foreach(i=1:100)%dopar%{aic.tbp[[i]] <- aic.w(c(BM.1.tbp[[i]]$AICc, BM.M.tbp[[i]]$AICc, OU.1.tbp[[i]]$AICc, OU.M.tbp[[i]]$AICc))}
aicw.tbp.vect<-(unlist(aicw.tbp))
BM.1.tbp.w<-mean(aicw.tbp.vect[seq(1, length(aicw.tbp.vect), 4)])
BM.M.tbp.w<-mean(aicw.tbp.vect[seq(2, length(aicw.tbp.vect), 4)])
OU.1.tbp.w<-mean(aicw.tbp.vect[seq(3, length(aicw.tbp.vect), 4)])
OU.M.tbp.w<-mean(aicw.tbp.vect[seq(4, length(aicw.tbp.vect), 4)])
signif(c(BM.1.tbp.w, BM.M.tbp.w, OU.1.tbp.w, OU.M.tbp.w), 2)
BM.1.tbp.w.sd<-sd(aicw.tbp.vect[seq(1, length(aicw.tbp.vect), 4)])
BM.M.tbp.w.sd<-sd(aicw.tbp.vect[seq(2, length(aicw.tbp.vect), 4)])
OU.1.tbp.w.sd<-sd(aicw.tbp.vect[seq(3, length(aicw.tbp.vect), 4)])
OU.M.tbp.w.sd<-sd(aicw.tbp.vect[seq(4, length(aicw.tbp.vect), 4)])
signif(c(BM.1.tbp.w.sd, BM.M.tbp.w.sd, OU.1.tbp.w.sd, OU.M.tbp.w.sd), 2)
sigma.tbp <- list()
sigma.tbp<-foreach(i=1:100)%dopar%{sigma.tbp[[i]] <- c(BM.1.tbp[[i]]$sigma, BM.M.tbp[[i]]$sigma, OU.1.tbp[[i]]$sigma, OU.M.tbp[[i]]$sigma)}
sigma.tbp.vect<-(unlist(sigma.tbp))
BM.1.tbp.sigma<-mean(sigma.tbp.vect[seq(1, length(sigma.tbp.vect), 5)])
BM.1.tbp.sigma.sd<-sd(sigma.tbp.vect[seq(1, length(sigma.tbp.vect), 5)])
BM.M.tbp.sigma<-mean(sigma.tbp.vect[seq(2, length(sigma.tbp.vect), 5)])
BM.M.tbp.sigma.sd<-sd(sigma.tbp.vect[seq(2, length(sigma.tbp.vect), 5)])
BM.M.2.tbp.sigma<-mean(sigma.tbp.vect[seq(3, length(sigma.tbp.vect), 5)])
BM.M.2.tbp.sigma.sd<-sd(sigma.tbp.vect[seq(3, length(sigma.tbp.vect), 5)])
OU.1.tbp.sigma<-mean(sigma.tbp.vect[seq(4, length(sigma.tbp.vect), 5)])
OU.1.tbp.sigma.sd<-sd(sigma.tbp.vect[seq(4, length(sigma.tbp.vect), 5)])
OU.M.tbp.sigma<-mean(sigma.tbp.vect[seq(5, length(sigma.tbp.vect), 5)])
OU.M.tbp.sigma.sd<-sd(sigma.tbp.vect[seq(5, length(sigma.tbp.vect), 5)])
signif(c(BM.1.tbp.sigma, BM.M.tbp.sigma, BM.M.2.tbp.sigma, OU.1.tbp.sigma, OU.M.tbp.sigma), 2)
signif(c(BM.1.tbp.sigma.sd, BM.M.tbp.sigma.sd, BM.M.2.tbp.sigma.sd, OU.1.tbp.sigma.sd, OU.M.tbp.sigma.sd), 2)
theta.tbp <- list()
theta.tbp<-foreach(i=1:100)%dopar%{theta.tbp[[i]] <- c(BM.1.tbp[[i]]$theta, BM.M.tbp[[i]]$theta, OU.1.tbp[[i]]$theta, OU.M.tbp[[i]]$theta)}
theta.tbp.vect<-(unlist(theta.tbp))
BM.1.tbp.theta<-mean(theta.tbp.vect[seq(1, length(theta.tbp.vect), 5)])
BM.1.tbp.theta.sd<-sd(theta.tbp.vect[seq(1, length(theta.tbp.vect), 5)])
BM.M.tbp.theta<-mean(theta.tbp.vect[seq(2, length(theta.tbp.vect), 5)])
BM.M.tbp.theta.sd<-sd(theta.tbp.vect[seq(2, length(theta.tbp.vect), 5)])
OU.1.tbp.theta<-mean(theta.tbp.vect[seq(3, length(theta.tbp.vect), 5)])
OU.1.tbp.theta.sd<-sd(theta.tbp.vect[seq(3, length(theta.tbp.vect), 5)])
OU.M.tbp.theta<-mean(theta.tbp.vect[seq(4, length(theta.tbp.vect), 5)])
OU.M.tbp.theta.sd<-sd(theta.tbp.vect[seq(4, length(theta.tbp.vect), 5)])
OU.M.2.tbp.theta<-mean(theta.tbp.vect[seq(5, length(theta.tbp.vect), 5)])
OU.M.2.tbp.theta.sd<-sd(theta.tbp.vect[seq(5, length(theta.tbp.vect), 5)])
signif(c(BM.1.tbp.theta, BM.M.tbp.theta, OU.1.tbp.theta, OU.M.tbp.theta, OU.M.2.tbp.theta), 2)
signif(c(BM.1.tbp.theta.sd, BM.M.tbp.theta.sd, OU.1.tbp.theta.sd, OU.M.tbp.theta.sd, OU.M.2.tbp.theta.sd), 2)
alpha.tbp<-list()
alpha.tbp<-foreach(i=1:100)%dopar%{alpha.tbp[[i]] <- c(OU.1.tbp[[i]]$alpha, OU.M.tbp[[i]]$alpha)}
alpha.tbp.vect<-(unlist(alpha.tbp))
OU.1.tbp.alpha<-mean(alpha.tbp.vect[seq(1, length(alpha.tbp.vect), 2)])
OU.1.tbp.alpha.sd<-sd(alpha.tbp.vect[seq(1, length(alpha.tbp.vect), 2)])
OU.M.tbp.alpha<-mean(alpha.tbp.vect[seq(2, length(alpha.tbp.vect), 2)])
OU.M.tbp.alpha.sd<-sd(alpha.tbp.vect[seq(2, length(alpha.tbp.vect), 2)])
signif(c(OU.1.tbp.alpha, OU.M.tbp.alpha), 2)
signif(c(OU.1.tbp.alpha.sd, OU.M.tbp.alpha.sd), 2)
aic.tbp<-foreach(i=1:100)%dopar%{aic.tbp[[i]] <- c(BM.1.tbp[[i]]$AICc, BM.M.tbp[[i]]$AICc, OU.1.tbp[[i]]$AICc, OU.M.tbp[[i]]$AICc)}
aic.tbp.vect<-(unlist(aic.tbp))
BM.1.tbp.aic<-mean(aic.tbp.vect[seq(1, length(aic.tbp.vect), 4)])
BM.1.tbp.aic.sd<-sd(aic.tbp.vect[seq(1, length(aic.tbp.vect), 4)])
BM.M.tbp.aic<-mean(aic.tbp.vect[seq(2, length(aic.tbp.vect), 4)])
BM.M.tbp.aic.sd<-sd(aic.tbp.vect[seq(2, length(aic.tbp.vect), 4)])
OU.1.tbp.aic<-mean(aic.tbp.vect[seq(3, length(aic.tbp.vect), 4)])
OU.1.tbp.aic.sd<-sd(aic.tbp.vect[seq(3, length(aic.tbp.vect), 4)])
OU.M.tbp.aic<-mean(aic.tbp.vect[seq(4, length(aic.tbp.vect), 4)])
OU.M.tbp.aic.sd<-sd(aic.tbp.vect[seq(4, length(aic.tbp.vect), 4)])
signif(c(BM.1.tbp.aic, BM.M.tbp.aic, OU.1.tbp.aic, OU.M.tbp.aic), 4)
signif(c(BM.1.tbp.aic.sd, BM.M.tbp.aic.sd, OU.1.tbp.aic.sd, OU.M.tbp.aic.sd), 4)
power.error(OU.M.tbp[[1]], BM.1.tbp[[1]])

#cycle
BM.1.cycle <- list()
BM.M.cycle <- list()
OU.1.cycle <- list()
OU.M.cycle <- list()
aicw.cycle <- list()
aic.cycle<-list()
cycle.adjust <- list()
cycle.adjust<-foreach(i=1:100)%dopar%{cycle.adjust[[i]] <- phyl.resid(phylogeny.final.F[[i]], massspeed, cycle)}
BM.1.cycle<-foreach(i=1:100)%dopar%{BM.1.cycle[[i]]<-mvBM(painttree[[i]], cycle.adjust[[i]]$resid, model='BM1')}
BM.M.cycle<-foreach(i=1:100)%dopar%{BM.M.cycle[[i]]<-mvBM(painttree[[i]], cycle.adjust[[i]]$resid, model='BMM')}
OU.1.cycle<-foreach(i=1:100)%dopar%{OU.1.cycle[[i]]<-mvOU(painttree[[i]], cycle.adjust[[i]]$resid, model='OU1')}
OU.M.cycle<-foreach(i=1:100)%dopar%{OU.M.cycle[[i]]<-mvOU(painttree[[i]], cycle.adjust[[i]]$resid, model='OUM')}
aicw.cycle<-foreach(i=1:100)%dopar%{aic.cycle[[i]] <- aic.w(c(BM.1.cycle[[i]]$AICc, BM.M.cycle[[i]]$AICc, OU.1.cycle[[i]]$AICc, OU.M.cycle[[i]]$AICc))}
aicw.cycle.vect<-(unlist(aicw.cycle))
BM.1.cycle.w<-mean(aicw.cycle.vect[seq(1, length(aicw.cycle.vect), 4)])
BM.M.cycle.w<-mean(aicw.cycle.vect[seq(2, length(aicw.cycle.vect), 4)])
OU.1.cycle.w<-mean(aicw.cycle.vect[seq(3, length(aicw.cycle.vect), 4)])
OU.M.cycle.w<-mean(aicw.cycle.vect[seq(4, length(aicw.cycle.vect), 4)])
signif(c(BM.1.cycle.w, BM.M.cycle.w, OU.1.cycle.w, OU.M.cycle.w), 2)
BM.1.cycle.w.sd<-sd(aicw.cycle.vect[seq(1, length(aicw.cycle.vect), 4)])
BM.M.cycle.w.sd<-sd(aicw.cycle.vect[seq(2, length(aicw.cycle.vect), 4)])
OU.1.cycle.w.sd<-sd(aicw.cycle.vect[seq(3, length(aicw.cycle.vect), 4)])
OU.M.cycle.w.sd<-sd(aicw.cycle.vect[seq(4, length(aicw.cycle.vect), 4)])
signif(c(BM.1.cycle.w.sd, BM.M.cycle.w.sd, OU.1.cycle.w.sd, OU.M.cycle.w.sd), 2)
sigma.cycle <- list()
sigma.cycle<-foreach(i=1:100)%dopar%{sigma.cycle[[i]] <- c(BM.1.cycle[[i]]$sigma, BM.M.cycle[[i]]$sigma, OU.1.cycle[[i]]$sigma, OU.M.cycle[[i]]$sigma)}
sigma.cycle.vect<-(unlist(sigma.cycle))
BM.1.cycle.sigma<-mean(sigma.cycle.vect[seq(1, length(sigma.cycle.vect), 5)])
BM.1.cycle.sigma.sd<-sd(sigma.cycle.vect[seq(1, length(sigma.cycle.vect), 5)])
BM.M.cycle.sigma<-mean(sigma.cycle.vect[seq(2, length(sigma.cycle.vect), 5)])
BM.M.cycle.sigma.sd<-sd(sigma.cycle.vect[seq(2, length(sigma.cycle.vect), 5)])
BM.M.2.cycle.sigma<-mean(sigma.cycle.vect[seq(3, length(sigma.cycle.vect), 5)])
BM.M.2.cycle.sigma.sd<-sd(sigma.cycle.vect[seq(3, length(sigma.cycle.vect), 5)])
OU.1.cycle.sigma<-mean(sigma.cycle.vect[seq(4, length(sigma.cycle.vect), 5)])
OU.1.cycle.sigma.sd<-sd(sigma.cycle.vect[seq(4, length(sigma.cycle.vect), 5)])
OU.M.cycle.sigma<-mean(sigma.cycle.vect[seq(5, length(sigma.cycle.vect), 5)])
OU.M.cycle.sigma.sd<-sd(sigma.cycle.vect[seq(5, length(sigma.cycle.vect), 5)])
signif(c(BM.1.cycle.sigma, BM.M.cycle.sigma, BM.M.2.cycle.sigma, OU.1.cycle.sigma, OU.M.cycle.sigma), 2)
signif(c(BM.1.cycle.sigma.sd, BM.M.cycle.sigma.sd, BM.M.2.cycle.sigma.sd, OU.1.cycle.sigma.sd, OU.M.cycle.sigma.sd), 2)
theta.cycle <- list()
theta.cycle<-foreach(i=1:100)%dopar%{theta.cycle[[i]] <- c(BM.1.cycle[[i]]$theta, BM.M.cycle[[i]]$theta, OU.1.cycle[[i]]$theta, OU.M.cycle[[i]]$theta)}
theta.cycle.vect<-(unlist(theta.cycle))
BM.1.cycle.theta<-mean(theta.cycle.vect[seq(1, length(theta.cycle.vect), 5)])
BM.1.cycle.theta.sd<-sd(theta.cycle.vect[seq(1, length(theta.cycle.vect), 5)])
BM.M.cycle.theta<-mean(theta.cycle.vect[seq(2, length(theta.cycle.vect), 5)])
BM.M.cycle.theta.sd<-sd(theta.cycle.vect[seq(2, length(theta.cycle.vect), 5)])
OU.1.cycle.theta<-mean(theta.cycle.vect[seq(3, length(theta.cycle.vect), 5)])
OU.1.cycle.theta.sd<-sd(theta.cycle.vect[seq(3, length(theta.cycle.vect), 5)])
OU.M.cycle.theta<-mean(theta.cycle.vect[seq(4, length(theta.cycle.vect), 5)])
OU.M.cycle.theta.sd<-sd(theta.cycle.vect[seq(4, length(theta.cycle.vect), 5)])
OU.M.2.cycle.theta<-mean(theta.cycle.vect[seq(5, length(theta.cycle.vect), 5)])
OU.M.2.cycle.theta.sd<-sd(theta.cycle.vect[seq(5, length(theta.cycle.vect), 5)])
signif(c(BM.1.cycle.theta, BM.M.cycle.theta, OU.1.cycle.theta, OU.M.cycle.theta, OU.M.2.cycle.theta), 2)
signif(c(BM.1.cycle.theta.sd, BM.M.cycle.theta.sd, OU.1.cycle.theta.sd, OU.M.cycle.theta.sd, OU.M.2.cycle.theta.sd), 2)
alpha.cycle<-list()
alpha.cycle<-foreach(i=1:100)%dopar%{alpha.cycle[[i]] <- c(OU.1.cycle[[i]]$alpha, OU.M.cycle[[i]]$alpha)}
alpha.cycle.vect<-(unlist(alpha.cycle))
OU.1.cycle.alpha<-mean(alpha.cycle.vect[seq(1, length(alpha.cycle.vect), 2)])
OU.1.cycle.alpha.sd<-sd(alpha.cycle.vect[seq(1, length(alpha.cycle.vect), 2)])
OU.M.cycle.alpha<-mean(alpha.cycle.vect[seq(2, length(alpha.cycle.vect), 2)])
OU.M.cycle.alpha.sd<-sd(alpha.cycle.vect[seq(2, length(alpha.cycle.vect), 2)])
signif(c(OU.1.cycle.alpha, OU.M.cycle.alpha), 2)
signif(c(OU.1.cycle.alpha.sd, OU.M.cycle.alpha.sd), 2)
aic.cycle<-foreach(i=1:100)%dopar%{aic.cycle[[i]] <- c(BM.1.cycle[[i]]$AICc, BM.M.cycle[[i]]$AICc, OU.1.cycle[[i]]$AICc, OU.M.cycle[[i]]$AICc)}
aic.cycle.vect<-(unlist(aic.cycle))
BM.1.cycle.aic<-mean(aic.cycle.vect[seq(1, length(aic.cycle.vect), 4)])
BM.1.cycle.aic.sd<-sd(aic.cycle.vect[seq(1, length(aic.cycle.vect), 4)])
BM.M.cycle.aic<-mean(aic.cycle.vect[seq(2, length(aic.cycle.vect), 4)])
BM.M.cycle.aic.sd<-sd(aic.cycle.vect[seq(2, length(aic.cycle.vect), 4)])
OU.1.cycle.aic<-mean(aic.cycle.vect[seq(3, length(aic.cycle.vect), 4)])
OU.1.cycle.aic.sd<-sd(aic.cycle.vect[seq(3, length(aic.cycle.vect), 4)])
OU.M.cycle.aic<-mean(aic.cycle.vect[seq(4, length(aic.cycle.vect), 4)])
OU.M.cycle.aic.sd<-sd(aic.cycle.vect[seq(4, length(aic.cycle.vect), 4)])
signif(c(BM.1.cycle.aic, BM.M.cycle.aic, OU.1.cycle.aic, OU.M.cycle.aic), 4)
signif(c(BM.1.cycle.aic.sd, BM.M.cycle.aic.sd, OU.1.cycle.aic.sd, OU.M.cycle.aic.sd), 4)
power.error(OU.M.cycle[[1]], BM.1.cycle[[1]])

# RAW EVOL MODELS 2NDSET -----------------------------------------------------------------------
#peakbrake
raw.BM.1.pb <- list()
raw.BM.M.pb <- list()
raw.OU.1.pb <- list()
raw.OU.M.pb <- list()
raw.aicw.pb <- list()
raw.aic.pb <- list()
raw.BM.1.pb<-foreach(i=1:100)%dopar%{raw.BM.1.pb[[i]]<-mvBM(painttree[[i]], peakbrake,error=se.pb^2, model='BM1')}
raw.BM.M.pb<-foreach(i=1:100)%dopar%{raw.BM.M.pb[[i]]<-mvBM(painttree[[i]], peakbrake,error=se.pb^2, model='BMM')}
raw.OU.1.pb<-foreach(i=1:100)%dopar%{raw.OU.1.pb[[i]]<-mvOU(painttree[[i]], peakbrake,error=se.pb^2,model='OU1')}
raw.OU.M.pb<-foreach(i=1:100)%dopar%{raw.OU.M.pb[[i]]<-mvOU(painttree[[i]], peakbrake,error=se.pb^2,model='OUM')}
raw.aicw.pb<-foreach(i=1:100)%dopar%{raw.aic.pb[[i]] <- aic.w(c(raw.BM.1.pb[[i]]$AICc, raw.BM.M.pb[[i]]$AICc, raw.OU.1.pb[[i]]$AICc, raw.OU.M.pb[[i]]$AICc))}
raw.aicw.pb.vect<-(unlist(raw.aicw.pb))
raw.BM.1.pb.w<-mean(raw.aicw.pb.vect[seq(1, length(raw.aicw.pb.vect), 4)])
raw.BM.M.pb.w<-mean(raw.aicw.pb.vect[seq(2, length(raw.aicw.pb.vect), 4)])
raw.OU.1.pb.w<-mean(raw.aicw.pb.vect[seq(3, length(raw.aicw.pb.vect), 4)])
raw.OU.M.pb.w<-mean(raw.aicw.pb.vect[seq(4, length(raw.aicw.pb.vect), 4)])
signif(c(raw.BM.1.pb.w,raw.BM.M.pb.w, raw.OU.1.pb.w, raw.OU.M.pb.w), 2)
raw.BM.1.pb.w.sd<-sd(raw.aicw.pb.vect[seq(1, length(raw.aicw.pb.vect), 4)])
raw.BM.M.pb.w.sd<-sd(raw.aicw.pb.vect[seq(2, length(raw.aicw.pb.vect), 4)])
raw.OU.1.pb.w.sd<-sd(raw.aicw.pb.vect[seq(3, length(raw.aicw.pb.vect), 4)])
raw.OU.M.pb.w.sd<-sd(raw.aicw.pb.vect[seq(4, length(raw.aicw.pb.vect), 4)])
signif(c(raw.BM.1.pb.w.sd, raw.BM.M.pb.w.sd, raw.OU.1.pb.w.sd, raw.OU.M.pb.w.sd), 4)
raw.sigma.pb <- list()
raw.sigma.pb<-foreach(i=1:100)%dopar%{raw.sigma.pb[[i]] <- c(raw.BM.1.pb[[i]]$sigma, raw.BM.M.pb[[i]]$sigma, raw.OU.1.pb[[i]]$sigma, raw.OU.M.pb[[i]]$sigma)}
raw.sigma.pb.vect<-(unlist(raw.sigma.pb))
raw.BM.1.pb.sigma<-mean(raw.sigma.pb.vect[seq(1, length(raw.sigma.pb.vect), 5)])
raw.BM.1.pb.sigma.sd<-sd(raw.sigma.pb.vect[seq(1, length(raw.sigma.pb.vect), 5)])
raw.BM.M.pb.sigma<-mean(raw.sigma.pb.vect[seq(2, length(raw.sigma.pb.vect), 5)])
raw.BM.M.pb.sigma.sd<-sd(raw.sigma.pb.vect[seq(2, length(raw.sigma.pb.vect), 5)])
raw.BM.M.2.pb.sigma<-mean(raw.sigma.pb.vect[seq(3, length(raw.sigma.pb.vect), 5)])
raw.BM.M.2.pb.sigma.sd<-sd(raw.sigma.pb.vect[seq(3, length(raw.sigma.pb.vect), 5)])
raw.OU.1.pb.sigma<-mean(raw.sigma.pb.vect[seq(4, length(raw.sigma.pb.vect), 5)])
raw.OU.1.pb.sigma.sd<-sd(raw.sigma.pb.vect[seq(4, length(raw.sigma.pb.vect), 5)])
raw.OU.M.pb.sigma<-mean(raw.sigma.pb.vect[seq(5, length(raw.sigma.pb.vect), 5)])
raw.OU.M.pb.sigma.sd<-sd(raw.sigma.pb.vect[seq(5, length(raw.sigma.pb.vect), 5)])
signif(c(raw.BM.1.pb.sigma, raw.BM.M.pb.sigma, raw.BM.M.2.pb.sigma, raw.OU.1.pb.sigma, raw.OU.M.pb.sigma), 2)
signif(c(raw.BM.1.pb.sigma.sd, raw.BM.M.pb.sigma.sd, raw.BM.M.2.pb.sigma.sd, raw.OU.1.pb.sigma.sd, raw.OU.M.pb.sigma.sd), 2)
raw.theta.pb <- list()
raw.theta.pb<-foreach(i=1:100)%dopar%{raw.theta.pb[[i]] <- c(raw.BM.1.pb[[i]]$theta, raw.BM.M.pb[[i]]$theta, raw.OU.1.pb[[i]]$theta, raw.OU.M.pb[[i]]$theta)}
raw.theta.pb.vect<-(unlist(raw.theta.pb))
raw.BM.1.pb.theta<-mean(raw.theta.pb.vect[seq(1, length(raw.theta.pb.vect), 5)])
raw.BM.1.pb.theta.sd<-sd(raw.theta.pb.vect[seq(1, length(raw.theta.pb.vect), 5)])
raw.BM.M.pb.theta<-mean(raw.theta.pb.vect[seq(2, length(raw.theta.pb.vect), 5)])
raw.BM.M.pb.theta.sd<-sd(raw.theta.pb.vect[seq(2, length(raw.theta.pb.vect), 5)])
raw.OU.1.pb.theta<-mean(raw.theta.pb.vect[seq(3, length(raw.theta.pb.vect), 5)])
raw.OU.1.pb.theta.sd<-sd(raw.theta.pb.vect[seq(3, length(raw.theta.pb.vect), 5)])
raw.OU.M.pb.theta<-mean(raw.theta.pb.vect[seq(4, length(raw.theta.pb.vect), 5)])
raw.OU.M.pb.theta.sd<-sd(raw.theta.pb.vect[seq(4, length(raw.theta.pb.vect), 5)])
raw.OU.M.2.pb.theta<-mean(raw.theta.pb.vect[seq(5, length(raw.theta.pb.vect), 5)])
raw.OU.M.2.pb.theta.sd<-sd(raw.theta.pb.vect[seq(5, length(raw.theta.pb.vect), 5)])
signif(c(raw.BM.1.pb.theta, raw.BM.M.pb.theta, raw.OU.1.pb.theta, raw.OU.M.pb.theta, raw.OU.M.2.pb.theta), 2)
signif(c(raw.BM.1.pb.theta.sd, raw.BM.M.pb.theta.sd, raw.OU.1.pb.theta.sd, raw.OU.M.pb.theta.sd, raw.OU.M.2.pb.theta.sd), 2)
raw.alpha.pb<-list()
raw.alpha.pb<-foreach(i=1:100)%dopar%{raw.alpha.pb[[i]] <- c(raw.OU.1.pb[[i]]$alpha, raw.OU.M.pb[[i]]$alpha)}
raw.alpha.pb.vect<-(unlist(raw.alpha.pb))
raw.OU.1.pb.alpha<-mean(raw.alpha.pb.vect[seq(1, length(raw.alpha.pb.vect), 2)])
raw.OU.1.pb.alpha.sd<-sd(raw.alpha.pb.vect[seq(1, length(raw.alpha.pb.vect), 2)])
raw.OU.M.pb.alpha<-mean(raw.alpha.pb.vect[seq(2, length(raw.alpha.pb.vect), 2)])
raw.OU.M.pb.alpha.sd<-sd(raw.alpha.pb.vect[seq(2, length(raw.alpha.pb.vect), 2)])
signif(c(raw.OU.1.pb.alpha, raw.OU.M.pb.alpha), 2)
signif(c(raw.OU.1.pb.alpha.sd, raw.OU.M.pb.alpha.sd), 2)
raw.aic.pb<-foreach(i=1:100)%dopar%{raw.aic.pb[[i]] <- c(raw.BM.1.pb[[i]]$AICc, raw.BM.M.pb[[i]]$AICc, raw.OU.1.pb[[i]]$AICc, raw.OU.M.pb[[i]]$AICc)}
raw.aic.pb.vect<-(unlist(raw.aic.pb))
raw.BM.1.pb.aic<-mean(raw.aic.pb.vect[seq(1, length(raw.aic.pb.vect), 4)])
raw.BM.1.pb.aic.sd<-sd(raw.aic.pb.vect[seq(1, length(raw.aic.pb.vect), 4)])
raw.BM.M.pb.aic<-mean(raw.aic.pb.vect[seq(2, length(raw.aic.pb.vect), 4)])
raw.BM.M.pb.aic.sd<-sd(raw.aic.pb.vect[seq(2, length(raw.aic.pb.vect), 4)])
raw.OU.1.pb.aic<-mean(raw.aic.pb.vect[seq(3, length(raw.aic.pb.vect), 4)])
raw.OU.1.pb.aic.sd<-sd(raw.aic.pb.vect[seq(3, length(raw.aic.pb.vect), 4)])
raw.OU.M.pb.aic<-mean(raw.aic.pb.vect[seq(4, length(raw.aic.pb.vect), 4)])
raw.OU.M.pb.aic.sd<-sd(raw.aic.pb.vect[seq(4, length(raw.aic.pb.vect), 4)])
signif(c(raw.BM.1.pb.aic, raw.BM.M.pb.aic, raw.OU.1.pb.aic, raw.OU.M.pb.aic), 4)
signif(c(raw.BM.1.pb.aic.sd, raw.BM.M.pb.aic.sd, raw.OU.1.pb.aic.sd, raw.OU.M.pb.aic.sd), 4)
power.error(raw.OU.M.pb[[1]], raw.BM.1.pb[[1]])

#peakaccel
raw.BM.1.pa <- list()
raw.BM.M.pa <- list()
raw.OU.1.pa <- list()
raw.OU.M.pa <- list()
raw.aicw.pa <- list()
raw.aic.pa <- list()
raw.BM.1.pa<-foreach(i=1:100)%dopar%{raw.BM.1.pa[[i]]<-mvBM(painttree[[i]], peakaccel,error=se.pa^2, model='BM1')}
raw.BM.M.pa<-foreach(i=1:100)%dopar%{raw.BM.M.pa[[i]]<-mvBM(painttree[[i]], peakaccel,error=se.pa^2, model='BMM')}
raw.OU.1.pa<-foreach(i=1:100)%dopar%{raw.OU.1.pa[[i]]<-mvOU(painttree[[i]], peakaccel,error=se.pa^2,model='OU1')}
raw.OU.M.pa<-foreach(i=1:100)%dopar%{raw.OU.M.pa[[i]]<-mvOU(painttree[[i]], peakaccel,error=se.pa^2,model='OUM')}
raw.aicw.pa<-foreach(i=1:100)%dopar%{raw.aic.pa[[i]] <- aic.w(c(raw.BM.1.pa[[i]]$AICc, raw.BM.M.pa[[i]]$AICc, raw.OU.1.pa[[i]]$AICc, raw.OU.M.pa[[i]]$AICc))}
raw.aicw.pa.vect<-(unlist(raw.aicw.pa))
raw.BM.1.pa.w<-mean(raw.aicw.pa.vect[seq(1, length(raw.aicw.pa.vect), 4)])
raw.BM.M.pa.w<-mean(raw.aicw.pa.vect[seq(2, length(raw.aicw.pa.vect), 4)])
raw.OU.1.pa.w<-mean(raw.aicw.pa.vect[seq(3, length(raw.aicw.pa.vect), 4)])
raw.OU.M.pa.w<-mean(raw.aicw.pa.vect[seq(4, length(raw.aicw.pa.vect), 4)])
raw.BM.1.pa.w.sd<-sd(raw.aicw.pa.vect[seq(1, length(raw.aicw.pa.vect), 4)])
raw.BM.M.pa.w.sd<-sd(raw.aicw.pa.vect[seq(2, length(raw.aicw.pa.vect), 4)])
raw.OU.1.pa.w.sd<-sd(raw.aicw.pa.vect[seq(3, length(raw.aicw.pa.vect), 4)])
raw.OU.M.pa.w.sd<-sd(raw.aicw.pa.vect[seq(4, length(raw.aicw.pa.vect), 4)])
signif(c(raw.BM.1.pa.w, raw.BM.M.pa.w, raw.OU.1.pa.w, raw.OU.M.pa.w), 2)
signif(c(raw.BM.1.pa.w.sd, raw.BM.M.pa.w.sd, raw.OU.1.pa.w.sd, raw.OU.M.pa.w.sd), 2)
raw.sigma.pa <- list()
raw.sigma.pa<-foreach(i=1:100)%dopar%{raw.sigma.pa[[i]] <- c(raw.BM.1.pa[[i]]$sigma, raw.BM.M.pa[[i]]$sigma, raw.OU.1.pa[[i]]$sigma, raw.OU.M.pa[[i]]$sigma)}
raw.sigma.pa.vect<-(unlist(raw.sigma.pa))
raw.BM.1.pa.sigma<-mean(raw.sigma.pa.vect[seq(1, length(raw.sigma.pa.vect), 5)])
raw.BM.1.pa.sigma.sd<-sd(raw.sigma.pa.vect[seq(1, length(raw.sigma.pa.vect), 5)])
raw.BM.M.pa.sigma<-mean(raw.sigma.pa.vect[seq(2, length(raw.sigma.pa.vect), 5)])
raw.BM.M.pa.sigma.sd<-sd(raw.sigma.pa.vect[seq(2, length(raw.sigma.pa.vect), 5)])
raw.BM.M.2.pa.sigma<-mean(raw.sigma.pa.vect[seq(3, length(raw.sigma.pa.vect), 5)])
raw.BM.M.2.pa.sigma.sd<-sd(raw.sigma.pa.vect[seq(3, length(raw.sigma.pa.vect), 5)])
raw.OU.1.pa.sigma<-mean(raw.sigma.pa.vect[seq(4, length(raw.sigma.pa.vect), 5)])
raw.OU.1.pa.sigma.sd<-sd(raw.sigma.pa.vect[seq(4, length(raw.sigma.pa.vect), 5)])
raw.OU.M.pa.sigma<-mean(raw.sigma.pa.vect[seq(5, length(raw.sigma.pa.vect), 5)])
raw.OU.M.pa.sigma.sd<-sd(raw.sigma.pa.vect[seq(5, length(raw.sigma.pa.vect), 5)])
signif(c(raw.BM.1.pa.sigma, raw.BM.M.pa.sigma, raw.BM.M.2.pa.sigma, raw.OU.1.pa.sigma, raw.OU.M.pa.sigma), 2)
signif(c(raw.BM.1.pa.sigma.sd, raw.BM.M.pa.sigma.sd, raw.BM.M.2.pa.sigma.sd, raw.OU.1.pa.sigma.sd, raw.OU.M.pa.sigma.sd), 2)
raw.theta.pa <- list()
raw.theta.pa<-foreach(i=1:100)%dopar%{raw.theta.pa[[i]] <- c(raw.BM.1.pa[[i]]$theta, raw.BM.M.pa[[i]]$theta, raw.OU.1.pa[[i]]$theta, raw.OU.M.pa[[i]]$theta)}
raw.theta.pa.vect<-(unlist(raw.theta.pa))
raw.BM.1.pa.theta<-mean(raw.theta.pa.vect[seq(1, length(raw.theta.pa.vect), 5)])
raw.BM.1.pa.theta.sd<-sd(raw.theta.pa.vect[seq(1, length(raw.theta.pa.vect), 5)])
raw.BM.M.pa.theta<-mean(raw.theta.pa.vect[seq(2, length(raw.theta.pa.vect), 5)])
raw.BM.M.pa.theta.sd<-sd(raw.theta.pa.vect[seq(2, length(raw.theta.pa.vect), 5)])
raw.OU.1.pa.theta<-mean(raw.theta.pa.vect[seq(3, length(raw.theta.pa.vect), 5)])
raw.OU.1.pa.theta.sd<-sd(raw.theta.pa.vect[seq(3, length(raw.theta.pa.vect), 5)])
raw.OU.M.pa.theta<-mean(raw.theta.pa.vect[seq(4, length(raw.theta.pa.vect), 5)])
raw.OU.M.pa.theta.sd<-sd(raw.theta.pa.vect[seq(4, length(raw.theta.pa.vect), 5)])
raw.OU.M.2.pa.theta<-mean(raw.theta.pa.vect[seq(5, length(raw.theta.pa.vect), 5)])
raw.OU.M.2.pa.theta.sd<-sd(raw.theta.pa.vect[seq(5, length(raw.theta.pa.vect), 5)])
signif(c(raw.BM.1.pa.theta, raw.BM.M.pa.theta, raw.OU.1.pa.theta, raw.OU.M.pa.theta, raw.OU.M.2.pa.theta), 2)
signif(c(raw.BM.1.pa.theta.sd, raw.BM.M.pa.theta.sd, raw.OU.1.pa.theta.sd, raw.OU.M.pa.theta.sd, raw.OU.M.2.pa.theta.sd), 2)
raw.alpha.pa<-list()
raw.alpha.pa<-foreach(i=1:100)%dopar%{raw.alpha.pa[[i]] <- c(raw.OU.1.pa[[i]]$alpha, raw.OU.M.pa[[i]]$alpha)}
raw.alpha.pa.vect<-(unlist(raw.alpha.pa))
raw.OU.1.pa.alpha<-mean(raw.alpha.pa.vect[seq(1, length(raw.alpha.pa.vect), 2)])
raw.OU.1.pa.alpha.sd<-sd(raw.alpha.pa.vect[seq(1, length(raw.alpha.pa.vect), 2)])
raw.OU.M.pa.alpha<-mean(raw.alpha.pa.vect[seq(2, length(raw.alpha.pa.vect), 2)])
raw.OU.M.pa.alpha.sd<-sd(raw.alpha.pa.vect[seq(2, length(raw.alpha.pa.vect), 2)])
signif(c(raw.OU.1.pa.alpha, raw.OU.M.pa.alpha), 2)
signif(c(raw.OU.1.pa.alpha.sd, raw.OU.M.pa.alpha.sd), 2)
raw.aic.pa<-foreach(i=1:100)%dopar%{raw.aic.pa[[i]] <- c(raw.BM.1.pa[[i]]$AICc, raw.BM.M.pa[[i]]$AICc, raw.OU.1.pa[[i]]$AICc, raw.OU.M.pa[[i]]$AICc)}
raw.aic.pa.vect<-(unlist(raw.aic.pa))
raw.BM.1.pa.aic<-mean(raw.aic.pa.vect[seq(1, length(raw.aic.pa.vect), 4)])
raw.BM.1.pa.aic.sd<-sd(raw.aic.pa.vect[seq(1, length(raw.aic.pa.vect), 4)])
raw.BM.M.pa.aic<-mean(raw.aic.pa.vect[seq(2, length(raw.aic.pa.vect), 4)])
raw.BM.M.pa.aic.sd<-sd(raw.aic.pa.vect[seq(2, length(raw.aic.pa.vect), 4)])
raw.OU.1.pa.aic<-mean(raw.aic.pa.vect[seq(3, length(raw.aic.pa.vect), 4)])
raw.OU.1.pa.aic.sd<-sd(raw.aic.pa.vect[seq(3, length(raw.aic.pa.vect), 4)])
raw.OU.M.pa.aic<-mean(raw.aic.pa.vect[seq(4, length(raw.aic.pa.vect), 4)])
raw.OU.M.pa.aic.sd<-sd(raw.aic.pa.vect[seq(4, length(raw.aic.pa.vect), 4)])
signif(c(raw.BM.1.pa.aic, raw.BM.M.pa.aic, raw.OU.1.pa.aic, raw.OU.M.pa.aic), 2)
signif(c(raw.BM.1.pa.aic.sd, raw.BM.M.pa.aic.sd, raw.OU.1.pa.aic.sd, raw.OU.M.pa.aic.sd), 2)
power.error(raw.OU.M.pa[[1]], raw.BM.1.pa[[1]])

#peakmed
raw.BM.1.pm <- list()
raw.BM.M.pm <- list()
raw.OU.1.pm <- list()
raw.OU.M.pm <- list()
raw.aicw.pm <- list()
raw.aic.pm <- list()
raw.BM.1.pm<-foreach(i=1:100)%dopar%{raw.BM.1.pm[[i]]<-mvBM(painttree[[i]], peakmed,error=se.pm^2, model='BM1')}
raw.BM.M.pm<-foreach(i=1:100)%dopar%{raw.BM.M.pm[[i]]<-mvBM(painttree[[i]], peakmed,error=se.pm^2, model='BMM')}
raw.OU.1.pm<-foreach(i=1:100)%dopar%{raw.OU.1.pm[[i]]<-mvOU(painttree[[i]], peakmed,error=se.pm^2,model='OU1')}
raw.OU.M.pm<-foreach(i=1:100)%dopar%{raw.OU.M.pm[[i]]<-mvOU(painttree[[i]], peakmed,error=se.pm^2,model='OUM')}
raw.aicw.pm<-foreach(i=1:100)%dopar%{raw.aic.pm[[i]] <- aic.w(c(raw.BM.1.pm[[i]]$AICc, raw.BM.M.pm[[i]]$AICc, raw.OU.1.pm[[i]]$AICc, raw.OU.M.pm[[i]]$AICc))}
raw.aicw.pm.vect<-(unlist(raw.aicw.pm))
raw.BM.1.pm.w<-mean(raw.aicw.pm.vect[seq(1, length(raw.aicw.pm.vect), 4)])
raw.BM.M.pm.w<-mean(raw.aicw.pm.vect[seq(2, length(raw.aicw.pm.vect), 4)])
raw.OU.1.pm.w<-mean(raw.aicw.pm.vect[seq(3, length(raw.aicw.pm.vect), 4)])
raw.OU.M.pm.w<-mean(raw.aicw.pm.vect[seq(4, length(raw.aicw.pm.vect), 4)])
signif(c(raw.BM.1.pm.w, raw.BM.M.pm.w, raw.OU.1.pm.w, raw.OU.M.pm.w), 2)
raw.BM.1.pm.w.sd<-sd(raw.aicw.pm.vect[seq(1, length(raw.aicw.pm.vect), 4)])
raw.BM.M.pm.w.sd<-sd(raw.aicw.pm.vect[seq(2, length(raw.aicw.pm.vect), 4)])
raw.OU.1.pm.w.sd<-sd(raw.aicw.pm.vect[seq(3, length(raw.aicw.pm.vect), 4)])
raw.OU.M.pm.w.sd<-sd(raw.aicw.pm.vect[seq(4, length(raw.aicw.pm.vect), 4)])
signif(c(raw.BM.1.pm.w.sd, raw.BM.M.pm.w.sd, raw.OU.1.pm.w.sd, raw.OU.M.pm.w.sd), 2)
raw.sigma.pm <- list()
raw.sigma.pm<-foreach(i=1:100)%dopar%{raw.sigma.pm[[i]] <- c(raw.BM.1.pm[[i]]$sigma, raw.BM.M.pm[[i]]$sigma, raw.OU.1.pm[[i]]$sigma, raw.OU.M.pm[[i]]$sigma)}
raw.sigma.pm.vect<-(unlist(raw.sigma.pm))
raw.BM.1.pm.sigma<-mean(raw.sigma.pm.vect[seq(1, length(raw.sigma.pm.vect), 5)])
raw.BM.1.pm.sigma.sd<-sd(raw.sigma.pm.vect[seq(1, length(raw.sigma.pm.vect), 5)])
raw.BM.M.pm.sigma<-mean(raw.sigma.pm.vect[seq(2, length(raw.sigma.pm.vect), 5)])
raw.BM.M.pm.sigma.sd<-sd(raw.sigma.pm.vect[seq(2, length(raw.sigma.pm.vect), 5)])
raw.BM.M.2.pm.sigma<-mean(raw.sigma.pm.vect[seq(3, length(raw.sigma.pm.vect), 5)])
raw.BM.M.2.pm.sigma.sd<-sd(raw.sigma.pm.vect[seq(3, length(raw.sigma.pm.vect), 5)])
raw.OU.1.pm.sigma<-mean(raw.sigma.pm.vect[seq(4, length(raw.sigma.pm.vect), 5)])
raw.OU.1.pm.sigma.sd<-sd(raw.sigma.pm.vect[seq(4, length(raw.sigma.pm.vect), 5)])
raw.OU.M.pm.sigma<-mean(raw.sigma.pm.vect[seq(5, length(raw.sigma.pm.vect), 5)])
raw.OU.M.pm.sigma.sd<-sd(raw.sigma.pm.vect[seq(5, length(raw.sigma.pm.vect), 5)])
signif(c(raw.BM.1.pm.sigma, raw.BM.M.pm.sigma, raw.BM.M.2.pm.sigma, raw.OU.1.pm.sigma, raw.OU.M.pm.sigma), 2)
signif(c(raw.BM.1.pm.sigma.sd, raw.BM.M.pm.sigma.sd, raw.BM.M.2.pm.sigma.sd, raw.OU.1.pm.sigma.sd, raw.OU.M.pm.sigma.sd), 2)
raw.theta.pm <- list()
raw.theta.pm<-foreach(i=1:100)%dopar%{raw.theta.pm[[i]] <- c(raw.BM.1.pm[[i]]$theta, raw.BM.M.pm[[i]]$theta, raw.OU.1.pm[[i]]$theta, raw.OU.M.pm[[i]]$theta)}
raw.theta.pm.vect<-(unlist(raw.theta.pm))
raw.BM.1.pm.theta<-mean(raw.theta.pm.vect[seq(1, length(raw.theta.pm.vect), 5)])
raw.BM.1.pm.theta.sd<-sd(raw.theta.pm.vect[seq(1, length(raw.theta.pm.vect), 5)])
raw.BM.M.pm.theta<-mean(raw.theta.pm.vect[seq(2, length(raw.theta.pm.vect), 5)])
raw.BM.M.pm.theta.sd<-sd(raw.theta.pm.vect[seq(2, length(raw.theta.pm.vect), 5)])
raw.OU.1.pm.theta<-mean(raw.theta.pm.vect[seq(3, length(raw.theta.pm.vect), 5)])
raw.OU.1.pm.theta.sd<-sd(raw.theta.pm.vect[seq(3, length(raw.theta.pm.vect), 5)])
raw.OU.M.pm.theta<-mean(raw.theta.pm.vect[seq(4, length(raw.theta.pm.vect), 5)])
raw.OU.M.pm.theta.sd<-sd(raw.theta.pm.vect[seq(4, length(raw.theta.pm.vect), 5)])
raw.OU.M.2.pm.theta<-mean(raw.theta.pm.vect[seq(5, length(raw.theta.pm.vect), 5)])
raw.OU.M.2.pm.theta.sd<-sd(raw.theta.pm.vect[seq(5, length(raw.theta.pm.vect), 5)])
signif(c(raw.BM.1.pm.theta, raw.BM.M.pm.theta, raw.OU.1.pm.theta, raw.OU.M.pm.theta, raw.OU.M.2.pm.theta), 2)
signif(c(raw.BM.1.pm.theta.sd, raw.BM.M.pm.theta.sd, raw.OU.1.pm.theta.sd, raw.OU.M.pm.theta.sd, raw.OU.M.2.pm.theta.sd), 2)
raw.alpha.pm<-list()
raw.alpha.pm<-foreach(i=1:100)%dopar%{raw.alpha.pm[[i]] <- c(raw.OU.1.pm[[i]]$alpha, raw.OU.M.pm[[i]]$alpha)}
raw.alpha.pm.vect<-(unlist(raw.alpha.pm))
raw.OU.1.pm.alpha<-mean(raw.alpha.pm.vect[seq(1, length(raw.alpha.pm.vect), 2)])
raw.OU.1.pm.alpha.sd<-sd(raw.alpha.pm.vect[seq(1, length(raw.alpha.pm.vect), 2)])
raw.OU.M.pm.alpha<-mean(raw.alpha.pm.vect[seq(2, length(raw.alpha.pm.vect), 2)])
raw.OU.M.pm.alpha.sd<-sd(raw.alpha.pm.vect[seq(2, length(raw.alpha.pm.vect), 2)])
signif(c(raw.OU.1.pm.alpha, raw.OU.M.pm.alpha), 2)
signif(c(raw.OU.1.pm.alpha.sd, raw.OU.M.pm.alpha.sd), 2)
raw.aic.pm<-foreach(i=1:100)%dopar%{raw.aic.pm[[i]] <- c(raw.BM.1.pm[[i]]$AICc, raw.BM.M.pm[[i]]$AICc, raw.OU.1.pm[[i]]$AICc, raw.OU.M.pm[[i]]$AICc)}
raw.aic.pm.vect<-(unlist(raw.aic.pm))
raw.BM.1.pm.aic<-mean(raw.aic.pm.vect[seq(1, length(raw.aic.pm.vect), 4)])
raw.BM.1.pm.aic.sd<-sd(raw.aic.pm.vect[seq(1, length(raw.aic.pm.vect), 4)])
raw.BM.M.pm.aic<-mean(raw.aic.pm.vect[seq(2, length(raw.aic.pm.vect), 4)])
raw.BM.M.pm.aic.sd<-sd(raw.aic.pm.vect[seq(2, length(raw.aic.pm.vect), 4)])
raw.OU.1.pm.aic<-mean(raw.aic.pm.vect[seq(3, length(raw.aic.pm.vect), 4)])
raw.OU.1.pm.aic.sd<-sd(raw.aic.pm.vect[seq(3, length(raw.aic.pm.vect), 4)])
raw.OU.M.pm.aic<-mean(raw.aic.pm.vect[seq(4, length(raw.aic.pm.vect), 4)])
raw.OU.M.pm.aic.sd<-sd(raw.aic.pm.vect[seq(4, length(raw.aic.pm.vect), 4)])
signif(c(raw.BM.1.pm.aic, raw.BM.M.pm.aic, raw.OU.1.pm.aic, raw.OU.M.pm.aic), 3)
signif(c(raw.BM.1.pm.aic.sd, raw.BM.M.pm.aic.sd, raw.OU.1.pm.aic.sd, raw.OU.M.pm.aic.sd), 3)
power.error(raw.OU.M.pm[[1]], raw.BM.1.pm[[1]])

#peaklat
raw.BM.1.pl <- list()
raw.BM.M.pl <- list()
raw.OU.1.pl <- list()
raw.OU.M.pl <- list()
raw.aicw.pl <- list()
raw.aic.pl <- list()
raw.BM.1.pl<-foreach(i=1:100)%dopar%{raw.BM.1.pl[[i]]<-mvBM(painttree[[i]], peaklat,error=se.pl^2, model='BM1')}
raw.BM.M.pl<-foreach(i=1:100)%dopar%{raw.BM.M.pl[[i]]<-mvBM(painttree[[i]], peaklat,error=se.pl^2, model='BMM')}
raw.OU.1.pl<-foreach(i=1:100)%dopar%{raw.OU.1.pl[[i]]<-mvOU(painttree[[i]], peaklat,error=se.pl^2,model='OU1')}
raw.OU.M.pl<-foreach(i=1:100)%dopar%{raw.OU.M.pl[[i]]<-mvOU(painttree[[i]], peaklat,error=se.pl^2,model='OUM')}
raw.aicw.pl<-foreach(i=1:100)%dopar%{raw.aic.pl[[i]] <- aic.w(c(raw.BM.1.pl[[i]]$AICc, raw.BM.M.pl[[i]]$AICc, raw.OU.1.pl[[i]]$AICc, raw.OU.M.pl[[i]]$AICc))}
raw.aicw.pl.vect<-(unlist(raw.aicw.pl))
raw.BM.1.pl.w<-mean(raw.aicw.pl.vect[seq(1, length(raw.aicw.pl.vect), 4)])
raw.BM.M.pl.w<-mean(raw.aicw.pl.vect[seq(2, length(raw.aicw.pl.vect), 4)])
raw.OU.1.pl.w<-mean(raw.aicw.pl.vect[seq(3, length(raw.aicw.pl.vect), 4)])
raw.OU.M.pl.w<-mean(raw.aicw.pl.vect[seq(4, length(raw.aicw.pl.vect), 4)])
signif(c(raw.BM.1.pl.w, raw.BM.M.pl.w, raw.OU.1.pl.w, raw.OU.M.pl.w), 2)
raw.BM.1.pl.w.sd<-sd(raw.aicw.pl.vect[seq(1, length(raw.aicw.pl.vect), 4)])
raw.BM.M.pl.w.sd<-sd(raw.aicw.pl.vect[seq(2, length(raw.aicw.pl.vect), 4)])
raw.OU.1.pl.w.sd<-sd(raw.aicw.pl.vect[seq(3, length(raw.aicw.pl.vect), 4)])
raw.OU.M.pl.w.sd<-sd(raw.aicw.pl.vect[seq(4, length(raw.aicw.pl.vect), 4)])
signif(c(raw.BM.1.pl.w.sd, raw.BM.M.pl.w.sd, raw.OU.1.pl.w.sd, raw.OU.M.pl.w.sd), 2)
raw.sigma.pl <- list()
raw.sigma.pl<-foreach(i=1:100)%dopar%{raw.sigma.pl[[i]] <- c(raw.BM.1.pl[[i]]$sigma, raw.BM.M.pl[[i]]$sigma, raw.OU.1.pl[[i]]$sigma, raw.OU.M.pl[[i]]$sigma)}
raw.sigma.pl.vect<-(unlist(raw.sigma.pl))
raw.BM.1.pl.sigma<-mean(raw.sigma.pl.vect[seq(1, length(raw.sigma.pl.vect), 5)])
raw.BM.1.pl.sigma.sd<-sd(raw.sigma.pl.vect[seq(1, length(raw.sigma.pl.vect), 5)])
raw.BM.M.pl.sigma<-mean(raw.sigma.pl.vect[seq(2, length(raw.sigma.pl.vect), 5)])
raw.BM.M.pl.sigma.sd<-sd(raw.sigma.pl.vect[seq(2, length(raw.sigma.pl.vect), 5)])
raw.BM.M.2.pl.sigma<-mean(raw.sigma.pl.vect[seq(3, length(raw.sigma.pl.vect), 5)])
raw.BM.M.2.pl.sigma.sd<-sd(raw.sigma.pl.vect[seq(3, length(raw.sigma.pl.vect), 5)])
raw.OU.1.pl.sigma<-mean(raw.sigma.pl.vect[seq(4, length(raw.sigma.pl.vect), 5)])
raw.OU.1.pl.sigma.sd<-sd(raw.sigma.pl.vect[seq(4, length(raw.sigma.pl.vect), 5)])
raw.OU.M.pl.sigma<-mean(raw.sigma.pl.vect[seq(5, length(raw.sigma.pl.vect), 5)])
raw.OU.M.pl.sigma.sd<-sd(raw.sigma.pl.vect[seq(5, length(raw.sigma.pl.vect), 5)])
signif(c(raw.BM.1.pl.sigma, raw.BM.M.pl.sigma, raw.BM.M.2.pl.sigma, raw.OU.1.pl.sigma, raw.OU.M.pl.sigma), 2)
signif(c(raw.BM.1.pl.sigma.sd, raw.BM.M.pl.sigma.sd, raw.BM.M.2.pl.sigma.sd, raw.OU.1.pl.sigma.sd, raw.OU.M.pl.sigma.sd), 2)
raw.theta.pl <- list()
raw.theta.pl<-foreach(i=1:100)%dopar%{raw.theta.pl[[i]] <- c(raw.BM.1.pl[[i]]$theta, raw.BM.M.pl[[i]]$theta, raw.OU.1.pl[[i]]$theta, raw.OU.M.pl[[i]]$theta)}
raw.theta.pl.vect<-(unlist(raw.theta.pl))
raw.BM.1.pl.theta<-mean(raw.theta.pl.vect[seq(1, length(raw.theta.pl.vect), 5)])
raw.BM.1.pl.theta.sd<-sd(raw.theta.pl.vect[seq(1, length(raw.theta.pl.vect), 5)])
raw.BM.M.pl.theta<-mean(raw.theta.pl.vect[seq(2, length(raw.theta.pl.vect), 5)])
raw.BM.M.pl.theta.sd<-sd(raw.theta.pl.vect[seq(2, length(raw.theta.pl.vect), 5)])
raw.OU.1.pl.theta<-mean(raw.theta.pl.vect[seq(3, length(raw.theta.pl.vect), 5)])
raw.OU.1.pl.theta.sd<-sd(raw.theta.pl.vect[seq(3, length(raw.theta.pl.vect), 5)])
raw.OU.M.pl.theta<-mean(raw.theta.pl.vect[seq(4, length(raw.theta.pl.vect), 5)])
raw.OU.M.pl.theta.sd<-sd(raw.theta.pl.vect[seq(4, length(raw.theta.pl.vect), 5)])
raw.OU.M.2.pl.theta<-mean(raw.theta.pl.vect[seq(5, length(raw.theta.pl.vect), 5)])
raw.OU.M.2.pl.theta.sd<-sd(raw.theta.pl.vect[seq(5, length(raw.theta.pl.vect), 5)])
signif(c(raw.BM.1.pl.theta, raw.BM.M.pl.theta, raw.OU.1.pl.theta, raw.OU.M.pl.theta, raw.OU.M.2.pl.theta), 2)
signif(c(raw.BM.1.pl.theta.sd, raw.BM.M.pl.theta.sd, raw.OU.1.pl.theta.sd, raw.OU.M.pl.theta.sd, raw.OU.M.2.pl.theta.sd), 2)
raw.alpha.pl<-list()
raw.alpha.pl<-foreach(i=1:100)%dopar%{raw.alpha.pl[[i]] <- c(raw.OU.1.pl[[i]]$alpha, raw.OU.M.pl[[i]]$alpha)}
raw.alpha.pl.vect<-(unlist(raw.alpha.pl))
raw.OU.1.pl.alpha<-mean(raw.alpha.pl.vect[seq(1, length(raw.alpha.pl.vect), 2)])
raw.OU.1.pl.alpha.sd<-sd(raw.alpha.pl.vect[seq(1, length(raw.alpha.pl.vect), 2)])
raw.OU.M.pl.alpha<-mean(raw.alpha.pl.vect[seq(2, length(raw.alpha.pl.vect), 2)])
raw.OU.M.pl.alpha.sd<-sd(raw.alpha.pl.vect[seq(2, length(raw.alpha.pl.vect), 2)])
signif(c(raw.OU.1.pl.alpha, raw.OU.M.pl.alpha), 2)
signif(c(raw.OU.1.pl.alpha.sd, raw.OU.M.pl.alpha.sd), 2)
raw.aic.pl<-foreach(i=1:100)%dopar%{raw.aic.pl[[i]] <- c(raw.BM.1.pl[[i]]$AICc, raw.BM.M.pl[[i]]$AICc, raw.OU.1.pl[[i]]$AICc, raw.OU.M.pl[[i]]$AICc)}
raw.aic.pl.vect<-(unlist(raw.aic.pl))
raw.BM.1.pl.aic<-mean(raw.aic.pl.vect[seq(1, length(raw.aic.pl.vect), 4)])
raw.BM.1.pl.aic.sd<-sd(raw.aic.pl.vect[seq(1, length(raw.aic.pl.vect), 4)])
raw.BM.M.pl.aic<-mean(raw.aic.pl.vect[seq(2, length(raw.aic.pl.vect), 4)])
raw.BM.M.pl.aic.sd<-sd(raw.aic.pl.vect[seq(2, length(raw.aic.pl.vect), 4)])
raw.OU.1.pl.aic<-mean(raw.aic.pl.vect[seq(3, length(raw.aic.pl.vect), 4)])
raw.OU.1.pl.aic.sd<-sd(raw.aic.pl.vect[seq(3, length(raw.aic.pl.vect), 4)])
raw.OU.M.pl.aic<-mean(raw.aic.pl.vect[seq(4, length(raw.aic.pl.vect), 4)])
raw.OU.M.pl.aic.sd<-sd(raw.aic.pl.vect[seq(4, length(raw.aic.pl.vect), 4)])
signif(c(raw.BM.1.pl.aic, raw.BM.M.pl.aic, raw.OU.1.pl.aic, raw.OU.M.pl.aic), 3)
signif(c(raw.BM.1.pl.aic.sd, raw.BM.M.pl.aic.sd, raw.OU.1.pl.aic.sd, raw.OU.M.pl.aic.sd), 3)
power.error(raw.OU.M.pl[[1]], raw.BM.1.pl[[1]])


#peakv
raw.BM.1.pv <- list()
raw.BM.M.pv <- list()
raw.OU.1.pv <- list()
raw.OU.M.pv <- list()
raw.aicw.pv <- list()
raw.aic.pv <- list()
raw.BM.1.pv<-foreach(i=1:100)%dopar%{raw.BM.1.pv[[i]]<-mvBM(painttree[[i]], peakv,error=se.pv^2, model='BM1')}
raw.BM.M.pv<-foreach(i=1:100)%dopar%{raw.BM.M.pv[[i]]<-mvBM(painttree[[i]], peakv,error=se.pv^2, model='BMM')}
raw.OU.1.pv<-foreach(i=1:100)%dopar%{raw.OU.1.pv[[i]]<-mvOU(painttree[[i]], peakv,error=se.pv^2,model='OU1')}
raw.OU.M.pv<-foreach(i=1:100)%dopar%{raw.OU.M.pv[[i]]<-mvOU(painttree[[i]], peakv,error=se.pv^2,model='OUM')}
raw.aicw.pv<-foreach(i=1:100)%dopar%{raw.aic.pv[[i]] <- aic.w(c(raw.BM.1.pv[[i]]$AICc, raw.BM.M.pv[[i]]$AICc, raw.OU.1.pv[[i]]$AICc, raw.OU.M.pv[[i]]$AICc))}
raw.aicw.pv.vect<-(unlist(raw.aicw.pv))
raw.BM.1.pv.w<-mean(raw.aicw.pv.vect[seq(1, length(raw.aicw.pv.vect), 4)])
raw.BM.M.pv.w<-mean(raw.aicw.pv.vect[seq(2, length(raw.aicw.pv.vect), 4)])
raw.OU.1.pv.w<-mean(raw.aicw.pv.vect[seq(3, length(raw.aicw.pv.vect), 4)])
raw.OU.M.pv.w<-mean(raw.aicw.pv.vect[seq(4, length(raw.aicw.pv.vect), 4)])
signif(c(raw.BM.1.pv.w, raw.BM.M.pv.w, raw.OU.1.pv.w, raw.OU.M.pv.w), 2)
raw.BM.1.pv.w.sd<-sd(raw.aicw.pv.vect[seq(1, length(raw.aicw.pv.vect), 4)])
raw.BM.M.pv.w.sd<-sd(raw.aicw.pv.vect[seq(2, length(raw.aicw.pv.vect), 4)])
raw.OU.1.pv.w.sd<-sd(raw.aicw.pv.vect[seq(3, length(raw.aicw.pv.vect), 4)])
raw.OU.M.pv.w.sd<-sd(raw.aicw.pv.vect[seq(4, length(raw.aicw.pv.vect), 4)])
signif(c(raw.BM.1.pv.w.sd, raw.BM.M.pv.w.sd, raw.OU.1.pv.w.sd, raw.OU.M.pv.w.sd), 2)
raw.sigma.pv <- list()
raw.sigma.pv<-foreach(i=1:100)%dopar%{raw.sigma.pv[[i]] <- c(raw.BM.1.pv[[i]]$sigma, raw.BM.M.pv[[i]]$sigma, raw.OU.1.pv[[i]]$sigma, raw.OU.M.pv[[i]]$sigma)}
raw.sigma.pv.vect<-(unlist(raw.sigma.pv))
raw.BM.1.pv.sigma<-mean(raw.sigma.pv.vect[seq(1, length(raw.sigma.pv.vect), 5)])
raw.BM.1.pv.sigma.sd<-sd(raw.sigma.pv.vect[seq(1, length(raw.sigma.pv.vect), 5)])
raw.BM.M.pv.sigma<-mean(raw.sigma.pv.vect[seq(2, length(raw.sigma.pv.vect), 5)])
raw.BM.M.pv.sigma.sd<-sd(raw.sigma.pv.vect[seq(2, length(raw.sigma.pv.vect), 5)])
raw.BM.M.2.pv.sigma<-mean(raw.sigma.pv.vect[seq(3, length(raw.sigma.pv.vect), 5)])
raw.BM.M.2.pv.sigma.sd<-sd(raw.sigma.pv.vect[seq(3, length(raw.sigma.pv.vect), 5)])
raw.OU.1.pv.sigma<-mean(raw.sigma.pv.vect[seq(4, length(raw.sigma.pv.vect), 5)])
raw.OU.1.pv.sigma.sd<-sd(raw.sigma.pv.vect[seq(4, length(raw.sigma.pv.vect), 5)])
raw.OU.M.pv.sigma<-mean(raw.sigma.pv.vect[seq(5, length(raw.sigma.pv.vect), 5)])
raw.OU.M.pv.sigma.sd<-sd(raw.sigma.pv.vect[seq(5, length(raw.sigma.pv.vect), 5)])
signif(c(raw.BM.1.pv.sigma, raw.BM.M.pv.sigma, raw.BM.M.2.pv.sigma, raw.OU.1.pv.sigma, raw.OU.M.pv.sigma), 2)
signif(c(raw.BM.1.pv.sigma.sd, raw.BM.M.pv.sigma.sd, raw.BM.M.2.pv.sigma.sd, raw.OU.1.pv.sigma.sd, raw.OU.M.pv.sigma.sd), 2)
raw.theta.pv <- list()
raw.theta.pv<-foreach(i=1:100)%dopar%{raw.theta.pv[[i]] <- c(raw.BM.1.pv[[i]]$theta, raw.BM.M.pv[[i]]$theta, raw.OU.1.pv[[i]]$theta, raw.OU.M.pv[[i]]$theta)}
raw.theta.pv.vect<-(unlist(raw.theta.pv))
raw.BM.1.pv.theta<-mean(raw.theta.pv.vect[seq(1, length(raw.theta.pv.vect), 5)])
raw.BM.1.pv.theta.sd<-sd(raw.theta.pv.vect[seq(1, length(raw.theta.pv.vect), 5)])
raw.BM.M.pv.theta<-mean(raw.theta.pv.vect[seq(2, length(raw.theta.pv.vect), 5)])
raw.BM.M.pv.theta.sd<-sd(raw.theta.pv.vect[seq(2, length(raw.theta.pv.vect), 5)])
raw.OU.1.pv.theta<-mean(raw.theta.pv.vect[seq(3, length(raw.theta.pv.vect), 5)])
raw.OU.1.pv.theta.sd<-sd(raw.theta.pv.vect[seq(3, length(raw.theta.pv.vect), 5)])
raw.OU.M.pv.theta<-mean(raw.theta.pv.vect[seq(4, length(raw.theta.pv.vect), 5)])
raw.OU.M.pv.theta.sd<-sd(raw.theta.pv.vect[seq(4, length(raw.theta.pv.vect), 5)])
raw.OU.M.2.pv.theta<-mean(raw.theta.pv.vect[seq(5, length(raw.theta.pv.vect), 5)])
raw.OU.M.2.pv.theta.sd<-sd(raw.theta.pv.vect[seq(5, length(raw.theta.pv.vect), 5)])
signif(c(raw.BM.1.pv.theta, raw.BM.M.pv.theta, raw.OU.1.pv.theta, raw.OU.M.pv.theta, raw.OU.M.2.pv.theta), 2)
signif(c(raw.BM.1.pv.theta.sd, raw.BM.M.pv.theta.sd, raw.OU.1.pv.theta.sd, raw.OU.M.pv.theta.sd, raw.OU.M.2.pv.theta.sd), 2)
raw.alpha.pv<-list()
raw.alpha.pv<-foreach(i=1:100)%dopar%{raw.alpha.pv[[i]] <- c(raw.OU.1.pv[[i]]$alpha, raw.OU.M.pv[[i]]$alpha)}
raw.alpha.pv.vect<-(unlist(raw.alpha.pv))
raw.OU.1.pv.alpha<-mean(raw.alpha.pv.vect[seq(1, length(raw.alpha.pv.vect), 2)])
raw.OU.1.pv.alpha.sd<-sd(raw.alpha.pv.vect[seq(1, length(raw.alpha.pv.vect), 2)])
raw.OU.M.pv.alpha<-mean(raw.alpha.pv.vect[seq(2, length(raw.alpha.pv.vect), 2)])
raw.OU.M.pv.alpha.sd<-sd(raw.alpha.pv.vect[seq(2, length(raw.alpha.pv.vect), 2)])
signif(c(raw.OU.1.pv.alpha, raw.OU.M.pv.alpha), 2)
signif(c(raw.OU.1.pv.alpha.sd, raw.OU.M.pv.alpha.sd), 2)
raw.aic.pv<-foreach(i=1:100)%dopar%{raw.aic.pv[[i]] <- c(raw.BM.1.pv[[i]]$AICc, raw.BM.M.pv[[i]]$AICc, raw.OU.1.pv[[i]]$AICc, raw.OU.M.pv[[i]]$AICc)}
raw.aic.pv.vect<-(unlist(raw.aic.pv))
raw.BM.1.pv.aic<-mean(raw.aic.pv.vect[seq(1, length(raw.aic.pv.vect), 4)])
raw.BM.1.pv.aic.sd<-sd(raw.aic.pv.vect[seq(1, length(raw.aic.pv.vect), 4)])
raw.BM.M.pv.aic<-mean(raw.aic.pv.vect[seq(2, length(raw.aic.pv.vect), 4)])
raw.BM.M.pv.aic.sd<-sd(raw.aic.pv.vect[seq(2, length(raw.aic.pv.vect), 4)])
raw.OU.1.pv.aic<-mean(raw.aic.pv.vect[seq(3, length(raw.aic.pv.vect), 4)])
raw.OU.1.pv.aic.sd<-sd(raw.aic.pv.vect[seq(3, length(raw.aic.pv.vect), 4)])
raw.OU.M.pv.aic<-mean(raw.aic.pv.vect[seq(4, length(raw.aic.pv.vect), 4)])
raw.OU.M.pv.aic.sd<-sd(raw.aic.pv.vect[seq(4, length(raw.aic.pv.vect), 4)])
signif(c(raw.BM.1.pv.aic, raw.BM.M.pv.aic, raw.OU.1.pv.aic, raw.OU.M.pv.aic), 4)
signif(c(raw.BM.1.pv.aic.sd, raw.BM.M.pv.aic.sd, raw.OU.1.pv.aic.sd, raw.OU.M.pv.aic.sd), 4)
power.error(raw.OU.M.pv[[1]], raw.BM.1.pv[[1]])

#tbrake
raw.BM.1.tb <- list()
raw.BM.M.tb <- list()
raw.OU.1.tb <- list()
raw.OU.M.tb <- list()
raw.aicw.tb <- list()
raw.aic.tb <- list()
raw.BM.1.tb<-foreach(i=1:100)%dopar%{raw.BM.1.tb[[i]]<-mvBM(painttree[[i]], tbrake,error=se.tb^2, model='BM1')}
raw.BM.M.tb<-foreach(i=1:100)%dopar%{raw.BM.M.tb[[i]]<-mvBM(painttree[[i]], tbrake,error=se.tb^2, model='BMM')}
raw.OU.1.tb<-foreach(i=1:100)%dopar%{raw.OU.1.tb[[i]]<-mvOU(painttree[[i]], tbrake,error=se.tb^2,model='OU1')}
raw.OU.M.tb<-foreach(i=1:100)%dopar%{raw.OU.M.tb[[i]]<-mvOU(painttree[[i]], tbrake,error=se.tb^2,model='OUM')}
raw.aicw.tb<-foreach(i=1:100)%dopar%{raw.aic.tb[[i]] <- aic.w(c(raw.BM.1.tb[[i]]$AICc, raw.BM.M.tb[[i]]$AICc, raw.OU.1.tb[[i]]$AICc, raw.OU.M.tb[[i]]$AICc))}
raw.aicw.tb.vect<-(unlist(raw.aicw.tb))
raw.BM.1.tb.w<-mean(raw.aicw.tb.vect[seq(1, length(raw.aicw.tb.vect), 4)])
raw.BM.M.tb.w<-mean(raw.aicw.tb.vect[seq(2, length(raw.aicw.tb.vect), 4)])
raw.OU.1.tb.w<-mean(raw.aicw.tb.vect[seq(3, length(raw.aicw.tb.vect), 4)])
raw.OU.M.tb.w<-mean(raw.aicw.tb.vect[seq(4, length(raw.aicw.tb.vect), 4)])
signif(c(raw.BM.1.tb.w, raw.BM.M.tb.w, raw.OU.1.tb.w, raw.OU.M.tb.w), 2)
raw.BM.1.tb.w.sd<-sd(raw.aicw.tb.vect[seq(1, length(raw.aicw.tb.vect), 4)])
raw.BM.M.tb.w.sd<-sd(raw.aicw.tb.vect[seq(2, length(raw.aicw.tb.vect), 4)])
raw.OU.1.tb.w.sd<-sd(raw.aicw.tb.vect[seq(3, length(raw.aicw.tb.vect), 4)])
raw.OU.M.tb.w.sd<-sd(raw.aicw.tb.vect[seq(4, length(raw.aicw.tb.vect), 4)])
signif(c(raw.BM.1.tb.w.sd, raw.BM.M.tb.w.sd, raw.OU.1.tb.w.sd, raw.OU.M.tb.w.sd), 2)
raw.sigma.tb <- list()
raw.sigma.tb<-foreach(i=1:100)%dopar%{raw.sigma.tb[[i]] <- c(raw.BM.1.tb[[i]]$sigma, raw.BM.M.tb[[i]]$sigma, raw.OU.1.tb[[i]]$sigma, raw.OU.M.tb[[i]]$sigma)}
raw.sigma.tb.vect<-(unlist(raw.sigma.tb))
raw.BM.1.tb.sigma<-mean(raw.sigma.tb.vect[seq(1, length(raw.sigma.tb.vect), 5)])
raw.BM.1.tb.sigma.sd<-sd(raw.sigma.tb.vect[seq(1, length(raw.sigma.tb.vect), 5)])
raw.BM.M.tb.sigma<-mean(raw.sigma.tb.vect[seq(2, length(raw.sigma.tb.vect), 5)])
raw.BM.M.tb.sigma.sd<-sd(raw.sigma.tb.vect[seq(2, length(raw.sigma.tb.vect), 5)])
raw.BM.M.2.tb.sigma<-mean(raw.sigma.tb.vect[seq(3, length(raw.sigma.tb.vect), 5)])
raw.BM.M.2.tb.sigma.sd<-sd(raw.sigma.tb.vect[seq(3, length(raw.sigma.tb.vect), 5)])
raw.OU.1.tb.sigma<-mean(raw.sigma.tb.vect[seq(4, length(raw.sigma.tb.vect), 5)])
raw.OU.1.tb.sigma.sd<-sd(raw.sigma.tb.vect[seq(4, length(raw.sigma.tb.vect), 5)])
raw.OU.M.tb.sigma<-mean(raw.sigma.tb.vect[seq(5, length(raw.sigma.tb.vect), 5)])
raw.OU.M.tb.sigma.sd<-sd(raw.sigma.tb.vect[seq(5, length(raw.sigma.tb.vect), 5)])
signif(c(raw.BM.1.tb.sigma, raw.BM.M.tb.sigma, raw.BM.M.2.tb.sigma, raw.OU.1.tb.sigma, raw.OU.M.tb.sigma), 2)
signif(c(raw.BM.1.tb.sigma.sd, raw.BM.M.tb.sigma.sd, raw.BM.M.2.tb.sigma.sd, raw.OU.1.tb.sigma.sd, raw.OU.M.tb.sigma.sd), 2)
raw.theta.tb <- list()
raw.theta.tb<-foreach(i=1:100)%dopar%{raw.theta.tb[[i]] <- c(raw.BM.1.tb[[i]]$theta, raw.BM.M.tb[[i]]$theta, raw.OU.1.tb[[i]]$theta, raw.OU.M.tb[[i]]$theta)}
raw.theta.tb.vect<-(unlist(raw.theta.tb))
raw.BM.1.tb.theta<-mean(raw.theta.tb.vect[seq(1, length(raw.theta.tb.vect), 5)])
raw.BM.1.tb.theta.sd<-sd(raw.theta.tb.vect[seq(1, length(raw.theta.tb.vect), 5)])
raw.BM.M.tb.theta<-mean(raw.theta.tb.vect[seq(2, length(raw.theta.tb.vect), 5)])
raw.BM.M.tb.theta.sd<-sd(raw.theta.tb.vect[seq(2, length(raw.theta.tb.vect), 5)])
raw.OU.1.tb.theta<-mean(raw.theta.tb.vect[seq(3, length(raw.theta.tb.vect), 5)])
raw.OU.1.tb.theta.sd<-sd(raw.theta.tb.vect[seq(3, length(raw.theta.tb.vect), 5)])
raw.OU.M.tb.theta<-mean(raw.theta.tb.vect[seq(4, length(raw.theta.tb.vect), 5)])
raw.OU.M.tb.theta.sd<-sd(raw.theta.tb.vect[seq(4, length(raw.theta.tb.vect), 5)])
raw.OU.M.2.tb.theta<-mean(raw.theta.tb.vect[seq(5, length(raw.theta.tb.vect), 5)])
raw.OU.M.2.tb.theta.sd<-sd(raw.theta.tb.vect[seq(5, length(raw.theta.tb.vect), 5)])
signif(c(raw.BM.1.tb.theta, raw.BM.M.tb.theta, raw.OU.1.tb.theta, raw.OU.M.tb.theta, raw.OU.M.2.tb.theta), 2)
signif(c(raw.BM.1.tb.theta.sd, raw.BM.M.tb.theta.sd, raw.OU.1.tb.theta.sd, raw.OU.M.tb.theta.sd, raw.OU.M.2.tb.theta.sd), 2)
raw.alpha.tb<-list()
raw.alpha.tb<-foreach(i=1:100)%dopar%{raw.alpha.tb[[i]] <- c(raw.OU.1.tb[[i]]$alpha, raw.OU.M.tb[[i]]$alpha)}
raw.alpha.tb.vect<-(unlist(raw.alpha.tb))
raw.OU.1.tb.alpha<-mean(raw.alpha.tb.vect[seq(1, length(raw.alpha.tb.vect), 2)])
raw.OU.1.tb.alpha.sd<-sd(raw.alpha.tb.vect[seq(1, length(raw.alpha.tb.vect), 2)])
raw.OU.M.tb.alpha<-mean(raw.alpha.tb.vect[seq(2, length(raw.alpha.tb.vect), 2)])
raw.OU.M.tb.alpha.sd<-sd(raw.alpha.tb.vect[seq(2, length(raw.alpha.tb.vect), 2)])
signif(c(raw.OU.1.tb.alpha, raw.OU.M.tb.alpha), 2)
signif(c(raw.OU.1.tb.alpha.sd, raw.OU.M.tb.alpha.sd), 2)
raw.aic.tb<-foreach(i=1:100)%dopar%{raw.aic.tb[[i]] <- c(raw.BM.1.tb[[i]]$AICc, raw.BM.M.tb[[i]]$AICc, raw.OU.1.tb[[i]]$AICc, raw.OU.M.tb[[i]]$AICc)}
raw.aic.tb.vect<-(unlist(raw.aic.tb))
raw.BM.1.tb.aic<-mean(raw.aic.tb.vect[seq(1, length(raw.aic.tb.vect), 4)])
raw.BM.1.tb.aic.sd<-sd(raw.aic.tb.vect[seq(1, length(raw.aic.tb.vect), 4)])
raw.BM.M.tb.aic<-mean(raw.aic.tb.vect[seq(2, length(raw.aic.tb.vect), 4)])
raw.BM.M.tb.aic.sd<-sd(raw.aic.tb.vect[seq(2, length(raw.aic.tb.vect), 4)])
raw.OU.1.tb.aic<-mean(raw.aic.tb.vect[seq(3, length(raw.aic.tb.vect), 4)])
raw.OU.1.tb.aic.sd<-sd(raw.aic.tb.vect[seq(3, length(raw.aic.tb.vect), 4)])
raw.OU.M.tb.aic<-mean(raw.aic.tb.vect[seq(4, length(raw.aic.tb.vect), 4)])
raw.OU.M.tb.aic.sd<-sd(raw.aic.tb.vect[seq(4, length(raw.aic.tb.vect), 4)])
signif(c(raw.BM.1.tb.aic, raw.BM.M.tb.aic, raw.OU.1.tb.aic, raw.OU.M.tb.aic), 4)
signif(c(raw.BM.1.tb.aic.sd, raw.BM.M.tb.aic.sd, raw.OU.1.tb.aic.sd, raw.OU.M.tb.aic.sd), 4)
power.error(raw.OU.M.tb[[1]], raw.BM.1.tb[[1]])

#taccel
raw.BM.1.ta <- list()
raw.BM.M.ta <- list()
raw.OU.1.ta <- list()
raw.OU.M.ta <- list()
raw.aicw.ta <- list()
raw.aic.ta <- list()
raw.BM.1.ta<-foreach(i=1:100)%dopar%{raw.BM.1.ta[[i]]<-mvBM(painttree[[i]], taccel,error=se.ta^2, model='BM1')}
raw.BM.M.ta<-foreach(i=1:100)%dopar%{raw.BM.M.ta[[i]]<-mvBM(painttree[[i]], taccel,error=se.ta^2, model='BMM')}
raw.OU.1.ta<-foreach(i=1:100)%dopar%{raw.OU.1.ta[[i]]<-mvOU(painttree[[i]], taccel,error=se.ta^2,model='OU1')}
raw.OU.M.ta<-foreach(i=1:100)%dopar%{raw.OU.M.ta[[i]]<-mvOU(painttree[[i]], taccel,error=se.ta^2,model='OUM')}
raw.aicw.ta<-foreach(i=1:100)%dopar%{raw.aic.ta[[i]] <- aic.w(c(raw.BM.1.ta[[i]]$AICc, raw.BM.M.ta[[i]]$AICc, raw.OU.1.ta[[i]]$AICc, raw.OU.M.ta[[i]]$AICc))}
raw.aicw.ta.vect<-(unlist(raw.aicw.ta))
raw.BM.1.ta.w<-mean(raw.aicw.ta.vect[seq(1, length(raw.aicw.ta.vect), 4)])
raw.BM.M.ta.w<-mean(raw.aicw.ta.vect[seq(2, length(raw.aicw.ta.vect), 4)])
raw.OU.1.ta.w<-mean(raw.aicw.ta.vect[seq(3, length(raw.aicw.ta.vect), 4)])
raw.OU.M.ta.w<-mean(raw.aicw.ta.vect[seq(4, length(raw.aicw.ta.vect), 4)])
signif(c(raw.BM.1.ta.w, raw.BM.M.ta.w, raw.OU.1.ta.w, raw.OU.M.ta.w), 2)
raw.BM.1.ta.w.sd<-sd(raw.aicw.ta.vect[seq(1, length(raw.aicw.ta.vect), 4)])
raw.BM.M.ta.w.sd<-sd(raw.aicw.ta.vect[seq(2, length(raw.aicw.ta.vect), 4)])
raw.OU.1.ta.w.sd<-sd(raw.aicw.ta.vect[seq(3, length(raw.aicw.ta.vect), 4)])
raw.OU.M.ta.w.sd<-sd(raw.aicw.ta.vect[seq(4, length(raw.aicw.ta.vect), 4)])
signif(c(raw.BM.1.ta.w.sd, raw.BM.M.ta.w.sd, raw.OU.1.ta.w.sd, raw.OU.M.ta.w.sd), 2)
raw.sigma.ta <- list()
raw.sigma.ta<-foreach(i=1:100)%dopar%{raw.sigma.ta[[i]] <- c(raw.BM.1.ta[[i]]$sigma, raw.BM.M.ta[[i]]$sigma, raw.OU.1.ta[[i]]$sigma, raw.OU.M.ta[[i]]$sigma)}
raw.sigma.ta.vect<-(unlist(raw.sigma.ta))
raw.BM.1.ta.sigma<-mean(raw.sigma.ta.vect[seq(1, length(raw.sigma.ta.vect), 5)])
raw.BM.1.ta.sigma.sd<-sd(raw.sigma.ta.vect[seq(1, length(raw.sigma.ta.vect), 5)])
raw.BM.M.ta.sigma<-mean(raw.sigma.ta.vect[seq(2, length(raw.sigma.ta.vect), 5)])
raw.BM.M.ta.sigma.sd<-sd(raw.sigma.ta.vect[seq(2, length(raw.sigma.ta.vect), 5)])
raw.BM.M.2.ta.sigma<-mean(raw.sigma.ta.vect[seq(3, length(raw.sigma.ta.vect), 5)])
raw.BM.M.2.ta.sigma.sd<-sd(raw.sigma.ta.vect[seq(3, length(raw.sigma.ta.vect), 5)])
raw.OU.1.ta.sigma<-mean(raw.sigma.ta.vect[seq(4, length(raw.sigma.ta.vect), 5)])
raw.OU.1.ta.sigma.sd<-sd(raw.sigma.ta.vect[seq(4, length(raw.sigma.ta.vect), 5)])
raw.OU.M.ta.sigma<-mean(raw.sigma.ta.vect[seq(5, length(raw.sigma.ta.vect), 5)])
raw.OU.M.ta.sigma.sd<-sd(raw.sigma.ta.vect[seq(5, length(raw.sigma.ta.vect), 5)])
signif(c(raw.BM.1.ta.sigma, raw.BM.M.ta.sigma, raw.BM.M.2.ta.sigma, raw.OU.1.ta.sigma, raw.OU.M.ta.sigma), 2)
signif(c(raw.BM.1.ta.sigma.sd, raw.BM.M.ta.sigma.sd, raw.BM.M.2.ta.sigma.sd, raw.OU.1.ta.sigma.sd, raw.OU.M.ta.sigma.sd), 2)
raw.theta.ta <- list()
raw.theta.ta<-foreach(i=1:100)%dopar%{raw.theta.ta[[i]] <- c(raw.BM.1.ta[[i]]$theta, raw.BM.M.ta[[i]]$theta, raw.OU.1.ta[[i]]$theta, raw.OU.M.ta[[i]]$theta)}
raw.theta.ta.vect<-(unlist(raw.theta.ta))
raw.BM.1.ta.theta<-mean(raw.theta.ta.vect[seq(1, length(raw.theta.ta.vect), 5)])
raw.BM.1.ta.theta.sd<-sd(raw.theta.ta.vect[seq(1, length(raw.theta.ta.vect), 5)])
raw.BM.M.ta.theta<-mean(raw.theta.ta.vect[seq(2, length(raw.theta.ta.vect), 5)])
raw.BM.M.ta.theta.sd<-sd(raw.theta.ta.vect[seq(2, length(raw.theta.ta.vect), 5)])
raw.OU.1.ta.theta<-mean(raw.theta.ta.vect[seq(3, length(raw.theta.ta.vect), 5)])
raw.OU.1.ta.theta.sd<-sd(raw.theta.ta.vect[seq(3, length(raw.theta.ta.vect), 5)])
raw.OU.M.ta.theta<-mean(raw.theta.ta.vect[seq(4, length(raw.theta.ta.vect), 5)])
raw.OU.M.ta.theta.sd<-sd(raw.theta.ta.vect[seq(4, length(raw.theta.ta.vect), 5)])
raw.OU.M.2.ta.theta<-mean(raw.theta.ta.vect[seq(5, length(raw.theta.ta.vect), 5)])
raw.OU.M.2.ta.theta.sd<-sd(raw.theta.ta.vect[seq(5, length(raw.theta.ta.vect), 5)])
signif(c(raw.BM.1.ta.theta, raw.BM.M.ta.theta, raw.OU.1.ta.theta, raw.OU.M.ta.theta, raw.OU.M.2.ta.theta), 2)
signif(c(raw.BM.1.ta.theta.sd, raw.BM.M.ta.theta.sd, raw.OU.1.ta.theta.sd, raw.OU.M.ta.theta.sd, raw.OU.M.2.ta.theta.sd), 2)
raw.alpha.ta<-list()
raw.alpha.ta<-foreach(i=1:100)%dopar%{raw.alpha.ta[[i]] <- c(raw.OU.1.ta[[i]]$alpha, raw.OU.M.ta[[i]]$alpha)}
raw.alpha.ta.vect<-(unlist(raw.alpha.ta))
raw.OU.1.ta.alpha<-mean(raw.alpha.ta.vect[seq(1, length(raw.alpha.ta.vect), 2)])
raw.OU.1.ta.alpha.sd<-sd(raw.alpha.ta.vect[seq(1, length(raw.alpha.ta.vect), 2)])
raw.OU.M.ta.alpha<-mean(raw.alpha.ta.vect[seq(2, length(raw.alpha.ta.vect), 2)])
raw.OU.M.ta.alpha.sd<-sd(raw.alpha.ta.vect[seq(2, length(raw.alpha.ta.vect), 2)])
signif(c(raw.OU.1.ta.alpha, raw.OU.M.ta.alpha), 2)
signif(c(raw.OU.1.ta.alpha.sd, raw.OU.M.ta.alpha.sd), 2)
raw.aic.ta<-foreach(i=1:100)%dopar%{raw.aic.ta[[i]] <- c(raw.BM.1.ta[[i]]$AICc, raw.BM.M.ta[[i]]$AICc, raw.OU.1.ta[[i]]$AICc, raw.OU.M.ta[[i]]$AICc)}
raw.aic.ta.vect<-(unlist(raw.aic.ta))
raw.BM.1.ta.aic<-mean(raw.aic.ta.vect[seq(1, length(raw.aic.ta.vect), 4)])
raw.BM.1.ta.aic.sd<-sd(raw.aic.ta.vect[seq(1, length(raw.aic.ta.vect), 4)])
raw.BM.M.ta.aic<-mean(raw.aic.ta.vect[seq(2, length(raw.aic.ta.vect), 4)])
raw.BM.M.ta.aic.sd<-sd(raw.aic.ta.vect[seq(2, length(raw.aic.ta.vect), 4)])
raw.OU.1.ta.aic<-mean(raw.aic.ta.vect[seq(3, length(raw.aic.ta.vect), 4)])
raw.OU.1.ta.aic.sd<-sd(raw.aic.ta.vect[seq(3, length(raw.aic.ta.vect), 4)])
raw.OU.M.ta.aic<-mean(raw.aic.ta.vect[seq(4, length(raw.aic.ta.vect), 4)])
raw.OU.M.ta.aic.sd<-sd(raw.aic.ta.vect[seq(4, length(raw.aic.ta.vect), 4)])
signif(c(raw.BM.1.ta.aic, raw.BM.M.ta.aic, raw.OU.1.ta.aic, raw.OU.M.ta.aic), 4)
signif(c(raw.BM.1.ta.aic.sd, raw.BM.M.ta.aic.sd, raw.OU.1.ta.aic.sd, raw.OU.M.ta.aic.sd), 4)
power.error(raw.OU.M.ta[[1]], raw.BM.1.ta[[1]])

#tmed
raw.BM.1.tm <- list()
raw.BM.M.tm <- list()
raw.OU.1.tm <- list()
raw.OU.M.tm <- list()
raw.aicw.tm <- list()
raw.aic.tm <- list()
raw.BM.1.tm<-foreach(i=1:100)%dopar%{raw.BM.1.tm[[i]]<-mvBM(painttree[[i]], tmed,error=se.tm^2, model='BM1')}
raw.BM.M.tm<-foreach(i=1:100)%dopar%{raw.BM.M.tm[[i]]<-mvBM(painttree[[i]], tmed,error=se.tm^2, model='BMM')}
raw.OU.1.tm<-foreach(i=1:100)%dopar%{raw.OU.1.tm[[i]]<-mvOU(painttree[[i]], tmed,error=se.tm^2,model='OU1')}
raw.OU.M.tm<-foreach(i=1:100)%dopar%{raw.OU.M.tm[[i]]<-mvOU(painttree[[i]], tmed,error=se.tm^2,model='OUM')}
raw.aicw.tm<-foreach(i=1:100)%dopar%{raw.aic.tm[[i]] <- aic.w(c(raw.BM.1.tm[[i]]$AICc, raw.BM.M.tm[[i]]$AICc, raw.OU.1.tm[[i]]$AICc, raw.OU.M.tm[[i]]$AICc))}
raw.aicw.tm.vect<-(unlist(raw.aicw.tm))
raw.BM.1.tm.w<-mean(raw.aicw.tm.vect[seq(1, length(raw.aicw.tm.vect), 4)])
raw.BM.M.tm.w<-mean(raw.aicw.tm.vect[seq(2, length(raw.aicw.tm.vect), 4)])
raw.OU.1.tm.w<-mean(raw.aicw.tm.vect[seq(3, length(raw.aicw.tm.vect), 4)])
raw.OU.M.tm.w<-mean(raw.aicw.tm.vect[seq(4, length(raw.aicw.tm.vect), 4)])
signif(c(raw.BM.1.tm.w, raw.BM.M.tm.w, raw.OU.1.tm.w, raw.OU.M.tm.w), 2)
raw.BM.1.tm.w.sd<-sd(raw.aicw.tm.vect[seq(1, length(raw.aicw.tm.vect), 4)])
raw.BM.M.tm.w.sd<-sd(raw.aicw.tm.vect[seq(2, length(raw.aicw.tm.vect), 4)])
raw.OU.1.tm.w.sd<-sd(raw.aicw.tm.vect[seq(3, length(raw.aicw.tm.vect), 4)])
raw.OU.M.tm.w.sd<-sd(raw.aicw.tm.vect[seq(4, length(raw.aicw.tm.vect), 4)])
signif(c(raw.BM.1.tm.w.sd, raw.BM.M.tm.w.sd, raw.OU.1.tm.w.sd, raw.OU.M.tm.w.sd), 2)
raw.sigma.tm <- list()
raw.sigma.tm<-foreach(i=1:100)%dopar%{raw.sigma.tm[[i]] <- c(raw.BM.1.tm[[i]]$sigma, raw.BM.M.tm[[i]]$sigma, raw.OU.1.tm[[i]]$sigma, raw.OU.M.tm[[i]]$sigma)}
raw.sigma.tm.vect<-(unlist(raw.sigma.tm))
raw.BM.1.tm.sigma<-mean(raw.sigma.tm.vect[seq(1, length(raw.sigma.tm.vect), 5)])
raw.BM.1.tm.sigma.sd<-sd(raw.sigma.tm.vect[seq(1, length(raw.sigma.tm.vect), 5)])
raw.BM.M.tm.sigma<-mean(raw.sigma.tm.vect[seq(2, length(raw.sigma.tm.vect), 5)])
raw.BM.M.tm.sigma.sd<-sd(raw.sigma.tm.vect[seq(2, length(raw.sigma.tm.vect), 5)])
raw.BM.M.2.tm.sigma<-mean(raw.sigma.tm.vect[seq(3, length(raw.sigma.tm.vect), 5)])
raw.BM.M.2.tm.sigma.sd<-sd(raw.sigma.tm.vect[seq(3, length(raw.sigma.tm.vect), 5)])
raw.OU.1.tm.sigma<-mean(raw.sigma.tm.vect[seq(4, length(raw.sigma.tm.vect), 5)])
raw.OU.1.tm.sigma.sd<-sd(raw.sigma.tm.vect[seq(4, length(raw.sigma.tm.vect), 5)])
raw.OU.M.tm.sigma<-mean(raw.sigma.tm.vect[seq(5, length(raw.sigma.tm.vect), 5)])
raw.OU.M.tm.sigma.sd<-sd(raw.sigma.tm.vect[seq(5, length(raw.sigma.tm.vect), 5)])
signif(c(raw.BM.1.tm.sigma, raw.BM.M.tm.sigma, raw.BM.M.2.tm.sigma, raw.OU.1.tm.sigma, raw.OU.M.tm.sigma), 2)
signif(c(raw.BM.1.tm.sigma.sd, raw.BM.M.tm.sigma.sd, raw.BM.M.2.tm.sigma.sd, raw.OU.1.tm.sigma.sd, raw.OU.M.tm.sigma.sd), 2)
raw.theta.tm <- list()
raw.theta.tm<-foreach(i=1:100)%dopar%{raw.theta.tm[[i]] <- c(raw.BM.1.tm[[i]]$theta, raw.BM.M.tm[[i]]$theta, raw.OU.1.tm[[i]]$theta, raw.OU.M.tm[[i]]$theta)}
raw.theta.tm.vect<-(unlist(raw.theta.tm))
raw.BM.1.tm.theta<-mean(raw.theta.tm.vect[seq(1, length(raw.theta.tm.vect), 5)])
raw.BM.1.tm.theta.sd<-sd(raw.theta.tm.vect[seq(1, length(raw.theta.tm.vect), 5)])
raw.BM.M.tm.theta<-mean(raw.theta.tm.vect[seq(2, length(raw.theta.tm.vect), 5)])
raw.BM.M.tm.theta.sd<-sd(raw.theta.tm.vect[seq(2, length(raw.theta.tm.vect), 5)])
raw.OU.1.tm.theta<-mean(raw.theta.tm.vect[seq(3, length(raw.theta.tm.vect), 5)])
raw.OU.1.tm.theta.sd<-sd(raw.theta.tm.vect[seq(3, length(raw.theta.tm.vect), 5)])
raw.OU.M.tm.theta<-mean(raw.theta.tm.vect[seq(4, length(raw.theta.tm.vect), 5)])
raw.OU.M.tm.theta.sd<-sd(raw.theta.tm.vect[seq(4, length(raw.theta.tm.vect), 5)])
raw.OU.M.2.tm.theta<-mean(raw.theta.tm.vect[seq(5, length(raw.theta.tm.vect), 5)])
raw.OU.M.2.tm.theta.sd<-sd(raw.theta.tm.vect[seq(5, length(raw.theta.tm.vect), 5)])
signif(c(raw.BM.1.tm.theta, raw.BM.M.tm.theta, raw.OU.1.tm.theta, raw.OU.M.tm.theta, raw.OU.M.2.tm.theta), 2)
signif(c(raw.BM.1.tm.theta.sd, raw.BM.M.tm.theta.sd, raw.OU.1.tm.theta.sd, raw.OU.M.tm.theta.sd, raw.OU.M.2.tm.theta.sd), 2)
raw.alpha.tm<-list()
raw.alpha.tm<-foreach(i=1:100)%dopar%{raw.alpha.tm[[i]] <- c(raw.OU.1.tm[[i]]$alpha, raw.OU.M.tm[[i]]$alpha)}
raw.alpha.tm.vect<-(unlist(raw.alpha.tm))
raw.OU.1.tm.alpha<-mean(raw.alpha.tm.vect[seq(1, length(raw.alpha.tm.vect), 2)])
raw.OU.1.tm.alpha.sd<-sd(raw.alpha.tm.vect[seq(1, length(raw.alpha.tm.vect), 2)])
raw.OU.M.tm.alpha<-mean(raw.alpha.tm.vect[seq(2, length(raw.alpha.tm.vect), 2)])
raw.OU.M.tm.alpha.sd<-sd(raw.alpha.tm.vect[seq(2, length(raw.alpha.tm.vect), 2)])
signif(c(raw.OU.1.tm.alpha, raw.OU.M.tm.alpha), 2)
signif(c(raw.OU.1.tm.alpha.sd, raw.OU.M.tm.alpha.sd), 2)
raw.aic.tm<-foreach(i=1:100)%dopar%{raw.aic.tm[[i]] <- c(raw.BM.1.tm[[i]]$AICc, raw.BM.M.tm[[i]]$AICc, raw.OU.1.tm[[i]]$AICc, raw.OU.M.tm[[i]]$AICc)}
raw.aic.tm.vect<-(unlist(raw.aic.tm))
raw.BM.1.tm.aic<-mean(raw.aic.tm.vect[seq(1, length(raw.aic.tm.vect), 4)])
raw.BM.1.tm.aic.sd<-sd(raw.aic.tm.vect[seq(1, length(raw.aic.tm.vect), 4)])
raw.BM.M.tm.aic<-mean(raw.aic.tm.vect[seq(2, length(raw.aic.tm.vect), 4)])
raw.BM.M.tm.aic.sd<-sd(raw.aic.tm.vect[seq(2, length(raw.aic.tm.vect), 4)])
raw.OU.1.tm.aic<-mean(raw.aic.tm.vect[seq(3, length(raw.aic.tm.vect), 4)])
raw.OU.1.tm.aic.sd<-sd(raw.aic.tm.vect[seq(3, length(raw.aic.tm.vect), 4)])
raw.OU.M.tm.aic<-mean(raw.aic.tm.vect[seq(4, length(raw.aic.tm.vect), 4)])
raw.OU.M.tm.aic.sd<-sd(raw.aic.tm.vect[seq(4, length(raw.aic.tm.vect), 4)])
signif(c(raw.BM.1.tm.aic, raw.BM.M.tm.aic, raw.OU.1.tm.aic, raw.OU.M.tm.aic), 4)
signif(c(raw.BM.1.tm.aic.sd, raw.BM.M.tm.aic.sd, raw.OU.1.tm.aic.sd, raw.OU.M.tm.aic.sd), 4)
power.error(raw.OU.M.tm[[1]], raw.BM.1.tm[[1]])

#tlat
raw.BM.1.tl <- list()
raw.BM.M.tl <- list()
raw.OU.1.tl <- list()
raw.OU.M.tl <- list()
raw.aicw.tl <- list()
raw.aic.tl <- list()
raw.BM.1.tl<-foreach(i=1:100)%dopar%{raw.BM.1.tl[[i]]<-mvBM(painttree[[i]], tlat,error=se.tl^2, model='BM1')}
raw.BM.M.tl<-foreach(i=1:100)%dopar%{raw.BM.M.tl[[i]]<-mvBM(painttree[[i]], tlat,error=se.tl^2, model='BMM')}
raw.OU.1.tl<-foreach(i=1:100)%dopar%{raw.OU.1.tl[[i]]<-mvOU(painttree[[i]], tlat,error=se.tl^2,model='OU1')}
raw.OU.M.tl<-foreach(i=1:100)%dopar%{raw.OU.M.tl[[i]]<-mvOU(painttree[[i]], tlat,error=se.tl^2,model='OUM')}
raw.aicw.tl<-foreach(i=1:100)%dopar%{raw.aic.tl[[i]] <- aic.w(c(raw.BM.1.tl[[i]]$AICc, raw.BM.M.tl[[i]]$AICc, raw.OU.1.tl[[i]]$AICc, raw.OU.M.tl[[i]]$AICc))}
raw.aicw.tl.vect<-(unlist(raw.aicw.tl))
raw.BM.1.tl.w<-mean(raw.aicw.tl.vect[seq(1, length(raw.aicw.tl.vect), 4)])
raw.BM.M.tl.w<-mean(raw.aicw.tl.vect[seq(2, length(raw.aicw.tl.vect), 4)])
raw.OU.1.tl.w<-mean(raw.aicw.tl.vect[seq(3, length(raw.aicw.tl.vect), 4)])
raw.OU.M.tl.w<-mean(raw.aicw.tl.vect[seq(4, length(raw.aicw.tl.vect), 4)])
signif(c(raw.BM.1.tl.w, raw.BM.M.tl.w, raw.OU.1.tl.w, raw.OU.M.tl.w), 2)
raw.BM.1.tl.w.sd<-sd(raw.aicw.tl.vect[seq(1, length(raw.aicw.tl.vect), 4)])
raw.BM.M.tl.w.sd<-sd(raw.aicw.tl.vect[seq(2, length(raw.aicw.tl.vect), 4)])
raw.OU.1.tl.w.sd<-sd(raw.aicw.tl.vect[seq(3, length(raw.aicw.tl.vect), 4)])
raw.OU.M.tl.w.sd<-sd(raw.aicw.tl.vect[seq(4, length(raw.aicw.tl.vect), 4)])
signif(c(raw.BM.1.tl.w.sd, raw.BM.M.tl.w.sd, raw.OU.1.tl.w.sd, raw.OU.M.tl.w.sd), 2)
raw.sigma.tl <- list()
raw.sigma.tl<-foreach(i=1:100)%dopar%{raw.sigma.tl[[i]] <- c(raw.BM.1.tl[[i]]$sigma, raw.BM.M.tl[[i]]$sigma, raw.OU.1.tl[[i]]$sigma, raw.OU.M.tl[[i]]$sigma)}
raw.sigma.tl.vect<-(unlist(raw.sigma.tl))
raw.BM.1.tl.sigma<-mean(raw.sigma.tl.vect[seq(1, length(raw.sigma.tl.vect), 5)])
raw.BM.1.tl.sigma.sd<-sd(raw.sigma.tl.vect[seq(1, length(raw.sigma.tl.vect), 5)])
raw.BM.M.tl.sigma<-mean(raw.sigma.tl.vect[seq(2, length(raw.sigma.tl.vect), 5)])
raw.BM.M.tl.sigma.sd<-sd(raw.sigma.tl.vect[seq(2, length(raw.sigma.tl.vect), 5)])
raw.BM.M.2.tl.sigma<-mean(raw.sigma.tl.vect[seq(3, length(raw.sigma.tl.vect), 5)])
raw.BM.M.2.tl.sigma.sd<-sd(raw.sigma.tl.vect[seq(3, length(raw.sigma.tl.vect), 5)])
raw.OU.1.tl.sigma<-mean(raw.sigma.tl.vect[seq(4, length(raw.sigma.tl.vect), 5)])
raw.OU.1.tl.sigma.sd<-sd(raw.sigma.tl.vect[seq(4, length(raw.sigma.tl.vect), 5)])
raw.OU.M.tl.sigma<-mean(raw.sigma.tl.vect[seq(5, length(raw.sigma.tl.vect), 5)])
raw.OU.M.tl.sigma.sd<-sd(raw.sigma.tl.vect[seq(5, length(raw.sigma.tl.vect), 5)])
signif(c(raw.BM.1.tl.sigma, raw.BM.M.tl.sigma, raw.BM.M.2.tl.sigma, raw.OU.1.tl.sigma, raw.OU.M.tl.sigma), 2)
signif(c(raw.BM.1.tl.sigma.sd, raw.BM.M.tl.sigma.sd, raw.BM.M.2.tl.sigma.sd, raw.OU.1.tl.sigma.sd, raw.OU.M.tl.sigma.sd), 2)
raw.theta.tl <- list()
raw.theta.tl<-foreach(i=1:100)%dopar%{raw.theta.tl[[i]] <- c(raw.BM.1.tl[[i]]$theta, raw.BM.M.tl[[i]]$theta, raw.OU.1.tl[[i]]$theta, raw.OU.M.tl[[i]]$theta)}
raw.theta.tl.vect<-(unlist(raw.theta.tl))
raw.BM.1.tl.theta<-mean(raw.theta.tl.vect[seq(1, length(raw.theta.tl.vect), 5)])
raw.BM.1.tl.theta.sd<-sd(raw.theta.tl.vect[seq(1, length(raw.theta.tl.vect), 5)])
raw.BM.M.tl.theta<-mean(raw.theta.tl.vect[seq(2, length(raw.theta.tl.vect), 5)])
raw.BM.M.tl.theta.sd<-sd(raw.theta.tl.vect[seq(2, length(raw.theta.tl.vect), 5)])
raw.OU.1.tl.theta<-mean(raw.theta.tl.vect[seq(3, length(raw.theta.tl.vect), 5)])
raw.OU.1.tl.theta.sd<-sd(raw.theta.tl.vect[seq(3, length(raw.theta.tl.vect), 5)])
raw.OU.M.tl.theta<-mean(raw.theta.tl.vect[seq(4, length(raw.theta.tl.vect), 5)])
raw.OU.M.tl.theta.sd<-sd(raw.theta.tl.vect[seq(4, length(raw.theta.tl.vect), 5)])
raw.OU.M.2.tl.theta<-mean(raw.theta.tl.vect[seq(5, length(raw.theta.tl.vect), 5)])
raw.OU.M.2.tl.theta.sd<-sd(raw.theta.tl.vect[seq(5, length(raw.theta.tl.vect), 5)])
signif(c(raw.BM.1.tl.theta, raw.BM.M.tl.theta, raw.OU.1.tl.theta, raw.OU.M.tl.theta, raw.OU.M.2.tl.theta), 2)
signif(c(raw.BM.1.tl.theta.sd, raw.BM.M.tl.theta.sd, raw.OU.1.tl.theta.sd, raw.OU.M.tl.theta.sd, raw.OU.M.2.tl.theta.sd), 2)
raw.alpha.tl<-list()
raw.alpha.tl<-foreach(i=1:100)%dopar%{raw.alpha.tl[[i]] <- c(raw.OU.1.tl[[i]]$alpha, raw.OU.M.tl[[i]]$alpha)}
raw.alpha.tl.vect<-(unlist(raw.alpha.tl))
raw.OU.1.tl.alpha<-mean(raw.alpha.tl.vect[seq(1, length(raw.alpha.tl.vect), 2)])
raw.OU.1.tl.alpha.sd<-sd(raw.alpha.tl.vect[seq(1, length(raw.alpha.tl.vect), 2)])
raw.OU.M.tl.alpha<-mean(raw.alpha.tl.vect[seq(2, length(raw.alpha.tl.vect), 2)])
raw.OU.M.tl.alpha.sd<-sd(raw.alpha.tl.vect[seq(2, length(raw.alpha.tl.vect), 2)])
signif(c(raw.OU.1.tl.alpha, raw.OU.M.tl.alpha), 2)
signif(c(raw.OU.1.tl.alpha.sd, raw.OU.M.tl.alpha.sd), 2)
raw.aic.tl<-foreach(i=1:100)%dopar%{raw.aic.tl[[i]] <- c(raw.BM.1.tl[[i]]$AICc, raw.BM.M.tl[[i]]$AICc, raw.OU.1.tl[[i]]$AICc, raw.OU.M.tl[[i]]$AICc)}
raw.aic.tl.vect<-(unlist(raw.aic.tl))
raw.BM.1.tl.aic<-mean(raw.aic.tl.vect[seq(1, length(raw.aic.tl.vect), 4)])
raw.BM.1.tl.aic.sd<-sd(raw.aic.tl.vect[seq(1, length(raw.aic.tl.vect), 4)])
raw.BM.M.tl.aic<-mean(raw.aic.tl.vect[seq(2, length(raw.aic.tl.vect), 4)])
raw.BM.M.tl.aic.sd<-sd(raw.aic.tl.vect[seq(2, length(raw.aic.tl.vect), 4)])
raw.OU.1.tl.aic<-mean(raw.aic.tl.vect[seq(3, length(raw.aic.tl.vect), 4)])
raw.OU.1.tl.aic.sd<-sd(raw.aic.tl.vect[seq(3, length(raw.aic.tl.vect), 4)])
raw.OU.M.tl.aic<-mean(raw.aic.tl.vect[seq(4, length(raw.aic.tl.vect), 4)])
raw.OU.M.tl.aic.sd<-sd(raw.aic.tl.vect[seq(4, length(raw.aic.tl.vect), 4)])
signif(c(raw.BM.1.tl.aic, raw.BM.M.tl.aic, raw.OU.1.tl.aic, raw.OU.M.tl.aic), 4)
signif(c(raw.BM.1.tl.aic.sd, raw.BM.M.tl.aic.sd, raw.OU.1.tl.aic.sd, raw.OU.M.tl.aic.sd), 4)
power.error(raw.OU.M.tl[[1]], raw.BM.1.tl[[1]])

#tv
raw.BM.1.tv <- list()
raw.BM.M.tv <- list()
raw.OU.1.tv <- list()
raw.OU.M.tv <- list()
raw.aicw.tv <- list()
raw.aic.tv <- list()
raw.BM.1.tv<-foreach(i=1:100)%dopar%{raw.BM.1.tv[[i]]<-mvBM(painttree[[i]], tv,error=se.tv^2, model='BM1')}
raw.BM.M.tv<-foreach(i=1:100)%dopar%{raw.BM.M.tv[[i]]<-mvBM(painttree[[i]], tv,error=se.tv^2, model='BMM')}
raw.OU.1.tv<-foreach(i=1:100)%dopar%{raw.OU.1.tv[[i]]<-mvOU(painttree[[i]], tv,error=se.tv^2,model='OU1')}
raw.OU.M.tv<-foreach(i=1:100)%dopar%{raw.OU.M.tv[[i]]<-mvOU(painttree[[i]], tv,error=se.tv^2,model='OUM')}
raw.aicw.tv<-foreach(i=1:100)%dopar%{raw.aic.tv[[i]] <- aic.w(c(raw.BM.1.tv[[i]]$AICc, raw.BM.M.tv[[i]]$AICc, raw.OU.1.tv[[i]]$AICc, raw.OU.M.tv[[i]]$AICc))}
raw.aicw.tv.vect<-(unlist(raw.aicw.tv))
raw.BM.1.tv.w<-mean(raw.aicw.tv.vect[seq(1, length(raw.aicw.tv.vect), 4)])
raw.BM.M.tv.w<-mean(raw.aicw.tv.vect[seq(2, length(raw.aicw.tv.vect), 4)])
raw.OU.1.tv.w<-mean(raw.aicw.tv.vect[seq(3, length(raw.aicw.tv.vect), 4)])
raw.OU.M.tv.w<-mean(raw.aicw.tv.vect[seq(4, length(raw.aicw.tv.vect), 4)])
signif(c(raw.BM.1.tv.w, raw.BM.M.tv.w, raw.OU.1.tv.w, raw.OU.M.tv.w), 2)
raw.BM.1.tv.w.sd<-sd(raw.aicw.tv.vect[seq(1, length(raw.aicw.tv.vect), 4)])
raw.BM.M.tv.w.sd<-sd(raw.aicw.tv.vect[seq(2, length(raw.aicw.tv.vect), 4)])
raw.OU.1.tv.w.sd<-sd(raw.aicw.tv.vect[seq(3, length(raw.aicw.tv.vect), 4)])
raw.OU.M.tv.w.sd<-sd(raw.aicw.tv.vect[seq(4, length(raw.aicw.tv.vect), 4)])
signif(c(raw.BM.1.tv.w.sd, raw.BM.M.tv.w.sd, raw.OU.1.tv.w.sd, raw.OU.M.tv.w.sd), 2)
raw.sigma.tv <- list()
raw.sigma.tv<-foreach(i=1:100)%dopar%{raw.sigma.tv[[i]] <- c(raw.BM.1.tv[[i]]$sigma, raw.BM.M.tv[[i]]$sigma, raw.OU.1.tv[[i]]$sigma, raw.OU.M.tv[[i]]$sigma)}
raw.sigma.tv.vect<-(unlist(raw.sigma.tv))
raw.BM.1.tv.sigma<-mean(raw.sigma.tv.vect[seq(1, length(raw.sigma.tv.vect), 5)])
raw.BM.1.tv.sigma.sd<-sd(raw.sigma.tv.vect[seq(1, length(raw.sigma.tv.vect), 5)])
raw.BM.M.tv.sigma<-mean(raw.sigma.tv.vect[seq(2, length(raw.sigma.tv.vect), 5)])
raw.BM.M.tv.sigma.sd<-sd(raw.sigma.tv.vect[seq(2, length(raw.sigma.tv.vect), 5)])
raw.BM.M.2.tv.sigma<-mean(raw.sigma.tv.vect[seq(3, length(raw.sigma.tv.vect), 5)])
raw.BM.M.2.tv.sigma.sd<-sd(raw.sigma.tv.vect[seq(3, length(raw.sigma.tv.vect), 5)])
raw.OU.1.tv.sigma<-mean(raw.sigma.tv.vect[seq(4, length(raw.sigma.tv.vect), 5)])
raw.OU.1.tv.sigma.sd<-sd(raw.sigma.tv.vect[seq(4, length(raw.sigma.tv.vect), 5)])
raw.OU.M.tv.sigma<-mean(raw.sigma.tv.vect[seq(5, length(raw.sigma.tv.vect), 5)])
raw.OU.M.tv.sigma.sd<-sd(raw.sigma.tv.vect[seq(5, length(raw.sigma.tv.vect), 5)])
signif(c(raw.BM.1.tv.sigma, raw.BM.M.tv.sigma, raw.BM.M.2.tv.sigma, raw.OU.1.tv.sigma, raw.OU.M.tv.sigma), 2)
signif(c(raw.BM.1.tv.sigma.sd, raw.BM.M.tv.sigma.sd, raw.BM.M.2.tv.sigma.sd, raw.OU.1.tv.sigma.sd, raw.OU.M.tv.sigma.sd), 2)
raw.theta.tv <- list()
raw.theta.tv<-foreach(i=1:100)%dopar%{raw.theta.tv[[i]] <- c(raw.BM.1.tv[[i]]$theta, raw.BM.M.tv[[i]]$theta, raw.OU.1.tv[[i]]$theta, raw.OU.M.tv[[i]]$theta)}
raw.theta.tv.vect<-(unlist(raw.theta.tv))
raw.BM.1.tv.theta<-mean(raw.theta.tv.vect[seq(1, length(raw.theta.tv.vect), 5)])
raw.BM.1.tv.theta.sd<-sd(raw.theta.tv.vect[seq(1, length(raw.theta.tv.vect), 5)])
raw.BM.M.tv.theta<-mean(raw.theta.tv.vect[seq(2, length(raw.theta.tv.vect), 5)])
raw.BM.M.tv.theta.sd<-sd(raw.theta.tv.vect[seq(2, length(raw.theta.tv.vect), 5)])
raw.OU.1.tv.theta<-mean(raw.theta.tv.vect[seq(3, length(raw.theta.tv.vect), 5)])
raw.OU.1.tv.theta.sd<-sd(raw.theta.tv.vect[seq(3, length(raw.theta.tv.vect), 5)])
raw.OU.M.tv.theta<-mean(raw.theta.tv.vect[seq(4, length(raw.theta.tv.vect), 5)])
raw.OU.M.tv.theta.sd<-sd(raw.theta.tv.vect[seq(4, length(raw.theta.tv.vect), 5)])
raw.OU.M.2.tv.theta<-mean(raw.theta.tv.vect[seq(5, length(raw.theta.tv.vect), 5)])
raw.OU.M.2.tv.theta.sd<-sd(raw.theta.tv.vect[seq(5, length(raw.theta.tv.vect), 5)])
signif(c(raw.BM.1.tv.theta, raw.BM.M.tv.theta, raw.OU.1.tv.theta, raw.OU.M.tv.theta, raw.OU.M.2.tv.theta), 2)
signif(c(raw.BM.1.tv.theta.sd, raw.BM.M.tv.theta.sd, raw.OU.1.tv.theta.sd, raw.OU.M.tv.theta.sd, raw.OU.M.2.tv.theta.sd), 2)
raw.alpha.tv<-list()
raw.alpha.tv<-foreach(i=1:100)%dopar%{raw.alpha.tv[[i]] <- c(raw.OU.1.tv[[i]]$alpha, raw.OU.M.tv[[i]]$alpha)}
raw.alpha.tv.vect<-(unlist(raw.alpha.tv))
raw.OU.1.tv.alpha<-mean(raw.alpha.tv.vect[seq(1, length(raw.alpha.tv.vect), 2)])
raw.OU.1.tv.alpha.sd<-sd(raw.alpha.tv.vect[seq(1, length(raw.alpha.tv.vect), 2)])
raw.OU.M.tv.alpha<-mean(raw.alpha.tv.vect[seq(2, length(raw.alpha.tv.vect), 2)])
raw.OU.M.tv.alpha.sd<-sd(raw.alpha.tv.vect[seq(2, length(raw.alpha.tv.vect), 2)])
signif(c(raw.OU.1.tv.alpha, raw.OU.M.tv.alpha), 2)
signif(c(raw.OU.1.tv.alpha.sd, raw.OU.M.tv.alpha.sd), 2)
raw.aic.tv<-list()
raw.aic.tv<-foreach(i=1:100)%dopar%{raw.aic.tv[[i]] <- c(raw.BM.1.tv[[i]]$AICc, raw.BM.M.tv[[i]]$AICc, raw.OU.1.tv[[i]]$AICc, raw.OU.M.tv[[i]]$AICc)}
raw.aic.tv.vect<-(unlist(raw.aic.tv))
raw.BM.1.tv.aic<-mean(raw.aic.tv.vect[seq(1, length(raw.aic.tv.vect), 4)])
raw.BM.1.tv.aic.sd<-sd(raw.aic.tv.vect[seq(1, length(raw.aic.tv.vect), 4)])
raw.BM.M.tv.aic<-mean(raw.aic.tv.vect[seq(2, length(raw.aic.tv.vect), 4)])
raw.BM.M.tv.aic.sd<-sd(raw.aic.tv.vect[seq(2, length(raw.aic.tv.vect), 4)])
raw.OU.1.tv.aic<-mean(raw.aic.tv.vect[seq(3, length(raw.aic.tv.vect), 4)])
raw.OU.1.tv.aic.sd<-sd(raw.aic.tv.vect[seq(3, length(raw.aic.tv.vect), 4)])
raw.OU.M.tv.aic<-mean(raw.aic.tv.vect[seq(4, length(raw.aic.tv.vect), 4)])
raw.OU.M.tv.aic.sd<-sd(raw.aic.tv.vect[seq(4, length(raw.aic.tv.vect), 4)])
signif(c(raw.BM.1.tv.aic, raw.BM.M.tv.aic, raw.OU.1.tv.aic, raw.OU.M.tv.aic), 4)
signif(c(raw.BM.1.tv.aic.sd, raw.BM.M.tv.aic.sd, raw.OU.1.tv.aic.sd, raw.OU.M.tv.aic.sd), 4)
power.error(raw.OU.M.tv[[1]], raw.BM.1.tv[[1]])

#tbp
raw.BM.1.tbp <- list()
raw.BM.M.tbp <- list()
raw.OU.1.tbp <- list()
raw.OU.M.tbp <- list()
raw.aicw.tbp <- list()
raw.aic.tbp <- list()
raw.BM.1.tbp<-foreach(i=1:100)%dopar%{raw.BM.1.tbp[[i]]<-mvBM(painttree[[i]], tbp,error=se.tbp^2, model='BM1')}
raw.BM.M.tbp<-foreach(i=1:100)%dopar%{raw.BM.M.tbp[[i]]<-mvBM(painttree[[i]], tbp,error=se.tbp^2, model='BMM')}
raw.OU.1.tbp<-foreach(i=1:100)%dopar%{raw.OU.1.tbp[[i]]<-mvOU(painttree[[i]], tbp,error=se.tbp^2,model='OU1')}
raw.OU.M.tbp<-foreach(i=1:100)%dopar%{raw.OU.M.tbp[[i]]<-mvOU(painttree[[i]], tbp,error=se.tbp^2,model='OUM')}
raw.aicw.tbp<-foreach(i=1:100)%dopar%{raw.aic.tbp[[i]] <- aic.w(c(raw.BM.1.tbp[[i]]$AICc, raw.BM.M.tbp[[i]]$AICc, raw.OU.1.tbp[[i]]$AICc, raw.OU.M.tbp[[i]]$AICc))}
raw.aicw.tbp.vect<-(unlist(raw.aicw.tbp))
raw.BM.1.tbp.w<-mean(raw.aicw.tbp.vect[seq(1, length(raw.aicw.tbp.vect), 4)])
raw.BM.M.tbp.w<-mean(raw.aicw.tbp.vect[seq(2, length(raw.aicw.tbp.vect), 4)])
raw.OU.1.tbp.w<-mean(raw.aicw.tbp.vect[seq(3, length(raw.aicw.tbp.vect), 4)])
raw.OU.M.tbp.w<-mean(raw.aicw.tbp.vect[seq(4, length(raw.aicw.tbp.vect), 4)])
signif(c(raw.BM.1.tbp.w, raw.BM.M.tbp.w, raw.OU.1.tbp.w, raw.OU.M.tbp.w), 2)
raw.BM.1.tbp.w.sd<-sd(raw.aicw.tbp.vect[seq(1, length(raw.aicw.tbp.vect), 4)])
raw.BM.M.tbp.w.sd<-sd(raw.aicw.tbp.vect[seq(2, length(raw.aicw.tbp.vect), 4)])
raw.OU.1.tbp.w.sd<-sd(raw.aicw.tbp.vect[seq(3, length(raw.aicw.tbp.vect), 4)])
raw.OU.M.tbp.w.sd<-sd(raw.aicw.tbp.vect[seq(4, length(raw.aicw.tbp.vect), 4)])
signif(c(raw.BM.1.tbp.w.sd, raw.BM.M.tbp.w.sd, raw.OU.1.tbp.w.sd, raw.OU.M.tbp.w.sd), 2)
raw.sigma.tbp <- list()
raw.sigma.tbp<-foreach(i=1:100)%dopar%{raw.sigma.tbp[[i]] <- c(raw.BM.1.tbp[[i]]$sigma, raw.BM.M.tbp[[i]]$sigma, raw.OU.1.tbp[[i]]$sigma, raw.OU.M.tbp[[i]]$sigma)}
raw.sigma.tbp.vect<-(unlist(raw.sigma.tbp))
raw.BM.1.tbp.sigma<-mean(raw.sigma.tbp.vect[seq(1, length(raw.sigma.tbp.vect), 5)])
raw.BM.1.tbp.sigma.sd<-sd(raw.sigma.tbp.vect[seq(1, length(raw.sigma.tbp.vect), 5)])
raw.BM.M.tbp.sigma<-mean(raw.sigma.tbp.vect[seq(2, length(raw.sigma.tbp.vect), 5)])
raw.BM.M.tbp.sigma.sd<-sd(raw.sigma.tbp.vect[seq(2, length(raw.sigma.tbp.vect), 5)])
raw.BM.M.2.tbp.sigma<-mean(raw.sigma.tbp.vect[seq(3, length(raw.sigma.tbp.vect), 5)])
raw.BM.M.2.tbp.sigma.sd<-sd(raw.sigma.tbp.vect[seq(3, length(raw.sigma.tbp.vect), 5)])
raw.OU.1.tbp.sigma<-mean(raw.sigma.tbp.vect[seq(4, length(raw.sigma.tbp.vect), 5)])
raw.OU.1.tbp.sigma.sd<-sd(raw.sigma.tbp.vect[seq(4, length(raw.sigma.tbp.vect), 5)])
raw.OU.M.tbp.sigma<-mean(raw.sigma.tbp.vect[seq(5, length(raw.sigma.tbp.vect), 5)])
raw.OU.M.tbp.sigma.sd<-sd(raw.sigma.tbp.vect[seq(5, length(raw.sigma.tbp.vect), 5)])
signif(c(raw.BM.1.tbp.sigma, raw.BM.M.tbp.sigma, raw.BM.M.2.tbp.sigma, raw.OU.1.tbp.sigma, raw.OU.M.tbp.sigma), 2)
signif(c(raw.BM.1.tbp.sigma.sd, raw.BM.M.tbp.sigma.sd, raw.BM.M.2.tbp.sigma.sd, raw.OU.1.tbp.sigma.sd, raw.OU.M.tbp.sigma.sd), 2)
raw.theta.tbp <- list()
raw.theta.tbp<-foreach(i=1:100)%dopar%{raw.theta.tbp[[i]] <- c(raw.BM.1.tbp[[i]]$theta, raw.BM.M.tbp[[i]]$theta, raw.OU.1.tbp[[i]]$theta, raw.OU.M.tbp[[i]]$theta)}
raw.theta.tbp.vect<-(unlist(raw.theta.tbp))
raw.BM.1.tbp.theta<-mean(raw.theta.tbp.vect[seq(1, length(raw.theta.tbp.vect), 5)])
raw.BM.1.tbp.theta.sd<-sd(raw.theta.tbp.vect[seq(1, length(raw.theta.tbp.vect), 5)])
raw.BM.M.tbp.theta<-mean(raw.theta.tbp.vect[seq(2, length(raw.theta.tbp.vect), 5)])
raw.BM.M.tbp.theta.sd<-sd(raw.theta.tbp.vect[seq(2, length(raw.theta.tbp.vect), 5)])
raw.OU.1.tbp.theta<-mean(raw.theta.tbp.vect[seq(3, length(raw.theta.tbp.vect), 5)])
raw.OU.1.tbp.theta.sd<-sd(raw.theta.tbp.vect[seq(3, length(raw.theta.tbp.vect), 5)])
raw.OU.M.tbp.theta<-mean(raw.theta.tbp.vect[seq(4, length(raw.theta.tbp.vect), 5)])
raw.OU.M.tbp.theta.sd<-sd(raw.theta.tbp.vect[seq(4, length(raw.theta.tbp.vect), 5)])
raw.OU.M.2.tbp.theta<-mean(raw.theta.tbp.vect[seq(5, length(raw.theta.tbp.vect), 5)])
raw.OU.M.2.tbp.theta.sd<-sd(raw.theta.tbp.vect[seq(5, length(raw.theta.tbp.vect), 5)])
signif(c(raw.BM.1.tbp.theta, raw.BM.M.tbp.theta, raw.OU.1.tbp.theta, raw.OU.M.tbp.theta, raw.OU.M.2.tbp.theta), 2)
signif(c(raw.BM.1.tbp.theta.sd, raw.BM.M.tbp.theta.sd, raw.OU.1.tbp.theta.sd, raw.OU.M.tbp.theta.sd, raw.OU.M.2.tbp.theta.sd), 2)
raw.alpha.tbp<-list()
raw.alpha.tbp<-foreach(i=1:100)%dopar%{raw.alpha.tbp[[i]] <- c(raw.OU.1.tbp[[i]]$alpha, raw.OU.M.tbp[[i]]$alpha)}
raw.alpha.tbp.vect<-(unlist(raw.alpha.tbp))
raw.OU.1.tbp.alpha<-mean(raw.alpha.tbp.vect[seq(1, length(raw.alpha.tbp.vect), 2)])
raw.OU.1.tbp.alpha.sd<-sd(raw.alpha.tbp.vect[seq(1, length(raw.alpha.tbp.vect), 2)])
raw.OU.M.tbp.alpha<-mean(raw.alpha.tbp.vect[seq(2, length(raw.alpha.tbp.vect), 2)])
raw.OU.M.tbp.alpha.sd<-sd(raw.alpha.tbp.vect[seq(2, length(raw.alpha.tbp.vect), 2)])
signif(c(raw.OU.1.tbp.alpha, raw.OU.M.tbp.alpha), 2)
signif(c(raw.OU.1.tbp.alpha.sd, raw.OU.M.tbp.alpha.sd), 2)
raw.aic.tbp<-foreach(i=1:100)%dopar%{raw.aic.tbp[[i]] <- c(raw.BM.1.tbp[[i]]$AICc, raw.BM.M.tbp[[i]]$AICc, raw.OU.1.tbp[[i]]$AICc, raw.OU.M.tbp[[i]]$AICc)}
raw.aic.tbp.vect<-(unlist(raw.aic.tbp))
raw.BM.1.tbp.aic<-mean(raw.aic.tbp.vect[seq(1, length(raw.aic.tbp.vect), 4)])
raw.BM.1.tbp.aic.sd<-sd(raw.aic.tbp.vect[seq(1, length(raw.aic.tbp.vect), 4)])
raw.BM.M.tbp.aic<-mean(raw.aic.tbp.vect[seq(2, length(raw.aic.tbp.vect), 4)])
raw.BM.M.tbp.aic.sd<-sd(raw.aic.tbp.vect[seq(2, length(raw.aic.tbp.vect), 4)])
raw.OU.1.tbp.aic<-mean(raw.aic.tbp.vect[seq(3, length(raw.aic.tbp.vect), 4)])
raw.OU.1.tbp.aic.sd<-sd(raw.aic.tbp.vect[seq(3, length(raw.aic.tbp.vect), 4)])
raw.OU.M.tbp.aic<-mean(raw.aic.tbp.vect[seq(4, length(raw.aic.tbp.vect), 4)])
raw.OU.M.tbp.aic.sd<-sd(raw.aic.tbp.vect[seq(4, length(raw.aic.tbp.vect), 4)])
signif(c(raw.BM.1.tbp.aic, raw.BM.M.tbp.aic, raw.OU.1.tbp.aic, raw.OU.M.tbp.aic), 4)
signif(c(raw.BM.1.tbp.aic.sd, raw.BM.M.tbp.aic.sd, raw.OU.1.tbp.aic.sd, raw.OU.M.tbp.aic.sd), 4)
power.error(raw.OU.M.tbp[[1]], raw.BM.1.tbp[[1]])

#cycle
raw.BM.1.cycle <- list()
raw.BM.M.cycle <- list()
raw.OU.1.cycle <- list()
raw.OU.M.cycle <- list()
raw.aicw.cycle <- list()
raw.aic.cycle <- list()
raw.BM.1.cycle<-foreach(i=1:100)%dopar%{raw.BM.1.cycle[[i]]<-mvBM(painttree[[i]], cycle,error=se.cycle^2, model='BM1')}
raw.BM.M.cycle<-foreach(i=1:100)%dopar%{raw.BM.M.cycle[[i]]<-mvBM(painttree[[i]], cycle,error=se.cycle^2, model='BMM')}
raw.OU.1.cycle<-foreach(i=1:100)%dopar%{raw.OU.1.cycle[[i]]<-mvOU(painttree[[i]], cycle,error=se.cycle^2,model='OU1')}
raw.OU.M.cycle<-foreach(i=1:100)%dopar%{raw.OU.M.cycle[[i]]<-mvOU(painttree[[i]], cycle,error=se.cycle^2,model='OUM')}
raw.aicw.cycle<-foreach(i=1:100)%dopar%{raw.aic.cycle[[i]] <- aic.w(c(raw.BM.1.cycle[[i]]$AICc, raw.BM.M.cycle[[i]]$AICc, raw.OU.1.cycle[[i]]$AICc, raw.OU.M.cycle[[i]]$AICc))}
raw.aicw.cycle.vect<-(unlist(raw.aicw.cycle))
raw.BM.1.cycle.w<-mean(raw.aicw.cycle.vect[seq(1, length(raw.aicw.cycle.vect), 4)])
raw.BM.M.cycle.w<-mean(raw.aicw.cycle.vect[seq(2, length(raw.aicw.cycle.vect), 4)])
raw.OU.1.cycle.w<-mean(raw.aicw.cycle.vect[seq(3, length(raw.aicw.cycle.vect), 4)])
raw.OU.M.cycle.w<-mean(raw.aicw.cycle.vect[seq(4, length(raw.aicw.cycle.vect), 4)])
signif(c(raw.BM.1.cycle.w, raw.BM.M.cycle.w, raw.OU.1.cycle.w, raw.OU.M.cycle.w), 2)
raw.BM.1.cycle.w.sd<-sd(raw.aicw.cycle.vect[seq(1, length(raw.aicw.cycle.vect), 4)])
raw.BM.M.cycle.w.sd<-sd(raw.aicw.cycle.vect[seq(2, length(raw.aicw.cycle.vect), 4)])
raw.OU.1.cycle.w.sd<-sd(raw.aicw.cycle.vect[seq(3, length(raw.aicw.cycle.vect), 4)])
raw.OU.M.cycle.w.sd<-sd(raw.aicw.cycle.vect[seq(4, length(raw.aicw.cycle.vect), 4)])
signif(c(raw.BM.1.cycle.w.sd, raw.BM.M.cycle.w.sd, raw.OU.1.cycle.w.sd, raw.OU.M.cycle.w.sd), 2)
raw.sigma.cycle <- list()
raw.sigma.cycle<-foreach(i=1:100)%dopar%{raw.sigma.cycle[[i]] <- c(raw.BM.1.cycle[[i]]$sigma, raw.BM.M.cycle[[i]]$sigma, raw.OU.1.cycle[[i]]$sigma, raw.OU.M.cycle[[i]]$sigma)}
raw.sigma.cycle.vect<-(unlist(raw.sigma.cycle))
raw.BM.1.cycle.sigma<-mean(raw.sigma.cycle.vect[seq(1, length(raw.sigma.cycle.vect), 5)])
raw.BM.1.cycle.sigma.sd<-sd(raw.sigma.cycle.vect[seq(1, length(raw.sigma.cycle.vect), 5)])
raw.BM.M.cycle.sigma<-mean(raw.sigma.cycle.vect[seq(2, length(raw.sigma.cycle.vect), 5)])
raw.BM.M.cycle.sigma.sd<-sd(raw.sigma.cycle.vect[seq(2, length(raw.sigma.cycle.vect), 5)])
raw.BM.M.2.cycle.sigma<-mean(raw.sigma.cycle.vect[seq(3, length(raw.sigma.cycle.vect), 5)])
raw.BM.M.2.cycle.sigma.sd<-sd(raw.sigma.cycle.vect[seq(3, length(raw.sigma.cycle.vect), 5)])
raw.OU.1.cycle.sigma<-mean(raw.sigma.cycle.vect[seq(4, length(raw.sigma.cycle.vect), 5)])
raw.OU.1.cycle.sigma.sd<-sd(raw.sigma.cycle.vect[seq(4, length(raw.sigma.cycle.vect), 5)])
raw.OU.M.cycle.sigma<-mean(raw.sigma.cycle.vect[seq(5, length(raw.sigma.cycle.vect), 5)])
raw.OU.M.cycle.sigma.sd<-sd(raw.sigma.cycle.vect[seq(5, length(raw.sigma.cycle.vect), 5)])
signif(c(raw.BM.1.cycle.sigma, raw.BM.M.cycle.sigma, raw.BM.M.2.cycle.sigma, raw.OU.1.cycle.sigma, raw.OU.M.cycle.sigma), 2)
signif(c(raw.BM.1.cycle.sigma.sd, raw.BM.M.cycle.sigma.sd, raw.BM.M.2.cycle.sigma.sd, raw.OU.1.cycle.sigma.sd, raw.OU.M.cycle.sigma.sd), 2)
raw.theta.cycle <- list()
raw.theta.cycle<-foreach(i=1:100)%dopar%{raw.theta.cycle[[i]] <- c(raw.BM.1.cycle[[i]]$theta, raw.BM.M.cycle[[i]]$theta, raw.OU.1.cycle[[i]]$theta, raw.OU.M.cycle[[i]]$theta)}
raw.theta.cycle.vect<-(unlist(raw.theta.cycle))
raw.BM.1.cycle.theta<-mean(raw.theta.cycle.vect[seq(1, length(raw.theta.cycle.vect), 5)])
raw.BM.1.cycle.theta.sd<-sd(raw.theta.cycle.vect[seq(1, length(raw.theta.cycle.vect), 5)])
raw.BM.M.cycle.theta<-mean(raw.theta.cycle.vect[seq(2, length(raw.theta.cycle.vect), 5)])
raw.BM.M.cycle.theta.sd<-sd(raw.theta.cycle.vect[seq(2, length(raw.theta.cycle.vect), 5)])
raw.OU.1.cycle.theta<-mean(raw.theta.cycle.vect[seq(3, length(raw.theta.cycle.vect), 5)])
raw.OU.1.cycle.theta.sd<-sd(raw.theta.cycle.vect[seq(3, length(raw.theta.cycle.vect), 5)])
raw.OU.M.cycle.theta<-mean(raw.theta.cycle.vect[seq(4, length(raw.theta.cycle.vect), 5)])
raw.OU.M.cycle.theta.sd<-sd(raw.theta.cycle.vect[seq(4, length(raw.theta.cycle.vect), 5)])
raw.OU.M.2.cycle.theta<-mean(raw.theta.cycle.vect[seq(5, length(raw.theta.cycle.vect), 5)])
raw.OU.M.2.cycle.theta.sd<-sd(raw.theta.cycle.vect[seq(5, length(raw.theta.cycle.vect), 5)])
signif(c(raw.BM.1.cycle.theta, raw.BM.M.cycle.theta, raw.OU.1.cycle.theta, raw.OU.M.cycle.theta, raw.OU.M.2.cycle.theta), 2)
signif(c(raw.BM.1.cycle.theta.sd, raw.BM.M.cycle.theta.sd, raw.OU.1.cycle.theta.sd, raw.OU.M.cycle.theta.sd, raw.OU.M.2.cycle.theta.sd), 2)
raw.alpha.cycle<-list()
raw.alpha.cycle<-foreach(i=1:100)%dopar%{raw.alpha.cycle[[i]] <- c(raw.OU.1.cycle[[i]]$alpha, raw.OU.M.cycle[[i]]$alpha)}
raw.alpha.cycle.vect<-(unlist(raw.alpha.cycle))
raw.OU.1.cycle.alpha<-mean(raw.alpha.cycle.vect[seq(1, length(raw.alpha.cycle.vect), 2)])
raw.OU.1.cycle.alpha.sd<-sd(raw.alpha.cycle.vect[seq(1, length(raw.alpha.cycle.vect), 2)])
raw.OU.M.cycle.alpha<-mean(raw.alpha.cycle.vect[seq(2, length(raw.alpha.cycle.vect), 2)])
raw.OU.M.cycle.alpha.sd<-sd(raw.alpha.cycle.vect[seq(2, length(raw.alpha.cycle.vect), 2)])
signif(c(raw.OU.1.cycle.alpha, raw.OU.M.cycle.alpha), 2)
signif(c(raw.OU.1.cycle.alpha.sd, raw.OU.M.cycle.alpha.sd), 2)
raw.aic.cycle<-foreach(i=1:100)%dopar%{raw.aic.cycle[[i]] <- c(raw.BM.1.cycle[[i]]$AICc, raw.BM.M.cycle[[i]]$AICc, raw.OU.1.cycle[[i]]$AICc, raw.OU.M.cycle[[i]]$AICc)}
raw.aic.cycle.vect<-(unlist(raw.aic.cycle))
raw.BM.1.cycle.aic<-mean(raw.aic.cycle.vect[seq(1, length(raw.aic.cycle.vect), 4)])
raw.BM.1.cycle.aic.sd<-sd(raw.aic.cycle.vect[seq(1, length(raw.aic.cycle.vect), 4)])
raw.BM.M.cycle.aic<-mean(raw.aic.cycle.vect[seq(2, length(raw.aic.cycle.vect), 4)])
raw.BM.M.cycle.aic.sd<-sd(raw.aic.cycle.vect[seq(2, length(raw.aic.cycle.vect), 4)])
raw.OU.1.cycle.aic<-mean(raw.aic.cycle.vect[seq(3, length(raw.aic.cycle.vect), 4)])
raw.OU.1.cycle.aic.sd<-sd(raw.aic.cycle.vect[seq(3, length(raw.aic.cycle.vect), 4)])
raw.OU.M.cycle.aic<-mean(raw.aic.cycle.vect[seq(4, length(raw.aic.cycle.vect), 4)])
raw.OU.M.cycle.aic.sd<-sd(raw.aic.cycle.vect[seq(4, length(raw.aic.cycle.vect), 4)])
signif(c(raw.BM.1.cycle.aic, raw.BM.M.cycle.aic, raw.OU.1.cycle.aic, raw.OU.M.cycle.aic), 4)
signif(c(raw.BM.1.cycle.aic.sd, raw.BM.M.cycle.aic.sd, raw.OU.1.cycle.aic.sd, raw.OU.M.cycle.aic.sd), 4)
power.error(raw.OU.M.cycle[[1]], raw.BM.1.cycle[[1]])



# pgls regression cycle-forces --------------------------------------------
#peak.brake
pb.pgls.BM <- list ()
pb.pgls.BM.p <- list()
pb.pgls.BM.t <- list()
pb.pgls.BM.sig <- list()
pb.pgls.BM.aic<-list()
pb.pgls.BM.lam<-list()
pb.pgls.BM.slope<-list()
pb.pgls.BM.intercept<-list()
pb.pgls.OU <- list ()
pb.pgls.OU.p <- list()
pb.pgls.OU.t <- list()
pb.pgls.OU.sig <- list()
pb.pgls.OU.alpha <- list()
pb.pgls.OU.aic<-list()
pb.pgls.OU.slope<-list()
pb.pgls.OU.intercept<-list()
pb.aicw <- list()
for (i in 1:100){
  pb.pgls.BM[[i]]<-phylolm(cycle~peakbrake, phy=phylogeny.final.F[[i]], model=("lambda"))
  pb.pgls.OU[[i]]<-phylolm(cycle~peakbrake, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  pb.pgls.BM.p[[i]] <- summary(pb.pgls.BM[[i]])$coefficients[2,4]
  pb.pgls.BM.t[[i]] <- summary(pb.pgls.BM[[i]])$coefficients[2,3]
  pb.pgls.BM.sig[[i]] <- pb.pgls.BM[[i]]$sigma2
  pb.pgls.BM.lam[[i]] <- pb.pgls.BM[[i]]$optpar
  pb.pgls.BM.aic[[i]]<-pb.pgls.BM[[i]]$aic
  pb.pgls.BM.intercept[[i]]<-pb.pgls.BM[[i]]$coefficients[1]
  pb.pgls.BM.slope[[i]]<-pb.pgls.BM[[i]]$coefficients[2]
  pb.pgls.OU.p[[i]] <- summary(pb.pgls.OU[[i]])$coefficients[2,4]
  pb.pgls.OU.t[[i]] <- summary(pb.pgls.OU[[i]])$coefficients[2,3]
  pb.pgls.OU.sig[[i]] <- pb.pgls.OU[[i]]$sigma2
  pb.pgls.OU.alpha[[i]] <- pb.pgls.OU[[i]]$optpar
  pb.pgls.OU.aic[[i]]<-pb.pgls.OU[[i]]$aic
  pb.pgls.OU.intercept[[i]]<-pb.pgls.OU[[i]]$coefficients[1]
  pb.pgls.OU.slope[[i]]<-pb.pgls.OU[[i]]$coefficients[2]
  pb.aicw[[i]]<-aic.w(c(pb.pgls.BM[[i]]$aic, pb.pgls.OU[[i]]$aic))
}
pb.aicw.vect<-(unlist(pb.aicw))
pb.mean.BM.aicw<-mean(pb.aicw.vect[seq(1, length(pb.aicw.vect), 2)])
pb.mean.OU.aicw<-mean(pb.aicw.vect[seq(2, length(pb.aicw.vect), 2)])
signif(c(pb.mean.BM.aicw, pb.mean.OU.aicw), 2)
mean(unlist(pb.pgls.BM.p))
sd(unlist(pb.pgls.BM.p))
mean(unlist(pb.pgls.BM.t))
sd(unlist(pb.pgls.BM.t))
mean(unlist(pb.pgls.BM.sig))
sd(unlist(pb.pgls.BM.sig))
mean(unlist(pb.pgls.BM.lam))
sd(unlist(pb.pgls.BM.lam))
mean(unlist(pb.pgls.BM.intercept))
sd(unlist(pb.pgls.BM.intercept))
mean(unlist(pb.pgls.BM.slope))
sd(unlist(pb.pgls.BM.slope))
mean(unlist(pb.pgls.OU.p))
sd(unlist(pb.pgls.OU.p))
mean(unlist(pb.pgls.OU.t))
sd(unlist(pb.pgls.OU.t))
mean(unlist(pb.pgls.OU.sig))
sd(unlist(pb.pgls.OU.sig))
mean(unlist(pb.pgls.OU.alpha))
sd(unlist(pb.pgls.OU.alpha))
mean(unlist(pb.pgls.OU.intercept))
sd(unlist(pb.pgls.OU.intercept))
mean(unlist(pb.pgls.OU.slope))
sd(unlist(pb.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(pb.pgls.BM[[1]])~fitted(pb.pgls.BM[[1]]),   main=" Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(pb.pgls.BM[[1]]))
qqline(resid(pb.pgls.BM[[1]], col="blue"))
#heteroscedasticity-OU
plot(resid(pb.pgls.OU[[1]])~fitted(pb.pgls.OU[[1]]),   main=" Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(pb.pgls.OU[[1]]))
qqline(resid(pb.pgls.OU[[1]], col="blue"))


#peakaccel-cycle
pa.pgls.BM <- list ()
pa.pgls.BM.p <- list()
pa.pgls.BM.t <- list()
pa.pgls.BM.sig <- list()
pa.pgls.BM.aic<-list()
pa.pgls.BM.lam<-list()
pa.pgls.BM.slope<-list()
pa.pgls.BM.intercept<-list()
pa.pgls.OU <- list ()
pa.pgls.OU.p <- list()
pa.pgls.OU.t <- list()
pa.pgls.OU.sig <- list()
pa.pgls.OU.alpha <- list()
pa.pgls.OU.aic<-list()
pa.pgls.OU.slope<-list()
pa.pgls.OU.intercept<-list()
pa.aicw <- list()
for (i in 1:100){
  pa.pgls.BM[[i]]<-phylolm(cycle~peakaccel, phy=phylogeny.final.F[[i]], model=("lambda"))
  pa.pgls.OU[[i]]<-phylolm(cycle~peakaccel, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  pa.pgls.BM.p[[i]] <- summary(pa.pgls.BM[[i]])$coefficients[2,4]
  pa.pgls.BM.t[[i]] <- summary(pa.pgls.BM[[i]])$coefficients[2,3]
  pa.pgls.BM.sig[[i]] <- pa.pgls.BM[[i]]$sigma2
  pa.pgls.BM.lam[[i]] <- pa.pgls.BM[[i]]$optpar
  pa.pgls.BM.aic[[i]]<-pa.pgls.BM[[i]]$aic
  pa.pgls.BM.intercept[[i]]<-pa.pgls.BM[[i]]$coefficients[1]
  pa.pgls.BM.slope[[i]]<-pa.pgls.BM[[i]]$coefficients[2]
  pa.pgls.OU.p[[i]] <- summary(pa.pgls.OU[[i]])$coefficients[2,4]
  pa.pgls.OU.t[[i]] <- summary(pa.pgls.OU[[i]])$coefficients[2,3]
  pa.pgls.OU.sig[[i]] <- pa.pgls.OU[[i]]$sigma2
  pa.pgls.OU.alpha[[i]] <- pa.pgls.OU[[i]]$optpar
  pa.pgls.OU.aic[[i]]<-pa.pgls.OU[[i]]$aic
  pa.pgls.OU.intercept[[i]]<-pa.pgls.OU[[i]]$coefficients[1]
  pa.pgls.OU.slope[[i]]<-pa.pgls.OU[[i]]$coefficients[2]
  pa.aicw[[i]]<-aic.w(c(pa.pgls.BM[[i]]$aic, pa.pgls.OU[[i]]$aic))
}
pa.aicw.vect<-(unlist(pa.aicw))
pa.mean.BM.aicw<-mean(pa.aicw.vect[seq(1, length(pa.aicw.vect), 2)])
pa.mean.OU.aicw<-mean(pa.aicw.vect[seq(2, length(pa.aicw.vect), 2)])
signif(c(pa.mean.BM.aicw, pa.mean.OU.aicw), 2)
mean(unlist(pa.pgls.BM.p))
sd(unlist(pa.pgls.BM.p))
mean(unlist(pa.pgls.BM.t))
sd(unlist(pa.pgls.BM.t))
mean(unlist(pa.pgls.BM.sig))
sd(unlist(pa.pgls.BM.sig))
mean(unlist(pa.pgls.BM.lam))
sd(unlist(pa.pgls.BM.lam))
mean(unlist(pa.pgls.BM.intercept))
sd(unlist(pa.pgls.BM.intercept))
mean(unlist(pa.pgls.BM.slope))
sd(unlist(pa.pgls.BM.slope))
mean(unlist(pa.pgls.OU.p))
sd(unlist(pa.pgls.OU.p))
mean(unlist(pa.pgls.OU.t))
sd(unlist(pa.pgls.OU.t))
mean(unlist(pa.pgls.OU.sig))
sd(unlist(pa.pgls.OU.sig))
mean(unlist(pa.pgls.OU.alpha))
sd(unlist(pa.pgls.OU.alpha))
mean(unlist(pa.pgls.OU.intercept))
sd(unlist(pa.pgls.OU.intercept))
mean(unlist(pa.pgls.OU.slope))
sd(unlist(pa.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(pa.pgls.BM[[1]])~fitted(pa.pgls.BM[[1]]),   main=" Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(pa.pgls.BM[[1]]))
qqline(resid(pa.pgls.BM[[1]], col="blue"))
#heteroscedasticity-OU
plot(resid(pa.pgls.OU[[1]])~fitted(pa.pgls.OU[[1]]),   main=" Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(pa.pgls.OU[[1]]))
qqline(resid(pa.pgls.OU[[1]], col="blue"))

#peakmed-cycle
pm.pgls.BM <- list ()
pm.pgls.BM.p <- list()
pm.pgls.BM.t <- list()
pm.pgls.BM.sig <- list()
pm.pgls.BM.aic<-list()
pm.pgls.BM.lam<-list()
pm.pgls.BM.slope<-list()
pm.pgls.BM.intercept<-list()
pm.pgls.OU <- list ()
pm.pgls.OU.p <- list()
pm.pgls.OU.t <- list()
pm.pgls.OU.sig <- list()
pm.pgls.OU.alpha <- list()
pm.pgls.OU.aic<-list()
pm.pgls.OU.slope<-list()
pm.pgls.OU.intercept<-list()
pm.aicw <- list()
for (i in 1:100){
  pm.pgls.BM[[i]]<-phylolm(cycle~peakmed, phy=phylogeny.final.F[[i]], model=("lambda"))
  pm.pgls.OU[[i]]<-phylolm(cycle~peakmed, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  pm.pgls.BM.p[[i]] <- summary(pm.pgls.BM[[i]])$coefficients[2,4]
  pm.pgls.BM.t[[i]] <- summary(pm.pgls.BM[[i]])$coefficients[2,3]
  pm.pgls.BM.sig[[i]] <- pm.pgls.BM[[i]]$sigma2
  pm.pgls.BM.lam[[i]] <- pm.pgls.BM[[i]]$optpar
  pm.pgls.BM.aic[[i]]<-pm.pgls.BM[[i]]$aic
  pm.pgls.BM.intercept[[i]]<-pm.pgls.BM[[i]]$coefficients[1]
  pm.pgls.BM.slope[[i]]<-pm.pgls.BM[[i]]$coefficients[2]
  pm.pgls.OU.p[[i]] <- summary(pm.pgls.OU[[i]])$coefficients[2,4]
  pm.pgls.OU.t[[i]] <- summary(pm.pgls.OU[[i]])$coefficients[2,3]
  pm.pgls.OU.sig[[i]] <- pm.pgls.OU[[i]]$sigma2
  pm.pgls.OU.alpha[[i]] <- pm.pgls.OU[[i]]$optpar
  pm.pgls.OU.aic[[i]]<-pm.pgls.OU[[i]]$aic
  pm.pgls.OU.intercept[[i]]<-pm.pgls.OU[[i]]$coefficients[1]
  pm.pgls.OU.slope[[i]]<-pm.pgls.OU[[i]]$coefficients[2]
  pm.aicw[[i]]<-aic.w(c(pm.pgls.BM[[i]]$aic, pm.pgls.OU[[i]]$aic))
}
pm.aicw.vect<-(unlist(pm.aicw))
pm.mean.BM.aicw<-mean(pm.aicw.vect[seq(1, length(pm.aicw.vect), 2)])
pm.mean.OU.aicw<-mean(pm.aicw.vect[seq(2, length(pm.aicw.vect), 2)])
signif(c(pm.mean.BM.aicw, pm.mean.OU.aicw), 2)
mean(unlist(pm.pgls.BM.p))
sd(unlist(pm.pgls.BM.p))
mean(unlist(pm.pgls.BM.t))
sd(unlist(pm.pgls.BM.t))
mean(unlist(pm.pgls.BM.sig))
sd(unlist(pm.pgls.BM.sig))
mean(unlist(pm.pgls.BM.lam))
sd(unlist(pm.pgls.BM.lam))
mean(unlist(pm.pgls.BM.intercept))
sd(unlist(pm.pgls.BM.intercept))
mean(unlist(pm.pgls.BM.slope))
sd(unlist(pm.pgls.BM.slope))
mean(unlist(pm.pgls.OU.p))
sd(unlist(pm.pgls.OU.p))
mean(unlist(pm.pgls.OU.t))
sd(unlist(pm.pgls.OU.t))
mean(unlist(pm.pgls.OU.sig))
sd(unlist(pm.pgls.OU.sig))
mean(unlist(pm.pgls.OU.alpha))
sd(unlist(pm.pgls.OU.alpha))
mean(unlist(pm.pgls.OU.intercept))
sd(unlist(pm.pgls.OU.intercept))
mean(unlist(pm.pgls.OU.slope))
sd(unlist(pm.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(pm.pgls.BM[[1]])~fitted(pm.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(pm.pgls.BM[[1]]))
qqline(resid(pm.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(pm.pgls.OU[[1]])~fitted(pm.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(pm.pgls.OU[[1]]))
qqline(resid(pm.pgls.OU[[1]]))

#peaklat-cycle
pl.pgls.BM <- list ()
pl.pgls.BM.p <- list()
pl.pgls.BM.t <- list()
pl.pgls.BM.sig <- list()
pl.pgls.BM.aic<-list()
pl.pgls.BM.lam<-list()
pl.pgls.BM.slope<-list()
pl.pgls.BM.intercept<-list()
pl.pgls.OU <- list ()
pl.pgls.OU.p <- list()
pl.pgls.OU.t <- list()
pl.pgls.OU.sig <- list()
pl.pgls.OU.alpha <- list()
pl.pgls.OU.aic<-list()
pl.pgls.OU.slope<-list()
pl.pgls.OU.intercept<-list()
pl.aicw <- list()
for (i in 1:100){
  pl.pgls.BM[[i]]<-phylolm(cycle~peaklat, phy=phylogeny.final.F[[i]], model=("lambda"))
  pl.pgls.OU[[i]]<-phylolm(cycle~peaklat, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  pl.pgls.BM.p[[i]] <- summary(pl.pgls.BM[[i]])$coefficients[2,4]
  pl.pgls.BM.t[[i]] <- summary(pl.pgls.BM[[i]])$coefficients[2,3]
  pl.pgls.BM.sig[[i]] <- pl.pgls.BM[[i]]$sigma2
  pl.pgls.BM.lam[[i]] <- pl.pgls.BM[[i]]$optpar
  pl.pgls.BM.aic[[i]]<-pl.pgls.BM[[i]]$aic
  pl.pgls.BM.intercept[[i]]<-pl.pgls.BM[[i]]$coefficients[1]
  pl.pgls.BM.slope[[i]]<-pl.pgls.BM[[i]]$coefficients[2]
  pl.pgls.OU.p[[i]] <- summary(pl.pgls.OU[[i]])$coefficients[2,4]
  pl.pgls.OU.t[[i]] <- summary(pl.pgls.OU[[i]])$coefficients[2,3]
  pl.pgls.OU.sig[[i]] <- pl.pgls.OU[[i]]$sigma2
  pl.pgls.OU.alpha[[i]] <- pl.pgls.OU[[i]]$optpar
  pl.pgls.OU.aic[[i]]<-pl.pgls.OU[[i]]$aic
  pl.pgls.OU.intercept[[i]]<-pl.pgls.OU[[i]]$coefficients[1]
  pl.pgls.OU.slope[[i]]<-pl.pgls.OU[[i]]$coefficients[2]
  pl.aicw[[i]]<-aic.w(c(pl.pgls.BM[[i]]$aic, pl.pgls.OU[[i]]$aic))
}
pl.aicw.vect<-(unlist(pl.aicw))
pl.mean.BM.aicw<-mean(pl.aicw.vect[seq(1, length(pl.aicw.vect), 2)])
pl.mean.OU.aicw<-mean(pl.aicw.vect[seq(2, length(pl.aicw.vect), 2)])
signif(c(pl.mean.BM.aicw, pl.mean.OU.aicw), 2)
mean(unlist(pl.pgls.BM.p))
sd(unlist(pl.pgls.BM.p))
mean(unlist(pl.pgls.BM.t))
sd(unlist(pl.pgls.BM.t))
mean(unlist(pl.pgls.BM.sig))
sd(unlist(pl.pgls.BM.sig))
mean(unlist(pl.pgls.BM.lam))
sd(unlist(pl.pgls.BM.lam))
mean(unlist(pl.pgls.BM.intercept))
sd(unlist(pl.pgls.BM.intercept))
mean(unlist(pl.pgls.BM.slope))
sd(unlist(pl.pgls.BM.slope))
mean(unlist(pl.pgls.OU.p))
sd(unlist(pl.pgls.OU.p))
mean(unlist(pl.pgls.OU.t))
sd(unlist(pl.pgls.OU.t))
mean(unlist(pl.pgls.OU.sig))
sd(unlist(pl.pgls.OU.sig))
mean(unlist(pl.pgls.OU.alpha))
sd(unlist(pl.pgls.OU.alpha))
mean(unlist(pl.pgls.OU.intercept))
sd(unlist(pl.pgls.OU.intercept))
mean(unlist(pl.pgls.OU.slope))
sd(unlist(pl.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(pl.pgls.BM[[1]])~fitted(pl.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(pl.pgls.BM[[1]]))
qqline(resid(pl.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(pl.pgls.OU[[1]])~fitted(pl.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(pl.pgls.OU[[1]]))
qqline(resid(pl.pgls.OU[[1]]))

#peakvert-cycle
pv.pgls.BM <- list ()
pv.pgls.BM.p <- list()
pv.pgls.BM.t <- list()
pv.pgls.BM.sig <- list()
pv.pgls.BM.aic<-list()
pv.pgls.BM.lam<-list()
pv.pgls.BM.slope<-list()
pv.pgls.BM.intercept<-list()
pv.pgls.OU <- list ()
pv.pgls.OU.p <- list()
pv.pgls.OU.t <- list()
pv.pgls.OU.sig <- list()
pv.pgls.OU.alpha <- list()
pv.pgls.OU.aic<-list()
pv.pgls.OU.slope<-list()
pv.pgls.OU.intercept<-list()
pv.aicw <- list()
for (i in 1:100){
  pv.pgls.BM[[i]]<-phylolm(cycle~peakv, phy=phylogeny.final.F[[i]], model=("lambda"))
  pv.pgls.OU[[i]]<-phylolm(cycle~peakv, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  pv.pgls.BM.p[[i]] <- summary(pv.pgls.BM[[i]])$coefficients[2,4]
  pv.pgls.BM.t[[i]] <- summary(pv.pgls.BM[[i]])$coefficients[2,3]
  pv.pgls.BM.sig[[i]] <- pv.pgls.BM[[i]]$sigma2
  pv.pgls.BM.lam[[i]] <- pv.pgls.BM[[i]]$optpar
  pv.pgls.BM.aic[[i]]<-pv.pgls.BM[[i]]$aic
  pv.pgls.BM.intercept[[i]]<-pv.pgls.BM[[i]]$coefficients[1]
  pv.pgls.BM.slope[[i]]<-pv.pgls.BM[[i]]$coefficients[2]
  pv.pgls.OU.p[[i]] <- summary(pv.pgls.OU[[i]])$coefficients[2,4]
  pv.pgls.OU.t[[i]] <- summary(pv.pgls.OU[[i]])$coefficients[2,3]
  pv.pgls.OU.sig[[i]] <- pv.pgls.OU[[i]]$sigma2
  pv.pgls.OU.alpha[[i]] <- pv.pgls.OU[[i]]$optpar
  pv.pgls.OU.aic[[i]]<-pv.pgls.OU[[i]]$aic
  pv.pgls.OU.intercept[[i]]<-pv.pgls.OU[[i]]$coefficients[1]
  pv.pgls.OU.slope[[i]]<-pv.pgls.OU[[i]]$coefficients[2]
  pv.aicw[[i]]<-aic.w(c(pv.pgls.BM[[i]]$aic, pv.pgls.OU[[i]]$aic))
}
pv.aicw.vect<-(unlist(pv.aicw))
pv.mean.BM.aicw<-mean(pv.aicw.vect[seq(1, length(pv.aicw.vect), 2)])
pv.mean.OU.aicw<-mean(pv.aicw.vect[seq(2, length(pv.aicw.vect), 2)])
signif(c(pv.mean.BM.aicw, pv.mean.OU.aicw), 2)
mean(unlist(pv.pgls.BM.p))
sd(unlist(pv.pgls.BM.p))
mean(unlist(pv.pgls.BM.t))
sd(unlist(pv.pgls.BM.t))
mean(unlist(pv.pgls.BM.sig))
sd(unlist(pv.pgls.BM.sig))
mean(unlist(pv.pgls.BM.lam))
sd(unlist(pv.pgls.BM.lam))
mean(unlist(pv.pgls.BM.intercept))
sd(unlist(pv.pgls.BM.intercept))
mean(unlist(pv.pgls.BM.slope))
sd(unlist(pv.pgls.BM.slope))
mean(unlist(pv.pgls.OU.p))
sd(unlist(pv.pgls.OU.p))
mean(unlist(pv.pgls.OU.t))
sd(unlist(pv.pgls.OU.t))
mean(unlist(pv.pgls.OU.sig))
sd(unlist(pv.pgls.OU.sig))
mean(unlist(pv.pgls.OU.alpha))
sd(unlist(pv.pgls.OU.alpha))
mean(unlist(pv.pgls.OU.intercept))
sd(unlist(pv.pgls.OU.intercept))
mean(unlist(pv.pgls.OU.slope))
sd(unlist(pv.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(pv.pgls.BM[[1]])~fitted(pv.pgls.BM[[1]]),   main=" Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(pv.pgls.BM[[1]]))
qqline(resid(pv.pgls.BM[[1]], col="blue"))
#heteroscedasticity-OU
plot(resid(pv.pgls.OU[[1]])~fitted(pv.pgls.OU[[1]]),   main=" Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(pv.pgls.OU[[1]]))
qqline(resid(pv.pgls.OU[[1]], col="blue"))

#timebrake-cycle
tb.pgls.BM <- list ()
tb.pgls.BM.p <- list()
tb.pgls.BM.t <- list()
tb.pgls.BM.sig <- list()
tb.pgls.BM.aic<-list()
tb.pgls.BM.lam<-list()
tb.pgls.BM.slope<-list()
tb.pgls.BM.intercept<-list()
tb.pgls.OU <- list ()
tb.pgls.OU.p <- list()
tb.pgls.OU.t <- list()
tb.pgls.OU.sig <- list()
tb.pgls.OU.alpha <- list()
tb.pgls.OU.aic<-list()
tb.pgls.OU.slope<-list()
tb.pgls.OU.intercept<-list()
tb.aicw <- list()
for (i in 1:100){
  tb.pgls.BM[[i]]<-phylolm(cycle~tbrake, phy=phylogeny.final.F[[i]], model=("lambda"))
  tb.pgls.OU[[i]]<-phylolm(cycle~tbrake, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  tb.pgls.BM.p[[i]] <- summary(tb.pgls.BM[[i]])$coefficients[2,4]
  tb.pgls.BM.t[[i]] <- summary(tb.pgls.BM[[i]])$coefficients[2,3]
  tb.pgls.BM.sig[[i]] <- tb.pgls.BM[[i]]$sigma2
  tb.pgls.BM.lam[[i]] <- tb.pgls.BM[[i]]$optpar
  tb.pgls.BM.aic[[i]]<-tb.pgls.BM[[i]]$aic
  tb.pgls.BM.intercept[[i]]<-tb.pgls.BM[[i]]$coefficients[1]
  tb.pgls.BM.slope[[i]]<-tb.pgls.BM[[i]]$coefficients[2]
  tb.pgls.OU.p[[i]] <- summary(tb.pgls.OU[[i]])$coefficients[2,4]
  tb.pgls.OU.t[[i]] <- summary(tb.pgls.OU[[i]])$coefficients[2,3]
  tb.pgls.OU.sig[[i]] <- tb.pgls.OU[[i]]$sigma2
  tb.pgls.OU.alpha[[i]] <- tb.pgls.OU[[i]]$optpar
  tb.pgls.OU.aic[[i]]<-tb.pgls.OU[[i]]$aic
  tb.pgls.OU.intercept[[i]]<-tb.pgls.OU[[i]]$coefficients[1]
  tb.pgls.OU.slope[[i]]<-tb.pgls.OU[[i]]$coefficients[2]
  tb.aicw[[i]]<-aic.w(c(tb.pgls.BM[[i]]$aic, tb.pgls.OU[[i]]$aic))
}
tb.aicw.vect<-(unlist(tb.aicw))
tb.mean.BM.aicw<-mean(tb.aicw.vect[seq(1, length(tb.aicw.vect), 2)])
tb.mean.OU.aicw<-mean(tb.aicw.vect[seq(2, length(tb.aicw.vect), 2)])
signif(c(tb.mean.BM.aicw, tb.mean.OU.aicw), 2)
mean(unlist(tb.pgls.BM.p))
sd(unlist(tb.pgls.BM.p))
mean(unlist(tb.pgls.BM.t))
sd(unlist(tb.pgls.BM.t))
mean(unlist(tb.pgls.BM.sig))
sd(unlist(tb.pgls.BM.sig))
mean(unlist(tb.pgls.BM.lam))
sd(unlist(tb.pgls.BM.lam))
mean(unlist(tb.pgls.BM.intercept))
sd(unlist(tb.pgls.BM.intercept))
mean(unlist(tb.pgls.BM.slope))
sd(unlist(tb.pgls.BM.slope))
mean(unlist(tb.pgls.OU.p))
sd(unlist(tb.pgls.OU.p))
mean(unlist(tb.pgls.OU.t))
sd(unlist(tb.pgls.OU.t))
mean(unlist(tb.pgls.OU.sig))
sd(unlist(tb.pgls.OU.sig))
mean(unlist(tb.pgls.OU.alpha))
sd(unlist(tb.pgls.OU.alpha))
mean(unlist(tb.pgls.OU.intercept))
sd(unlist(tb.pgls.OU.intercept))
mean(unlist(tb.pgls.OU.slope))
sd(unlist(tb.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(tb.pgls.BM[[1]])~fitted(tb.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(tb.pgls.BM[[1]]))
qqline(resid(tb.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(tb.pgls.OU[[1]])~fitted(tb.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(tb.pgls.OU[[1]]))
qqline(resid(tb.pgls.OU[[1]]))


#timeaccel-cycle
ta.pgls.BM <- list ()
ta.pgls.BM.p <- list()
ta.pgls.BM.t <- list()
ta.pgls.BM.sig <- list()
ta.pgls.BM.aic<-list()
ta.pgls.BM.lam<-list()
ta.pgls.BM.slope<-list()
ta.pgls.BM.intercept<-list()
ta.pgls.OU <- list ()
ta.pgls.OU.p <- list()
ta.pgls.OU.t <- list()
ta.pgls.OU.sig <- list()
ta.pgls.OU.alpha <- list()
ta.pgls.OU.aic<-list()
ta.pgls.OU.slope<-list()
ta.pgls.OU.intercept<-list()
ta.aicw <- list()
for (i in 1:100){
  ta.pgls.BM[[i]]<-phylolm(cycle~taccel, phy=phylogeny.final.F[[i]], model=("lambda"))
  ta.pgls.OU[[i]]<-phylolm(cycle~taccel, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  ta.pgls.BM.p[[i]] <- summary(ta.pgls.BM[[i]])$coefficients[2,4]
  ta.pgls.BM.t[[i]] <- summary(ta.pgls.BM[[i]])$coefficients[2,3]
  ta.pgls.BM.sig[[i]] <- ta.pgls.BM[[i]]$sigma2
  ta.pgls.BM.lam[[i]] <- ta.pgls.BM[[i]]$optpar
  ta.pgls.BM.aic[[i]]<-ta.pgls.BM[[i]]$aic
  ta.pgls.BM.intercept[[i]]<-ta.pgls.BM[[i]]$coefficients[1]
  ta.pgls.BM.slope[[i]]<-ta.pgls.BM[[i]]$coefficients[2]
  ta.pgls.OU.p[[i]] <- summary(ta.pgls.OU[[i]])$coefficients[2,4]
  ta.pgls.OU.t[[i]] <- summary(ta.pgls.OU[[i]])$coefficients[2,3]
  ta.pgls.OU.sig[[i]] <- ta.pgls.OU[[i]]$sigma2
  ta.pgls.OU.alpha[[i]] <- ta.pgls.OU[[i]]$optpar
  ta.pgls.OU.aic[[i]]<-ta.pgls.OU[[i]]$aic
  ta.pgls.OU.intercept[[i]]<-ta.pgls.OU[[i]]$coefficients[1]
  ta.pgls.OU.slope[[i]]<-ta.pgls.OU[[i]]$coefficients[2]
  ta.aicw[[i]]<-aic.w(c(ta.pgls.BM[[i]]$aic, ta.pgls.OU[[i]]$aic))
}
ta.aicw.vect<-(unlist(ta.aicw))
ta.mean.BM.aicw<-mean(ta.aicw.vect[seq(1, length(ta.aicw.vect), 2)])
ta.mean.OU.aicw<-mean(ta.aicw.vect[seq(2, length(ta.aicw.vect), 2)])
signif(c(ta.mean.BM.aicw, ta.mean.OU.aicw), 2)
mean(unlist(ta.pgls.BM.p))
sd(unlist(ta.pgls.BM.p))
mean(unlist(ta.pgls.BM.t))
sd(unlist(ta.pgls.BM.t))
mean(unlist(ta.pgls.BM.sig))
sd(unlist(ta.pgls.BM.sig))
mean(unlist(ta.pgls.BM.lam))
sd(unlist(ta.pgls.BM.lam))
mean(unlist(ta.pgls.BM.intercept))
sd(unlist(ta.pgls.BM.intercept))
mean(unlist(ta.pgls.BM.slope))
sd(unlist(ta.pgls.BM.slope))
mean(unlist(ta.pgls.OU.p))
sd(unlist(ta.pgls.OU.p))
mean(unlist(ta.pgls.OU.t))
sd(unlist(ta.pgls.OU.t))
mean(unlist(ta.pgls.OU.sig))
sd(unlist(ta.pgls.OU.sig))
mean(unlist(ta.pgls.OU.alpha))
sd(unlist(ta.pgls.OU.alpha))
mean(unlist(ta.pgls.OU.intercept))
sd(unlist(ta.pgls.OU.intercept))
mean(unlist(ta.pgls.OU.slope))
sd(unlist(ta.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(ta.pgls.BM[[1]])~fitted(ta.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(ta.pgls.BM[[1]]))
qqline(resid(ta.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(ta.pgls.OU[[1]])~fitted(ta.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(ta.pgls.OU[[1]]))
qqline(resid(ta.pgls.OU[[1]]))

#timemed-cycle
tm.pgls.BM <- list ()
tm.pgls.BM.p <- list()
tm.pgls.BM.t <- list()
tm.pgls.BM.sig <- list()
tm.pgls.BM.aic<-list()
tm.pgls.BM.lam<-list()
tm.pgls.BM.slope<-list()
tm.pgls.BM.intercept<-list()
tm.pgls.OU <- list ()
tm.pgls.OU.p <- list()
tm.pgls.OU.t <- list()
tm.pgls.OU.sig <- list()
tm.pgls.OU.alpha <- list()
tm.pgls.OU.aic<-list()
tm.pgls.OU.slope<-list()
tm.pgls.OU.intercept<-list()
tm.aicw <- list()
for (i in 1:100){
  tm.pgls.BM[[i]]<-phylolm(cycle~tmed, phy=phylogeny.final.F[[i]], model=("lambda"))
  tm.pgls.OU[[i]]<-phylolm(cycle~tmed, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  tm.pgls.BM.p[[i]] <- summary(tm.pgls.BM[[i]])$coefficients[2,4]
  tm.pgls.BM.t[[i]] <- summary(tm.pgls.BM[[i]])$coefficients[2,3]
  tm.pgls.BM.sig[[i]] <- tm.pgls.BM[[i]]$sigma2
  tm.pgls.BM.lam[[i]] <- tm.pgls.BM[[i]]$optpar
  tm.pgls.BM.aic[[i]]<-tm.pgls.BM[[i]]$aic
  tm.pgls.BM.intercept[[i]]<-tm.pgls.BM[[i]]$coefficients[1]
  tm.pgls.BM.slope[[i]]<-tm.pgls.BM[[i]]$coefficients[2]
  tm.pgls.OU.p[[i]] <- summary(tm.pgls.OU[[i]])$coefficients[2,4]
  tm.pgls.OU.t[[i]] <- summary(tm.pgls.OU[[i]])$coefficients[2,3]
  tm.pgls.OU.sig[[i]] <- tm.pgls.OU[[i]]$sigma2
  tm.pgls.OU.alpha[[i]] <- tm.pgls.OU[[i]]$optpar
  tm.pgls.OU.aic[[i]]<-tm.pgls.OU[[i]]$aic
  tm.pgls.OU.intercept[[i]]<-tm.pgls.OU[[i]]$coefficients[1]
  tm.pgls.OU.slope[[i]]<-tm.pgls.OU[[i]]$coefficients[2]
  tm.aicw[[i]]<-aic.w(c(tm.pgls.BM[[i]]$aic, tm.pgls.OU[[i]]$aic))
}
tm.aicw.vect<-(unlist(tm.aicw))
tm.mean.BM.aicw<-mean(tm.aicw.vect[seq(1, length(tm.aicw.vect), 2)])
tm.mean.OU.aicw<-mean(tm.aicw.vect[seq(2, length(tm.aicw.vect), 2)])
signif(c(tm.mean.BM.aicw, tm.mean.OU.aicw), 2)
mean(unlist(tm.pgls.BM.p))
sd(unlist(tm.pgls.BM.p))
mean(unlist(tm.pgls.BM.t))
sd(unlist(tm.pgls.BM.t))
mean(unlist(tm.pgls.BM.sig))
sd(unlist(tm.pgls.BM.sig))
mean(unlist(tm.pgls.BM.lam))
sd(unlist(tm.pgls.BM.lam))
mean(unlist(tm.pgls.BM.intercept))
sd(unlist(tm.pgls.BM.intercept))
mean(unlist(tm.pgls.BM.slope))
sd(unlist(tm.pgls.BM.slope))
mean(unlist(tm.pgls.OU.p))
sd(unlist(tm.pgls.OU.p))
mean(unlist(tm.pgls.OU.t))
sd(unlist(tm.pgls.OU.t))
mean(unlist(tm.pgls.OU.sig))
sd(unlist(tm.pgls.OU.sig))
mean(unlist(tm.pgls.OU.alpha))
sd(unlist(tm.pgls.OU.alpha))
mean(unlist(tm.pgls.OU.intercept))
sd(unlist(tm.pgls.OU.intercept))
mean(unlist(tm.pgls.OU.slope))
sd(unlist(tm.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(tm.pgls.BM[[1]])~fitted(tm.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(tm.pgls.BM[[1]]))
qqline(resid(tm.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(tm.pgls.OU[[1]])~fitted(tm.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(tm.pgls.OU[[1]]))
qqline(resid(tm.pgls.OU[[1]]))

#timelat-cycle
tl.pgls.BM <- list ()
tl.pgls.BM.p <- list()
tl.pgls.BM.t <- list()
tl.pgls.BM.sig <- list()
tl.pgls.BM.aic<-list()
tl.pgls.BM.lam<-list()
tl.pgls.BM.slope<-list()
tl.pgls.BM.intercept<-list()
tl.pgls.OU <- list ()
tl.pgls.OU.p <- list()
tl.pgls.OU.t <- list()
tl.pgls.OU.sig <- list()
tl.pgls.OU.alpha <- list()
tl.pgls.OU.aic<-list()
tl.pgls.OU.slope<-list()
tl.pgls.OU.intercept<-list()
tl.aicw <- list()
for (i in 1:100){
  tl.pgls.BM[[i]]<-phylolm(cycle~tlat, phy=phylogeny.final.F[[i]], model=("lambda"))
  tl.pgls.OU[[i]]<-phylolm(cycle~tlat, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  tl.pgls.BM.p[[i]] <- summary(tl.pgls.BM[[i]])$coefficients[2,4]
  tl.pgls.BM.t[[i]] <- summary(tl.pgls.BM[[i]])$coefficients[2,3]
  tl.pgls.BM.sig[[i]] <- tl.pgls.BM[[i]]$sigma2
  tl.pgls.BM.lam[[i]] <- tl.pgls.BM[[i]]$optpar
  tl.pgls.BM.aic[[i]]<-tl.pgls.BM[[i]]$aic
  tl.pgls.BM.intercept[[i]]<-tl.pgls.BM[[i]]$coefficients[1]
  tl.pgls.BM.slope[[i]]<-tl.pgls.BM[[i]]$coefficients[2]
  tl.pgls.OU.p[[i]] <- summary(tl.pgls.OU[[i]])$coefficients[2,4]
  tl.pgls.OU.t[[i]] <- summary(tl.pgls.OU[[i]])$coefficients[2,3]
  tl.pgls.OU.sig[[i]] <- tl.pgls.OU[[i]]$sigma2
  tl.pgls.OU.alpha[[i]] <- tl.pgls.OU[[i]]$optpar
  tl.pgls.OU.aic[[i]]<-tl.pgls.OU[[i]]$aic
  tl.pgls.OU.intercept[[i]]<-tl.pgls.OU[[i]]$coefficients[1]
  tl.pgls.OU.slope[[i]]<-tl.pgls.OU[[i]]$coefficients[2]
  tl.aicw[[i]]<-aic.w(c(tl.pgls.BM[[i]]$aic, tl.pgls.OU[[i]]$aic))
}
tl.aicw.vect<-(unlist(tl.aicw))
tl.mean.BM.aicw<-mean(tl.aicw.vect[seq(1, length(tl.aicw.vect), 2)])
tl.mean.OU.aicw<-mean(tl.aicw.vect[seq(2, length(tl.aicw.vect), 2)])
signif(c(tl.mean.BM.aicw, tl.mean.OU.aicw), 2)
mean(unlist(tl.pgls.BM.p))
sd(unlist(tl.pgls.BM.p))
mean(unlist(tl.pgls.BM.t))
sd(unlist(tl.pgls.BM.t))
mean(unlist(tl.pgls.BM.sig))
sd(unlist(tl.pgls.BM.sig))
mean(unlist(tl.pgls.BM.lam))
sd(unlist(tl.pgls.BM.lam))
mean(unlist(tl.pgls.BM.intercept))
sd(unlist(tl.pgls.BM.intercept))
mean(unlist(tl.pgls.BM.slope))
sd(unlist(tl.pgls.BM.slope))
mean(unlist(tl.pgls.OU.p))
sd(unlist(tl.pgls.OU.p))
mean(unlist(tl.pgls.OU.t))
sd(unlist(tl.pgls.OU.t))
mean(unlist(tl.pgls.OU.sig))
sd(unlist(tl.pgls.OU.sig))
mean(unlist(tl.pgls.OU.alpha))
sd(unlist(tl.pgls.OU.alpha))
mean(unlist(tl.pgls.OU.intercept))
sd(unlist(tl.pgls.OU.intercept))
mean(unlist(tl.pgls.OU.slope))
sd(unlist(tl.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(tl.pgls.BM[[1]])~fitted(tl.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(tl.pgls.BM[[1]]))
qqline(resid(tl.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(tl.pgls.OU[[1]])~fitted(tl.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(tl.pgls.OU[[1]]))
qqline(resid(tl.pgls.OU[[1]]))

#timev-cycle
tv.pgls.BM <- list ()
tv.pgls.BM.p <- list()
tv.pgls.BM.t <- list()
tv.pgls.BM.sig <- list()
tv.pgls.BM.aic<-list()
tv.pgls.BM.lam<-list()
tv.pgls.BM.slope<-list()
tv.pgls.BM.intercept<-list()
tv.pgls.OU <- list ()
tv.pgls.OU.p <- list()
tv.pgls.OU.t <- list()
tv.pgls.OU.sig <- list()
tv.pgls.OU.alpha <- list()
tv.pgls.OU.aic<-list()
tv.pgls.OU.slope<-list()
tv.pgls.OU.intercept<-list()
tv.aicw <- list()
for (i in 1:100){
  tv.pgls.BM[[i]]<-phylolm(cycle~tv, phy=phylogeny.final.F[[i]], model=("lambda"))
  tv.pgls.OU[[i]]<-phylolm(cycle~tv, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  tv.pgls.BM.p[[i]] <- summary(tv.pgls.BM[[i]])$coefficients[2,4]
  tv.pgls.BM.t[[i]] <- summary(tv.pgls.BM[[i]])$coefficients[2,3]
  tv.pgls.BM.sig[[i]] <- tv.pgls.BM[[i]]$sigma2
  tv.pgls.BM.lam[[i]] <- tv.pgls.BM[[i]]$optpar
  tv.pgls.BM.aic[[i]]<-tv.pgls.BM[[i]]$aic
  tv.pgls.BM.intercept[[i]]<-tv.pgls.BM[[i]]$coefficients[1]
  tv.pgls.BM.slope[[i]]<-tv.pgls.BM[[i]]$coefficients[2]
  tv.pgls.OU.p[[i]] <- summary(tv.pgls.OU[[i]])$coefficients[2,4]
  tv.pgls.OU.t[[i]] <- summary(tv.pgls.OU[[i]])$coefficients[2,3]
  tv.pgls.OU.sig[[i]] <- tv.pgls.OU[[i]]$sigma2
  tv.pgls.OU.alpha[[i]] <- tv.pgls.OU[[i]]$optpar
  tv.pgls.OU.aic[[i]]<-tv.pgls.OU[[i]]$aic
  tv.pgls.OU.intercept[[i]]<-tv.pgls.OU[[i]]$coefficients[1]
  tv.pgls.OU.slope[[i]]<-tv.pgls.OU[[i]]$coefficients[2]
  tv.aicw[[i]]<-aic.w(c(tv.pgls.BM[[i]]$aic, tv.pgls.OU[[i]]$aic))
}
tv.aicw.vect<-(unlist(tv.aicw))
tv.mean.BM.aicw<-mean(tv.aicw.vect[seq(1, length(tv.aicw.vect), 2)])
tv.mean.OU.aicw<-mean(tv.aicw.vect[seq(2, length(tv.aicw.vect), 2)])
signif(c(tv.mean.BM.aicw, tv.mean.OU.aicw), 2)
mean(unlist(tv.pgls.BM.p))
sd(unlist(tv.pgls.BM.p))
mean(unlist(tv.pgls.BM.t))
sd(unlist(tv.pgls.BM.t))
mean(unlist(tv.pgls.BM.sig))
sd(unlist(tv.pgls.BM.sig))
mean(unlist(tv.pgls.BM.lam))
sd(unlist(tv.pgls.BM.lam))
mean(unlist(tv.pgls.BM.intercept))
sd(unlist(tv.pgls.BM.intercept))
mean(unlist(tv.pgls.BM.slope))
sd(unlist(tv.pgls.BM.slope))
mean(unlist(tv.pgls.OU.p))
sd(unlist(tv.pgls.OU.p))
mean(unlist(tv.pgls.OU.t))
sd(unlist(tv.pgls.OU.t))
mean(unlist(tv.pgls.OU.sig))
sd(unlist(tv.pgls.OU.sig))
mean(unlist(tv.pgls.OU.alpha))
sd(unlist(tv.pgls.OU.alpha))
mean(unlist(tv.pgls.OU.intercept))
sd(unlist(tv.pgls.OU.intercept))
mean(unlist(tv.pgls.OU.slope))
sd(unlist(tv.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(tv.pgls.BM[[1]])~fitted(tv.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(tv.pgls.BM[[1]]))
qqline(resid(tv.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(tv.pgls.OU[[1]])~fitted(tv.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(tv.pgls.OU[[1]]))
qqline(resid(tv.pgls.OU[[1]]))

#tbp-cycle
tbp.pgls.BM <- list ()
tbp.pgls.BM.p <- list()
tbp.pgls.BM.t <- list()
tbp.pgls.BM.sig <- list()
tbp.pgls.BM.aic<-list()
tbp.pgls.BM.lam<-list()
tbp.pgls.BM.slope<-list()
tbp.pgls.BM.intercept<-list()
tbp.pgls.OU <- list ()
tbp.pgls.OU.p <- list()
tbp.pgls.OU.t <- list()
tbp.pgls.OU.sig <- list()
tbp.pgls.OU.alpha <- list()
tbp.pgls.OU.aic<-list()
tbp.pgls.OU.slope<-list()
tbp.pgls.OU.intercept<-list()
tbp.aicw <- list()
for (i in 1:100){
  tbp.pgls.BM[[i]]<-phylolm(cycle~tbp, phy=phylogeny.final.F[[i]], model=("lambda"))
  tbp.pgls.OU[[i]]<-phylolm(cycle~tbp, phy=phylogeny.final.F[[i]], model=("OUrandomRoot"), upper.bound=1)
  tbp.pgls.BM.p[[i]] <- summary(tbp.pgls.BM[[i]])$coefficients[2,4]
  tbp.pgls.BM.t[[i]] <- summary(tbp.pgls.BM[[i]])$coefficients[2,3]
  tbp.pgls.BM.sig[[i]] <- tbp.pgls.BM[[i]]$sigma2
  tbp.pgls.BM.lam[[i]] <- tbp.pgls.BM[[i]]$optpar
  tbp.pgls.BM.aic[[i]]<-tbp.pgls.BM[[i]]$aic
  tbp.pgls.BM.intercept[[i]]<-tbp.pgls.BM[[i]]$coefficients[1]
  tbp.pgls.BM.slope[[i]]<-tbp.pgls.BM[[i]]$coefficients[2]
  tbp.pgls.OU.p[[i]] <- summary(tbp.pgls.OU[[i]])$coefficients[2,4]
  tbp.pgls.OU.t[[i]] <- summary(tbp.pgls.OU[[i]])$coefficients[2,3]
  tbp.pgls.OU.sig[[i]] <- tbp.pgls.OU[[i]]$sigma2
  tbp.pgls.OU.alpha[[i]] <- tbp.pgls.OU[[i]]$optpar
  tbp.pgls.OU.aic[[i]]<-tbp.pgls.OU[[i]]$aic
  tbp.pgls.OU.intercept[[i]]<-tbp.pgls.OU[[i]]$coefficients[1]
  tbp.pgls.OU.slope[[i]]<-tbp.pgls.OU[[i]]$coefficients[2]
  tbp.aicw[[i]]<-aic.w(c(tbp.pgls.BM[[i]]$aic, tbp.pgls.OU[[i]]$aic))
}
tbp.aicw.vect<-(unlist(tbp.aicw))
tbp.mean.BM.aicw<-mean(tbp.aicw.vect[seq(1, length(tbp.aicw.vect), 2)])
tbp.mean.OU.aicw<-mean(tbp.aicw.vect[seq(2, length(tbp.aicw.vect), 2)])
signif(c(tbp.mean.BM.aicw, tbp.mean.OU.aicw), 2)
mean(unlist(tbp.pgls.BM.p))
sd(unlist(tbp.pgls.BM.p))
mean(unlist(tbp.pgls.BM.t))
sd(unlist(tbp.pgls.BM.t))
mean(unlist(tbp.pgls.BM.sig))
sd(unlist(tbp.pgls.BM.sig))
mean(unlist(tbp.pgls.BM.lam))
sd(unlist(tbp.pgls.BM.lam))
mean(unlist(tbp.pgls.BM.intercept))
sd(unlist(tbp.pgls.BM.intercept))
mean(unlist(tbp.pgls.BM.slope))
sd(unlist(tbp.pgls.BM.slope))
mean(unlist(tbp.pgls.OU.p))
sd(unlist(tbp.pgls.OU.p))
mean(unlist(tbp.pgls.OU.t))
sd(unlist(tbp.pgls.OU.t))
mean(unlist(tbp.pgls.OU.sig))
sd(unlist(tbp.pgls.OU.sig))
mean(unlist(tbp.pgls.OU.alpha))
sd(unlist(tbp.pgls.OU.alpha))
mean(unlist(tbp.pgls.OU.intercept))
sd(unlist(tbp.pgls.OU.intercept))
mean(unlist(tbp.pgls.OU.slope))
sd(unlist(tbp.pgls.OU.slope))
#heteroscedasticity-BM
plot(resid(tbp.pgls.BM[[1]])~fitted(tbp.pgls.BM[[1]]),, main="Residuals vs. Fitted Values")
#normal distribution of residuals-BM
qqnorm(resid(tbp.pgls.BM[[1]]))
qqline(resid(tbp.pgls.BM[[1]]))
#heteroscedasticity-OU
plot(resid(tbp.pgls.OU[[1]])~fitted(tbp.pgls.OU[[1]]), main="Residuals vs. Fitted Values")
#normal distribution of residuals-OU
qqnorm(resid(tbp.pgls.OU[[1]]))
qqline(resid(tbp.pgls.OU[[1]]))

